@@ -1,9 +1,22 @@
+/****************************************************************************
+ *
+ * MODULE:       db.drivers
+ * AUTHOR(S):    Radim Blazek <radim.blazek gmail.com> (original contributor)
+ *               Glynn Clements <glynn gclements.plus.com>, Markus Neteler <neteler itc.it>, Stephan Holl
+ * PURPOSE:      lists all database drivers
+ * COPYRIGHT:    (C) 2002-2006 by the GRASS Development Team
+ *
+ *               This program is free software under the GNU General Public
+ *               License (>=v2). Read the file COPYING that comes with GRASS
+ *               for details.
+ *
+ *****************************************************************************/
 #include <stdlib.h>
-#include "codes.h"
-#include "dbmi.h"
-#include "codes.h"
-#include "gis.h"
-#include "glocale.h"
+#include <grass/codes.h>
+#include <grass/dbmi.h>
+#include <grass/codes.h>
+#include <grass/gis.h>
+#include <grass/glocale.h>
 
 void parse_command_line();
 
@@ -48,10 +61,11 @@ parse_command_line (int argc, char *argv[])
 
     print = G_define_flag();
     print->key          = 'p';
-    print->description  = _("print tables and exit");    
+    print->description  = _("print drivers and exit");    
 
     /* Set description */
     module              = G_define_module();
+    module->keywords = _("database, SQL");
     module->description = _("List all database drivers.");
 
     if (G_parser(argc, argv))
@@ -59,3 +73,4 @@ parse_command_line (int argc, char *argv[])
 
     parms.f = full->answer;
 }
+
