@@ -2,11 +2,11 @@
 *
 * MODULE:       DBF driver 
 *   	    	
-* AUTHOR(S):    Radim Blazek
+* AUTHOR(S):    Radim Blazek, Daniel Calvelo
 *
 * PURPOSE:      Simple driver for reading and writing dbf files     
 *
-* COPYRIGHT:    (C) 2000 by the GRASS Development Team
+* COPYRIGHT:    (C) 2000,2005 by the GRASS Development Team
 *
 *               This program is free software under the GNU General Public
 *   	    	License (>=v2). Read the file COPYING that comes with GRASS
@@ -18,8 +18,9 @@
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>
-#include <dbmi.h>
-#include <shapefil.h>
+#include <grass/dbmi.h>
+#include <grass/shapefil.h>
+#include <grass/gis.h>
 #include "globals.h"
 #include "proto.h"
 
@@ -33,6 +34,7 @@
 int yyparse(void);
 void get_col_def ( SQLPSTMT *st, int col, int *type, int *width, int *decimals );
 int sel(SQLPSTMT * st, int tab, int **set);
+int eval_val(int tab, int row, int col, SQLPVALUE * inval, SQLPVALUE * result);
 int set_val(int tab, int row, int col, SQLPVALUE * val);
 double eval_node(SQLPNODE *, int, int, SQLPVALUE *);
 int eval_node_type(SQLPNODE *, int);
@@ -49,6 +51,7 @@ int execute(char *sql, cursor * c)
     int dtype, stype;
     int width, decimals;
     char *tmpsql, name[500];
+    SQLPVALUE *calctmp; /* store for calculated values in UPDATE, if any */
 
     /* parse sql statement */
     /* I don't know why, but if the statement ends by string in quotes 'xxx' and is not 
@@ -61,11 +64,11 @@ int execute(char *sql, cursor * c)
 
     if (yyparse() != 0) {
 	sqpFreeStmt(st);
-	free ( tmpsql) ;
+	G_free ( tmpsql) ;
 	append_error("SQL parser error in statement:\n%s\n", sql);
 	return DB_FAILED;
     }
-    free ( tmpsql) ;
+    G_free ( tmpsql) ;
 
     G_debug (3, "SQL statement parsed successfully" );
 
@@ -101,7 +104,7 @@ int execute(char *sql, cursor * c)
     if (st->command == SQLP_INSERT || st->command == SQLP_SELECT
 	|| st->command == SQLP_UPDATE) {
 	if (ncols > 0) {	/* colums were specified */
-	    cols = (int *) malloc(ncols * sizeof(int));
+	    cols = (int *) G_malloc (ncols * sizeof(int));
 	    for (i = 0; i < ncols; i++) {
 		cols[i] = find_column(tab, st->Col[i].s);
 		if ( cols[i] == -1 ) {
@@ -113,7 +116,7 @@ int execute(char *sql, cursor * c)
 	else {			/* all columns */
 
 	    ncols = db.tables[tab].ncols;
-	    cols = (int *) malloc(ncols * sizeof(int));
+	    cols = (int *) G_malloc (ncols * sizeof(int));
 	    for (i = 0; i < ncols; i++)
 		cols[i] = i;
 	}
@@ -123,7 +126,7 @@ int execute(char *sql, cursor * c)
     if (st->command == SQLP_INSERT || st->command == SQLP_UPDATE) {
 	for (i = 0; i < st->nVal; i++) {
 	    col = cols[i];
-	    if ( st->Val[i].type != SQLP_NULL ) {
+	    if ( st->Val[i].type != SQLP_NULL && st->Val[i].type != SQLP_EXPR) {
 		dtype = db.tables[tab].cols[col].type;
 		stype = st->Val[i].type;
 		if ((dtype == DBF_INT && stype != SQLP_I)
@@ -149,7 +152,7 @@ int execute(char *sql, cursor * c)
 	/* Add column to each row */
 	for ( i = 0; i < db.tables[tab].nrows; i++ ) {
 	    db.tables[tab].rows[i].values = 
-	        (VALUE *) realloc( db.tables[tab].rows[i].values, db.tables[tab].ncols * sizeof(VALUE));
+	        (VALUE *) G_realloc ( db.tables[tab].rows[i].values, db.tables[tab].ncols * sizeof(VALUE));
 
             dbval = &(db.tables[tab].rows[i].values[db.tables[tab].ncols-1]);
 	    dbval->i = 0;
@@ -198,13 +201,13 @@ int execute(char *sql, cursor * c)
 	if (db.tables[tab].nrows == db.tables[tab].arows) {
 	    db.tables[tab].arows += 1000;
 	    db.tables[tab].rows =
-		(ROW *) realloc(db.tables[tab].rows,
+		(ROW *) G_realloc (db.tables[tab].rows,
 				db.tables[tab].arows * sizeof(ROW));
 	}
 	dbrows = db.tables[tab].rows;
 	row = db.tables[tab].nrows;
 	dbrows[row].values =
-	    (VALUE *) calloc(db.tables[tab].ncols, sizeof(VALUE));
+	    (VALUE *) G_calloc (db.tables[tab].ncols, sizeof(VALUE));
 	dbrows[row].alive = TRUE;
         
 	/* set to null */
@@ -250,12 +253,22 @@ int execute(char *sql, cursor * c)
 
 	/* update rows */
 	for (i = 0; i < nrows; i++) {
+	  SQLPVALUE *temp_p;
+	  calctmp = (SQLPVALUE*)G_malloc((st->nVal) * sizeof(SQLPVALUE));
 	    row = selset[i];
+	    for (j = 0; j < st->nVal; j++) {
+		col = cols[j];
+		eval_val(tab, row, col, &(st->Val[j]), &(calctmp[j]));
+	    }
+	    temp_p = st->Val;
+	    st->Val = calctmp;
 	    for (j = 0; j < st->nVal; j++) {
 		col = cols[j];
 		set_val(tab, row, col, &(st->Val[j]));
 		db.tables[tab].updated = TRUE;
 	    }
+	    st->Val = temp_p;
+	    G_free(calctmp);
 	}
 	break;
 
@@ -310,14 +323,93 @@ void get_col_def ( SQLPSTMT *st, int col, int *type, int *width, int *decimals )
     }
 }
 
+int eval_val(int tab, int row, int col, SQLPVALUE * inval, SQLPVALUE *val)
+{
+  
+  double retval;
+  /* XXX */
+    if ( inval->type == SQLP_EXPR ) {
+
+      retval = eval_node( inval->expr, tab, row, val );
+      if ( retval == NODE_NULL )
+	{
+	  val->type = SQLP_NULL;
+	}
+      else if ( retval == NODE_TRUE )
+	{
+	  val->i = 1;
+	  val->d = 1.0;
+	  val->s = "TRUE";
+	}
+      else if ( retval == NODE_FALSE )
+	{
+	  val->i = 0;
+	  val->d = 0.0;
+	  val->s = NULL;
+	}
+      else if ( retval == NODE_VALUE )
+	{
+	  /* Ok, got a value, propagate it to the proper type */
+	  if( val->type == SQLP_I ){
+	    val->d = (double)val->i;
+	    val->s = (char*)G_malloc (32*sizeof(char));
+	    sprintf( val->s, "%d", val->i );
+	  }else if( val->type == SQLP_D ){
+	    val->i = (int)val->d;
+	    val->s = (char*)G_malloc (32*sizeof(char));
+	    sprintf( val->s, "%g", val->d );
+	  }else if( val->type == SQLP_S ){
+	    val->i = atoi( val->s );
+	    val->d = atof( val->s );
+	  }else{
+	    G_fatal_error("This should not happen: wrong return type in parsing.");
+	  }
+	}
+      else if ( retval == NODE_ERROR )
+	{
+	  G_fatal_error("This should not happen: got a wrong expression structure after parsing.");
+	}
+      else
+	{
+	  G_fatal_error("Unknown return value calling eval_node from eval_val");
+	}
+    }else{
+      /* 
+       * TODO: maybe use this function to perform type "conversion",
+       * i.e. setting all of s,i,d to the same "value",as is done with
+       * the result of eval_node above.
+       */
+      val = inval;
+    }
+}
+
 int set_val(int tab, int row, int col, SQLPVALUE * val)
 {
     VALUE *dbval;
 
     dbval = &(db.tables[tab].rows[row].values[col]);
-	
+/* For debugging purposes; see FIXME below	
+	fprintf(stderr, "In set_val : ");
+	fprintf(stderr, val->type==SQLP_EXPR?"sqlp_expr":
+			val->type==SQLP_NULL?"sqlp_null":
+			val->type==SQLP_I?"sqlp_i":
+			val->type==SQLP_D?"sqlp_d":
+			val->type==SQLP_S?"sqlp_s":
+			"other"); //DCA
+	fprintf(stderr,"%d\n",val->type);
+	fflush(stderr);
+*/
+    if ( val->type == SQLP_EXPR ){
+      eval_val( tab, row, col, val, val );
+    }
 
-    if ( val->type == SQLP_NULL ) {
+    /* FIXME: SQLP_NULL is not always properly detected.
+     * This workaround works, since type should be some of these
+     * after passing through eval_val; otherwise it is NULL
+     */
+    if ( ! ( val->type == SQLP_I
+	||  val->type == SQLP_D
+	||  val->type == SQLP_S ) ) {
         dbval->is_null = 1;
 	dbval->c = NULL;
 	dbval->i = 0;
@@ -400,7 +492,7 @@ int sel(SQLPSTMT * st, int tab, int **selset)
     }
 
     aset = 1;
-    set = (int *) malloc(aset * sizeof(int));
+    set = (int *) G_malloc (aset * sizeof(int));
 
     if (st->upperNodeptr) {
 	int node_type;
@@ -431,7 +523,7 @@ int sel(SQLPSTMT * st, int tab, int **selset)
 		} else if ( condition == NODE_TRUE ) { /* true */
 		    if (nset == aset) {
 			aset += 1000;
-			set = (int *) realloc(set, aset * sizeof(int));
+			set = (int *) G_realloc (set, aset * sizeof(int));
 		    }
 		    set[nset] = i;
 		    nset++;
@@ -446,7 +538,7 @@ int sel(SQLPSTMT * st, int tab, int **selset)
 	}
     } else { /* Select all */
 	aset = db.tables[tab].nrows;
-	set = (int *) realloc(set, aset * sizeof(int));
+	set = (int *) G_realloc (set, aset * sizeof(int));
 	for (i = 0; i < db.tables[tab].nrows; i++) {
 	    set[i] = i;
 	}
