@@ -13,13 +13,13 @@
 *   	    	for details.
 *
 *****************************************************************************/
-#include <dbmi.h>
+#include <grass/dbmi.h>
 #include "globals.h"
 #include "proto.h"
 
 int
-db__driver_execute_immediate (sql)
-    dbString *sql;
+db__driver_execute_immediate  (dbString *sql)
+
 {
     char *s;
     int  ret;
