@@ -17,7 +17,7 @@
 #define MAIN
 #include <stdlib.h>
 #include <string.h>
-#include <dbmi.h>
+#include <grass/dbmi.h>
 #include "globals.h"
 #include "proto.h"
 #include "dbdriver.h"
