@@ -1,11 +1,15 @@
 #define MAIN
-#include <dbmi.h>
+#include <stdlib.h>
+#include <grass/dbmi.h>
 #include "odbc.h"
 #include "globals.h"
 #include "dbdriver.h"
 
-main(argc, argv) char *argv[];
+
+int main(int argc, char **argv)
 {
 	init_dbdriver();
 	exit (db_driver (argc, argv));
+
+	return 0;
 }
