@@ -1,12 +1,10 @@
-#include <dbmi.h>
-#include <datetime.h>
+#include <grass/dbmi.h>
+#include <grass/datetime.h>
 #include "globals.h"
 #include "proto.h"
-#include "glocale.h"
+#include <grass/glocale.h>
 
-int db__driver_describe_table(table_name, table)
-     dbString *table_name;
-     dbTable **table;
+int db__driver_describe_table( dbString *table_name, dbTable **table)
 {
     dbString sql;
     PGresult *res;
@@ -15,7 +13,7 @@ int db__driver_describe_table(table_name, table)
 
     db_set_string( &sql, "select * from ");
     db_append_string ( &sql, db_get_string(table_name) );
-    db_append_string( &sql, " where oid < 0");
+    db_append_string( &sql, " where 1 = 0");
 
     res = PQexec(pg_conn, db_get_string(&sql));
 
@@ -97,6 +95,7 @@ int describe_table( PGresult *res, dbTable **table, cursor *c)
 	G_debug(3, "col: %s, kcols %d, pgtype : %d, gpgtype : %d, sqltype %d, fsize : %d", 
 		    fname, kcols, pgtype, gpgtype, sqltype, fsize);
 
+	/* PG types defined in globals.h (and pg_type.h) */
 	if ( sqltype == DB_SQL_TYPE_UNKNOWN ) {
 	    /* Warn, ignore and continue */
 	    G_warning ( _("pg driver: column '%s', type %d  is not supported"), fname, pgtype);
@@ -107,12 +106,6 @@ int describe_table( PGresult *res, dbTable **table, cursor *c)
 	    G_warning ( _("column '%s' : type int8 (bigint) is stored as integer (4 bytes) "
 		          "some data may be damaged"), fname);
 	
-	if ( gpgtype == PG_TYPE_TEXT ) {
-	    G_warning ( _("column '%s' : type text is stored as varchar(250) "
-		          "some data may be lost"), fname);
-	    fsize = 250;
-	}
-	
 	if ( gpgtype == PG_TYPE_VARCHAR && fsize < 0 ) {
 	    G_warning ( _("column '%s' : type character varying is stored as varchar(250) "
 		          "some data may be lost"), fname);
@@ -169,6 +162,7 @@ int get_column_info ( PGresult *res, int col, int *pgtype, int *gpgtype, int *sq
     
     /* TODO: we should load field names from pg_type table instead of using copy of #defines */
     switch ( *gpgtype) {
+	case PG_TYPE_BIT:
 	case PG_TYPE_INT2:
 	case PG_TYPE_INT4:
 	case PG_TYPE_INT8:
@@ -186,8 +180,7 @@ int get_column_info ( PGresult *res, int col, int *pgtype, int *gpgtype, int *sq
 	    break;
 	    
 	case PG_TYPE_TEXT: 
-	    *sqltype = DB_SQL_TYPE_CHARACTER;
-	    *size = 250; /* This is not optimal of course, some data may be lost */
+	    *sqltype = DB_SQL_TYPE_TEXT;
 	    break;
 
 	case PG_TYPE_FLOAT4:
