@@ -1,10 +1,11 @@
 #include <stdlib.h>
-#include <dbmi.h>
+#include <grass/dbmi.h>
+#include <grass/gis.h>
 #include "globals.h"
 #include "proto.h"
 
-int db__driver_execute_immediate(sql)
-     dbString *sql;
+int db__driver_execute_immediate (dbString *sql)
+
 {
     PGresult *res;
     char     *str;
@@ -31,12 +32,12 @@ int db__driver_execute_immediate(sql)
 	report_error();
 	PQclear(res);
 	if ( str ) 
-	    free ( str );
+	    G_free ( str );
 	return DB_FAILED;
     }
     
     if ( str ) 
-	free ( str );
+	G_free ( str );
     PQclear(res);
 
     return DB_OK;
