@@ -15,11 +15,12 @@ typedef struct {
         char *host, *port, *options, *tty, *dbname, *user, *password, *schema;
 } PGCONN;
 
-/* Postgres data types defined in GRASS */
+/* Postgres data types defined in GRASS, see pg_type.h */
 typedef enum {     /* name in pg_type, aliases */
   PG_TYPE_UNKNOWN,  /* all types not supported by GRASS */
 
-  PG_TYPE_INT2,	    /* int2,	smallint */
+  PG_TYPE_BIT,       /* bit */
+  PG_TYPE_INT2,      /* int2,	smallint */
   PG_TYPE_INT4,      /* int4,	integer, int */
   PG_TYPE_INT8,      /* int8,	bigint */
   PG_TYPE_SERIAL,    /* serial */
@@ -38,7 +39,7 @@ typedef enum {     /* name in pg_type, aliases */
   PG_TYPE_TIME,      /* time */
   PG_TYPE_TIMESTAMP, /* timestamp */
 
-  PG_TYPE_BOOL,      /* bool, boolean */
+  PG_TYPE_BOOL       /* bool, boolean */
 } PG_TYPES;
 
 
