@@ -3,11 +3,11 @@
 #include <unistd.h>
 #include <string.h>
 
-#include "gis.h"
-#include "display.h"
-#include "raster.h"
+#include <grass/gis.h>
+#include <grass/display.h>
+#include <grass/raster.h>
 #include "options.h"
-#include "colors.h"
+#include <grass/glocale.h>
 
 int color1;
 int color2;
@@ -16,6 +16,7 @@ double north;
 int use_feet;
 int do_background = 1;
 int do_bar = 1;
+int draw = 0;
 
 int main (int argc, char **argv)
 {
@@ -24,49 +25,57 @@ int main (int argc, char **argv)
 	int t, b, l, r ;
 	struct GModule *module;
 	struct Option *opt1, *opt2, *opt3 ;
-	struct Flag *mouse, *feet, *top, *linescale ;
+	struct Flag *mouse, *feet, *top, *linescale, *northarrow, *scalebar;
 	struct Cell_head W ;
-	int R, G, B;
-	const int customFGcolor = MAXCOLORS + 1;
-	const int customBGcolor = MAXCOLORS + 2;
 
 	/* Initialize the GIS calls */
 	G_gisinit(argv[0]);
 
 	module = G_define_module();
+	module->keywords = _("display, cartography");
 	module->description =
-		"Displays a barscale on GRASS monitor.";
+		_("Displays a barscale on GRASS monitor.");
 
 	mouse = G_define_flag() ;
 	mouse->key       = 'm';
-	mouse->description= "Use mouse to interactively place scale" ;
+	mouse->description= _("Use mouse to interactively place scale");
 
 	feet = G_define_flag() ;
 	feet->key        = 'f';
-	feet->description= "Use feet/miles instead of meters" ;
+	feet->description= _("Use feet/miles instead of meters");
 
 	linescale = G_define_flag() ;
 	linescale->key   = 'l';
-	linescale->description= "Draw a line scale instead of a bar scale" ;
+	linescale->description= _("Draw a line scale instead of a bar scale");
 
 	top = G_define_flag() ;
 	top->key         = 't';
-	top->description= "Write text on top of the scale, not to the right" ;
+	top->description= _("Write text on top of the scale, not to the right");
+
+	northarrow = G_define_flag();
+	northarrow->key  = 'n';
+	northarrow->description=_("Draw a north arrow only");
+
+	scalebar = G_define_flag();
+	scalebar->key  = 's';
+	scalebar->description=_("Draw a scale bar only");
 
 	opt1 = G_define_option() ;
 	opt1->key        = "bcolor" ;
 	opt1->type       = TYPE_STRING ;
 	opt1->answer     = DEFAULT_BG_COLOR ;
 	opt1->required   = NO ;
-	opt1->description= "Background color, either a standard GRASS color, R:G:B triplet, or \"none\"" ;
+	opt1->description=
+	    _("Background color, either a standard GRASS color, R:G:B triplet, or \"none\"");
+	opt1->gisprompt  = GISPROMPT_COLOR ;
 
 	opt2 = G_define_option() ;
 	opt2->key        = "tcolor" ;
 	opt2->type       = TYPE_STRING ;
 	opt2->answer     = DEFAULT_FG_COLOR ;
 	opt2->required   = NO ;
-/*	opt2->options    = D_color_list(); */
-	opt2->description= "Text color, either a standard GRASS color or R:G:B triplet (separated by colons)" ;
+	opt2->description= _("Text color, either a standard GRASS color or R:G:B triplet");
+	opt2->gisprompt  = GISPROMPT_COLOR ;
 
 	opt3 = G_define_option() ;
 	opt3->key        = "at";
@@ -75,80 +84,67 @@ int main (int argc, char **argv)
 	opt3->answer     = "0.0,0.0";
 	opt3->options    = "0-100" ;
 	opt3->required   = NO;
-	opt3->description= "The screen coordinates for top-left corner of label ([0,0] is top-left of frame)" ;
+	opt3->description=
+	    _("The screen coordinates for top-left corner of label ([0,0] is top-left of frame)");
 
 	if (G_parser(argc, argv) < 0)
-		exit(-1);
+		exit(EXIT_FAILURE);
+
 
 	G_get_window(&W) ;
 	if (W.proj == PROJECTION_LL)
-		G_fatal_error("%s does not work with a latitude-longitude location",
-			      argv[0]) ;
+	    G_fatal_error(_("%s does not work with a latitude-longitude location"), argv[0]);
 
 	if(linescale->answer)
 		do_bar = 0;
 
 	use_feet = feet->answer ? 1 : 0;
+	if(northarrow->answer && scalebar->answer)
+		G_fatal_error(_("Choose either -n or -s flag"));
 
-
-        /* Parse and select background color */
-	if(sscanf(opt1->answer, "%d:%d:%d", &R, &G, &B) == 3) {
-	    if (R>=0 && R<256 && G>=0 && G<256 && B>=0 && B<256) {
-		R_reset_color(R, G, B, customBGcolor);
-		color1 = customBGcolor;
-	    }
-	}
-	else if (!strcmp("none", opt1->answer)) {
-	    do_background = 0;
-	    color1 = 1;	/* dummy value */
-	}
+	if(northarrow->answer)
+		draw = 1;
 	else
-	    color1 = D_translate_color(opt1->answer);
-
-	if(!color1)
-	    G_fatal_error("[%s]: No such color", opt1->answer);
-
-
-        /* Parse and select foreground color */
-	if(sscanf(opt2->answer, "%d:%d:%d", &R, &G, &B) == 3) {
-	    if (R>=0 && R<256 && G>=0 && G<256 && B>=0 && B<256) {
-		R_reset_color(R, G, B, customFGcolor);
-		color2 = customFGcolor;
-	    }
-	}
-	else
-	    color2 = D_translate_color(opt2->answer);
-
-	if(!color2)
-	    G_fatal_error("[%s]: No such color", opt2->answer);
-
+	if(scalebar->answer)
+		draw = 2;
 
 	sscanf(opt3->answers[0], "%lf", &east) ;
 	sscanf(opt3->answers[1], "%lf", &north) ;
 
+
 	if (R_open_driver() != 0)
-		G_fatal_error ("No graphics device selected");
+	    G_fatal_error (_("No graphics device selected"));
 
 	if (D_get_cur_wind(window_name))
-		G_fatal_error("No current window") ;
+	    G_fatal_error(_("No current window")) ;
 
 	if (D_set_cur_wind(window_name))
-		G_fatal_error("Current window not available");
+	    G_fatal_error(_("Current window not available"));
+
+
+        /* Parse and select background color */
+	color1 = D_parse_color(opt1->answer, 1);
+	if (color1 == 0)
+	    do_background = 0;
+
+	/* Parse and select foreground color */
+	color2 = D_parse_color(opt2->answer, 0);
+
 
 	/* Read in the map window associated with window */
 	G_get_window(&window);
 
 	if (D_check_map_window(&window))
-		G_fatal_error("Setting map window");
+	    G_fatal_error(_("Setting map window"));
 
 	if (G_set_window(&window) == -1)
-		G_fatal_error("Current window not settable");
+	    G_fatal_error(_("Current window not settable"));
 
 	/* Determine conversion factors */
 	if (D_get_screen_window(&t, &b, &l, &r))
-		G_fatal_error("Getting screen window") ;
+	    G_fatal_error(_("Getting screen window")) ;
 	if (D_do_conversions(&window, t, b, l, r))
-		G_fatal_error("Error in calculating conversions") ;
+	    G_fatal_error(_("Error in calculating conversions")) ;
 
 	if (!mouse->answer)
 	{
@@ -179,13 +175,18 @@ int main (int argc, char **argv)
 			strcat(cmdbuf, " -t");
 		if(feet->answer)
 			strcat(cmdbuf, " -f");
+		if(linescale->answer)
+			strcat(cmdbuf, " -l");
+		if(northarrow->answer)
+			strcat(cmdbuf, " -n");
+		if(scalebar->answer)
+			strcat(cmdbuf, " -s");
 
 		/* Add this command to list */
 		D_add_to_list(cmdbuf) ;
-		return 1;
 	}
 
 	R_close_driver();
 
-	return 0;
+	exit(EXIT_SUCCESS);
 }
