@@ -1,8 +1,9 @@
 #include <stdlib.h>
 #include <stdio.h>
-#include "gis.h"
-#include "display.h"
-#include "raster.h"
+#include <grass/gis.h>
+#include <grass/display.h>
+#include <grass/raster.h>
+#include <grass/colors.h>
 #include "colors.h"
 
 int 
