@@ -3,9 +3,9 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include "raster.h"
-#include "gis.h"
-#include "monitors.h"
+#include <grass/raster.h>
+#include <grass/gis.h>
+#include <grass/monitors.h>
 #include "open.h"
 #include "local_proto.h"
 
