@@ -1,13 +1,14 @@
-#include "gis.h"
+#include <grass/gis.h>
+#include <grass/glocale.h>
 #include "profile.h"
 
 int is_null_value (RASTER_MAP_PTR *ptr, int col)
 {
     if (ptr == NULL)
-        G_fatal_error("%s: 'is_null_value()' got NULL pointer!",
+        G_fatal_error(_("%s: 'is_null_value()' got NULL pointer!"),
                 G_program_name());
     if (col < 0)
-        G_fatal_error("%s: 'is_null_value()' got negative column index",
+        G_fatal_error(_("%s: 'is_null_value()' got negative column index"),
                 G_program_name());
 
     switch (ptr->type)
@@ -19,8 +20,8 @@ int is_null_value (RASTER_MAP_PTR *ptr, int col)
         case DCELL_TYPE:
             return G_is_d_null_value (&ptr->data.d[col]);
         default:
-            G_fatal_error("%s: 'is_null_value()' Unknown "
-                    "RASTER_MAP_TYPE '%d'", G_program_name(),
+            G_fatal_error(_("%s: 'is_null_value()' Unknown "
+                    "RASTER_MAP_TYPE '%d'"), G_program_name(),
                     ptr->type);
     }
 
