@@ -1,9 +1,10 @@
 #include <stdlib.h>
-#include "gis.h"
-#include "raster.h"
-#include "display.h"
+#include <grass/gis.h>
+#include <grass/raster.h>
+#include <grass/display.h>
 #include "mask.h"
 #include "local_proto.h"
+#include <grass/glocale.h>
 
 static int cell_draw(char *,char *,struct Colors *,int,int,RASTER_MAP_TYPE);
 
@@ -19,7 +20,7 @@ int display(
     int r,g,b;
 
     if (G_read_colors(name, mapset, &colors) == -1)
-        G_fatal_error("Color file for [%s] not available", name);
+        G_fatal_error(_("Color file for [%s] not available"), name);
 
     /***DEBUG ***
     if (G_write_colors(name, mapset, &colors) == -1)
@@ -28,8 +29,7 @@ int display(
         G_fatal_error("Color file for [%s] not available", name) ;
     *********/
 
-    if (bg)
-    {
+    if (bg) {
 	get_rgb(bg, &r, &g, &b);
 	G_set_null_value_color (r, g, b, &colors);
     }
@@ -80,7 +80,6 @@ static int cell_draw(
     int invert,
     RASTER_MAP_TYPE data_type)
 {
-    char buff[128] ;
     int cellfile;
     void *xarray ;
     int cur_A_row ;
@@ -93,18 +92,12 @@ static int cell_draw(
     /* Set up the screen, conversions, and graphics */
     D_get_screen_window(&t, &b, &l, &r) ;
     if (D_cell_draw_setup(t, b, l, r))
-    {
-	sprintf(buff,"Cannot use current window") ;
-	G_fatal_error(buff) ;
-    }
+	G_fatal_error(_("Cannot use current window")) ;
     D_set_overlay_mode(overlay);
 
     /* Make sure map is available */
     if ((cellfile = G_open_cell_old(name, mapset)) == -1)
-    {
-	sprintf(buff,"Not able to open cellfile for [%s]", name);
-	G_fatal_error(buff) ;
-    }
+	G_fatal_error(_("Not able to open cellfile for [%s]"), name);
 
     /* Allocate space for cell buffer */
     xarray = G_allocate_raster_buf(data_type) ;
@@ -126,7 +119,7 @@ static int cell_draw(
 
     /* Wrap up and return */
     G_close_cell(cellfile) ;
-    free (xarray);
+    G_free (xarray);
     return(0) ;
 }
 
