@@ -1,6 +1,6 @@
 #include <stdio.h>
-#include "raster.h"
-#include "display.h"
+#include <grass/raster.h>
+#include <grass/display.h>
 #include "local_proto.h"
 
 int mouse (int line_color, int text_color)
