@@ -1,6 +1,4 @@
 /*
-* $Id: main.c,v 2.0 2004/11/09 12:53:01 bernhard Exp $
-*
 ****************************************************************************
 *
 * MODULE:       d.text
@@ -33,10 +31,11 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
-#include "gis.h"
-#include "display.h"
-#include "raster.h"
-#include "colors.h"
+#include <grass/gis.h>
+#include <grass/display.h>
+#include <grass/raster.h>
+#include <grass/colors.h>
+#include <grass/glocale.h>
 
 int 
 main (int argc, char **argv)
@@ -54,9 +53,10 @@ main (int argc, char **argv)
         int t, b, l, r ;
         int tsize ;
 	double x,y ;
+	double rotation;
 
 	struct GModule *module;
-	struct Option *opt1, *opt2, *opt3, *opt4;
+	struct Option *opt1, *opt2, *opt3, *opt4, *opt5;
 	struct Flag *flag_b;
 	char *wind_file_name;
 	FILE *wind_file;
@@ -65,8 +65,9 @@ main (int argc, char **argv)
         G_gisinit(argv[0]) ;
 
 	module = G_define_module();
-	module->description =
-	   "Draws text in the active display frame on the graphics monitor using the current font.";
+	module->keywords = _("display");
+    module->description =
+	   _("Draws text in the active display frame on the graphics monitor using the current font.");
 
         opt1 = G_define_option() ;
         opt1->key        = "size" ;
@@ -74,7 +75,7 @@ main (int argc, char **argv)
         opt1->required   = NO ;
         opt1->answer      = "5" ;
         opt1->options    = "0-100";
-        opt1->description="Height of letters in percent of available frame height";
+        opt1->description=_("Height of letters in percentage of available frame height");
 
         opt2 = G_define_option() ;
         opt2->key        = "color" ;
@@ -82,14 +83,15 @@ main (int argc, char **argv)
         opt2->answer     = "gray" ;
         opt2->required   = NO ;
         opt2->description=
-	   "Text color, either a standard GRASS color or R:G:B triplet (separated by colons)" ;
+	   _("Text color, either a standard GRASS color or R:G:B triplet");
 
         opt3 = G_define_option() ;
         opt3->key        = "line" ;
         opt3->required   = NO ;
         opt3->type       = TYPE_INTEGER ;
         opt3->options    = "1-1000" ;
-        opt3->description= "The screen line number on which text will begin to be drawn";
+        opt3->description=
+	   _("The screen line number on which text will begin to be drawn");
 
 	opt4 = G_define_option() ;
 	opt4->key	= "at" ;
@@ -98,26 +100,36 @@ main (int argc, char **argv)
 	opt4->options	= "0-100";
 	opt4->required	= NO ;
 	opt4->description=
-	   "Screen postion at which text will begin to be drawn (percentage, [0,0] is lower left)";
+	   _("Screen position at which text will begin to be drawn (percentage, [0,0] is lower left)");
+
+	opt5 = G_define_option();
+	opt5->key         = "rotation";
+	opt5->type        = TYPE_DOUBLE;
+	opt5->required    = NO;
+	opt5->answer      = "0";
+	opt5->description = _("Rotation angle in degrees (counter-clockwise)");
 
 	flag_b = G_define_flag();
 	flag_b->key         = 'b';
-	flag_b->description = "Use bold text";
+	flag_b->description = _("Use bold text");
 
 
         /* Check command line */
         if (G_parser(argc, argv))
-                exit(1);
+            exit(1);
 
 	if(opt3->answer && opt4->answer)
-		G_fatal_error("Please choose only one placement method");
+	    G_fatal_error(_("Please choose only one placement method"));
 
 
 	if (isatty(0))
-		fprintf (stdout,"\nPlease enter text instructions.  Enter EOF (ctrl-d) on last line to quit\n") ;
+	    fprintf (stdout,"\nPlease enter text instructions.  Enter EOF (ctrl-d) on last line to quit\n");
 
         sscanf(opt1->answer,"%f",&size);
 
+        if (R_open_driver() != 0)
+	    G_fatal_error (_("No graphics device selected"));
+
 	/* Parse and select text color */
 	if(sscanf(opt2->answer, "%d:%d:%d", &R, &G, &B) == 3) {
 		if (R>=0 && R<256 && G>=0 && G<256 && B>=0 && B<256) {
@@ -132,18 +144,15 @@ main (int argc, char **argv)
 	}
 
 	if(!color)
-		G_fatal_error("[%s]: No such color", opt2->answer);
+	    G_fatal_error(_("[%s]: No such color"), opt2->answer);
 
-
-	/* Open monitor window */
-        if (R_open_driver() != 0)
-		G_fatal_error ("No graphics device selected");
+	rotation = atof(opt5->answer);
 
         if (D_get_cur_wind(window_name))
-                G_fatal_error("No current window") ;
+	    G_fatal_error(_("No current window")) ;
 
         if (D_set_cur_wind(window_name))
-                G_fatal_error("Current window not available") ;
+	    G_fatal_error(_("Current window not available")) ;
 
         /* Figure out where to put text */
         D_get_screen_window(&t, &b, &l, &r) ;
@@ -164,13 +173,14 @@ main (int argc, char **argv)
 		x = atof(opt4->answers[0]);
 		y = atof(opt4->answers[1]);
 		if(x<0 || x>100 || y<0 || y>100)
-			G_fatal_error("value [%.0f,%.0f] out of range [0-100]", x, y);
+		    G_fatal_error(_("value [%.0f,%.0f] out of range [0-100]"), x, y);
 
 		cur_dot_row = t+(int)((b-t)*(100.-y)/100.);
 		cur_dot_column = l+(int)((r-l)*x/100.);
 	}
 	
-        R_text_size(tsize, tsize) ;
+	R_text_size(tsize, tsize) ;
+	R_text_rotation((float)rotation);
 
 	if(flag_b->answer)
 		bold = 1;
@@ -179,7 +189,7 @@ main (int argc, char **argv)
 
         wind_file_name = G_tempfile();
         if ((wind_file=fopen(wind_file_name,"w")) == NULL)
-          G_fatal_error("Unable to open the temporary file.");
+	    G_fatal_error(_("Unable to open the temporary file."));
 
         /* Do the plotting */
         while (fgets(buff,512,stdin))
@@ -217,6 +227,12 @@ main (int argc, char **argv)
                                 if (! sscanf(cmd_ptr, "%d", &bold))
                                         bold = 0 ;
                                 break ;
+			case 'R':   /* rotation */
+                                if (sscanf(cmd_ptr, "%lf", &rotation))
+                                {
+                                        R_text_rotation((float)rotation);
+                                }
+                                break ;
                         default:
                                 break ;
                         }
@@ -246,7 +262,8 @@ main (int argc, char **argv)
 	D_add_to_list(max_buff);
 	G_free(max_buff);
 
-        R_close_driver();
+	R_text_rotation(0.0);  /* reset */
+	R_close_driver();
 
 	exit(0);
 }
