@@ -1,9 +1,9 @@
 /* Print z coordinate value for each node */
 
-#include "gis.h"
-#include "Vect.h"
-#include "display.h"
-#include "raster.h"
+#include <grass/gis.h>
+#include <grass/Vect.h>
+#include <grass/display.h>
+#include <grass/raster.h>
 #include "plot.h"
 
 int zcoor ( struct Map_info *Map, int type, LATTR *lattr ) {
