@@ -1,5 +1,4 @@
 /***************************************************************************
- * $Id: main.c,v 1.12 2005/01/10 16:28:34 radim Exp $
  *
  * MODULE: 	g.region (commandline)
  * AUTHOR(S):	Michael Shapiro, CERL
@@ -11,17 +10,16 @@
  *
  *   	    	This program is free software under the GPL (>=v2)
  *   	    	Read the file COPYING that comes with GRASS for details.
- ****************************************************************************
- *
- */
+ ****************************************************************************/
 
 #include <string.h>
 #include <stdlib.h>
-#include "gis.h"
-#include "G3d.h"
-#include "Vect.h"
+#include <grass/gis.h>
+#include <grass/G3d.h>
+#include <grass/Vect.h>
 #include "local_proto.h"
 #include "projects.h"
+#include <grass/glocale.h>
 
 static int nsew(char *,char *,char *,char *);
 static void die(struct Option *);
@@ -34,7 +32,6 @@ int main (int argc, char *argv[])
 	int set_flag;
 	double x;
 	struct Cell_head window, temp_window;
-	char msg[200];
 	char *value;
 	char *name;
 	char *mapset;
@@ -56,7 +53,8 @@ int main (int argc, char *argv[])
 		*res_set,
 		*dist_res,
 		*dflt,
-		*z;
+		*z,
+		*bbox;
 	} flag;
 	struct
 	    {
@@ -69,53 +67,75 @@ int main (int argc, char *argv[])
 
 	G_gisinit (argv[0]);
 
+	/* get current region.
+	 * if current region not valid, set it from default
+	 * note: G_get_default_window() dies upon error
+	 */
+	G_get_default_window(&window);
+
 	module = G_define_module();
+	module->keywords = _("general");
 	module->description =
-		"Program to manage the boundary definitions for the "
-		"geographic region.";
+		_("Program to manage the boundary definitions for the "
+		"geographic region.");
 
 	/* flags */
 
 	flag.dflt = G_define_flag();
 	flag.dflt->key         = 'd';
-	flag.dflt->description = "Set from default region";
-
-	flag.gprint = G_define_flag();
-	flag.gprint->key         = 'g';
-	flag.gprint->description = "Print the current region (shell script style)";
+	flag.dflt->description = _("Set from default region");
+	flag.dflt->guisection  = _("Existing");
 
 	flag.print = G_define_flag();
 	flag.print->key         = 'p';
-	flag.print->description = "Print the current region";
+	flag.print->description = _("Print the current region");
+	flag.print->guisection  = _("Print");
 
 	flag.lprint = G_define_flag();
 	flag.lprint->key         = 'l';
-	flag.lprint->description = "Print the current region in lat/long";
+	flag.lprint->description = _("Print the current region in lat/long on current ellipsoid/datum");
+	flag.lprint->guisection  = _("Print");
 
 	flag.eprint = G_define_flag();
 	flag.eprint->key         = 'e';
-	flag.eprint->description = "Print the current region extent";
+	flag.eprint->description = _("Print the current region extent");
+	flag.eprint->guisection  = _("Print");
 
 	flag.center = G_define_flag();
 	flag.center->key         = 'c';
-	flag.center->description = "Print the current region map center coordinates";
+	flag.center->description = _("Print the current region map center coordinates");
+	flag.center->guisection  = _("Print");
 
         flag.dist_res= G_define_flag();
         flag.dist_res->key         = 'm';
-        flag.dist_res->description = "Print region resolution in meters (geodesic)";
+        flag.dist_res->description = _("Print region resolution in meters (geodesic)");
+        flag.dist_res->guisection  = _("Print");
 
         flag.res_set= G_define_flag();
         flag.res_set->key         = 'a';
-        flag.res_set->description = "Align region to resolution (default = align to bounds, "
-	    			    "works only for 2D resolution )";
+        flag.res_set->description = _("Align region to resolution (default = align to bounds, "
+	    			    "works only for 2D resolution )");
+        flag.res_set->guisection  = _("Bounds");
 
 	flag.update = G_define_flag();
 	flag.update->key         = 'u';
-	flag.update->description = "Do not update the current region";
+	flag.update->description = _("Do not update the current region");
+	flag.update->guisection  = _("Effects");
 
 	flag.z = G_define_flag();
 	flag.z->key         = '3';
-	flag.z->description = "Print also 3D";
+	flag.z->description = _("Print also 3D settings");
+	flag.z->guisection  = _("Print");
+
+	flag.gprint = G_define_flag();
+	flag.gprint->key         = 'g';
+	flag.gprint->description = _("Print the current region (shell script style)");
+	flag.gprint->guisection  = _("Print;Shell Script");
+
+	flag.bbox = G_define_flag();
+	flag.bbox->key         = 'b';
+	flag.bbox->description = _("Print the maximum bounding box in lat/long on WGS84 (-g mode only)");
+	flag.bbox->guisection  = _("Print;Shell Script");
 
 	/* parameters */
 
@@ -125,8 +145,9 @@ int main (int argc, char *argv[])
 	parm.region->required    = NO;
 	parm.region->multiple    = NO;
 	parm.region->type        = TYPE_STRING;
-	parm.region->description = "Set current region from named region";
+	parm.region->description = _("Set current region from named region");
 	parm.region->gisprompt   = "old,windows,region";
+	parm.region->guisection  = _("Existing");
 
 	parm.raster = G_define_option();
 	parm.raster->key         = "rast";
@@ -134,8 +155,9 @@ int main (int argc, char *argv[])
 	parm.raster->required    = NO;
 	parm.raster->multiple    = YES;
 	parm.raster->type        = TYPE_STRING;
-	parm.raster->description = "Set region to match this raster map";
+	parm.raster->description = _("Set region to match this raster map");
 	parm.raster->gisprompt   = "old,cell,raster";
+	parm.raster->guisection  = _("Existing");
 
 	parm.raster3d = G_define_option();
 	parm.raster3d->key         = "rast3d";
@@ -143,8 +165,9 @@ int main (int argc, char *argv[])
 	parm.raster3d->required    = NO;
 	parm.raster3d->multiple    = NO;
 	parm.raster3d->type        = TYPE_STRING;
-	parm.raster3d->description = "Set region to match this 3D raster map (both 2D and 3D values)";
+	parm.raster3d->description = _("Set region to match this 3D raster map (both 2D and 3D values)");
 	parm.raster3d->gisprompt   = "old,grid3,raster 3D";
+	parm.raster3d->guisection  = _("Existing");
 
 	parm.vect = G_define_option();
 	parm.vect->key         = "vect";
@@ -152,8 +175,9 @@ int main (int argc, char *argv[])
 	parm.vect->required    = NO;
 	parm.vect->multiple    = NO;
 	parm.vect->type        = TYPE_STRING;
-	parm.vect->description = "Set region to match this vector map";
+	parm.vect->description = _("Set region to match this vector map");
 	parm.vect->gisprompt   = "old,vector,vector";
+	parm.vect->guisection  = _("Existing");
 
 	parm.view = G_define_option();
 	parm.view->key         = "3dview";
@@ -161,7 +185,9 @@ int main (int argc, char *argv[])
 	parm.view->required    = NO;
 	parm.view->multiple    = NO;
 	parm.view->type        = TYPE_STRING;
-	parm.view->description = "Set region to match this 3dview file";
+	parm.view->description = _("Set region to match this 3dview file");
+	parm.view->gisprompt   = "old,3d.view,3d view";
+	parm.view->guisection  = _("Existing");
 
 	parm.north = G_define_option();
 	parm.north->key         = "n";
@@ -170,6 +196,7 @@ int main (int argc, char *argv[])
 	parm.north->multiple    = NO;
 	parm.north->type        = TYPE_STRING;
 	parm.north->description = llinfo("Value for the northern edge", G_lat_format_string(), window.proj);
+	parm.north->guisection  = _("Bounds");
 
 	parm.south = G_define_option();
 	parm.south->key         = "s";
@@ -178,6 +205,7 @@ int main (int argc, char *argv[])
 	parm.south->multiple    = NO;
 	parm.south->type        = TYPE_STRING;
 	parm.south->description = llinfo("Value for the southern edge", G_lat_format_string(), window.proj);
+	parm.south->guisection  = _("Bounds");
 
 	parm.east = G_define_option();
 	parm.east->key         = "e";
@@ -186,6 +214,7 @@ int main (int argc, char *argv[])
 	parm.east->multiple    = NO;
 	parm.east->type        = TYPE_STRING;
 	parm.east->description = llinfo("Value for the eastern edge ", G_lon_format_string(), window.proj);
+	parm.east->guisection  = _("Bounds");
 
 	parm.west = G_define_option();
 	parm.west->key         = "w";
@@ -194,6 +223,7 @@ int main (int argc, char *argv[])
 	parm.west->multiple    = NO;
 	parm.west->type        = TYPE_STRING;
 	parm.west->description = llinfo("Value for the western edge ", G_lon_format_string(), window.proj);
+	parm.west->guisection  = _("Bounds");
 
 	parm.top = G_define_option();
 	parm.top->key         = "t";
@@ -201,7 +231,8 @@ int main (int argc, char *argv[])
 	parm.top->required    = NO;
 	parm.top->multiple    = NO;
 	parm.top->type        = TYPE_STRING;
-	parm.top->description = "Value for the top edge";
+	parm.top->description = _("Value for the top edge");
+	parm.top->guisection  = _("Bounds");
 
 	parm.bottom = G_define_option();
 	parm.bottom->key         = "b";
@@ -209,7 +240,8 @@ int main (int argc, char *argv[])
 	parm.bottom->required    = NO;
 	parm.bottom->multiple    = NO;
 	parm.bottom->type        = TYPE_STRING;
-	parm.bottom->description = "Value for the bottom edge";
+	parm.bottom->description = _("Value for the bottom edge");
+	parm.bottom->guisection  = _("Bounds");
 
 	parm.res = G_define_option();
 	parm.res->key         = "res";
@@ -217,7 +249,8 @@ int main (int argc, char *argv[])
 	parm.res->required    = NO;
 	parm.res->multiple    = NO;
 	parm.res->type        = TYPE_STRING;
-	parm.res->description = "Grid resolution 2D (both north-south and east-west)";
+	parm.res->description = _("Grid resolution 2D (both north-south and east-west)");
+	parm.res->guisection  = _("Resolution");
 
 	parm.res3 = G_define_option();
 	parm.res3->key         = "res3";
@@ -225,7 +258,8 @@ int main (int argc, char *argv[])
 	parm.res3->required    = NO;
 	parm.res3->multiple    = NO;
 	parm.res3->type        = TYPE_STRING;
-	parm.res3->description = "3D grid resolution (north-south, east-west and top-bottom)";
+	parm.res3->description = _("3D grid resolution (north-south, east-west and top-bottom)");
+	parm.res3->guisection  = _("Resolution");
 
 	parm.nsres = G_define_option();
 	parm.nsres->key         = "nsres";
@@ -234,6 +268,7 @@ int main (int argc, char *argv[])
 	parm.nsres->multiple    = NO;
 	parm.nsres->type        = TYPE_STRING;
 	parm.nsres->description = llinfo("North-south grid resolution 2D ", G_llres_format_string(), window.proj);
+	parm.nsres->guisection  = _("Resolution");
 
 	parm.ewres = G_define_option();
 	parm.ewres->key         = "ewres";
@@ -241,7 +276,8 @@ int main (int argc, char *argv[])
 	parm.ewres->required    = NO;
 	parm.ewres->multiple    = NO;
 	parm.ewres->type        = TYPE_STRING;
-	parm.ewres->description = llinfo("East-west grid resolution  2D ", G_llres_format_string(), window.proj);
+	parm.ewres->description = llinfo("East-west grid resolution 2D ", G_llres_format_string(), window.proj);
+	parm.ewres->guisection  = _("Resolution");
 
 	parm.tbres = G_define_option();
 	parm.tbres->key         = "tbres";
@@ -249,7 +285,8 @@ int main (int argc, char *argv[])
 	parm.tbres->required    = NO;
 	parm.tbres->multiple    = NO;
 	parm.tbres->type        = TYPE_STRING;
-	parm.tbres->description = "Top-bottom grid resolution";
+	parm.tbres->description = _("Top-bottom grid resolution 3D");
+	parm.tbres->guisection  = _("Resolution");
 
 	parm.zoom = G_define_option();
 	parm.zoom->key         = "zoom";
@@ -257,8 +294,9 @@ int main (int argc, char *argv[])
 	parm.zoom->required    = NO;
 	parm.zoom->multiple    = NO;
 	parm.zoom->type        = TYPE_STRING;
-	parm.zoom->description = "Raster map to zoom into";
+	parm.zoom->description = _("Raster map to zoom into");
 	parm.zoom->gisprompt   = "old,cell,raster";
+	parm.zoom->guisection  = _("Resolution");
 
 	parm.align = G_define_option();
 	parm.align->key         = "align";
@@ -266,8 +304,9 @@ int main (int argc, char *argv[])
 	parm.align->required    = NO;
 	parm.align->multiple    = NO;
 	parm.align->type        = TYPE_STRING;
-	parm.align->description = "Raster map to align to";
+	parm.align->description = _("Raster map to align to");
 	parm.align->gisprompt   = "old,cell,raster";
+	parm.align->guisection  = _("Bounds");
 
 	parm.save = G_define_option();
 	parm.save->key         = "save";
@@ -275,21 +314,13 @@ int main (int argc, char *argv[])
 	parm.save->required    = NO;
 	parm.save->multiple    = NO;
 	parm.save->type        = TYPE_STRING;
-	parm.save->description = "Save the current region to region definition file";
+	parm.save->description = _("Save the current region to region definition file");
 	parm.save->gisprompt   = "new,windows,region";
+	parm.save->guisection  = _("Effects");
 
 	if (G_parser(argc,argv))
-		exit(1);
+		exit(EXIT_FAILURE);
 
-	/* get current region.
-	 * if current region not valid, set it from default
-	 * note: G_get_default_window() dies upon error
-	 */
-	if (G__get_window (&window, "", "WIND", G_mapset()) != NULL)
-	{
-		G_get_default_window (&window);
-		G_put_window (&window);
-	}
 	projection = window.proj;
 
 	set_flag = ! flag.update->answer;
@@ -311,25 +342,25 @@ int main (int argc, char *argv[])
 		dist_flag = 1;
 		/* Set -g default output */
 		if ( print_flag == 0)
-		print_flag = 2;
+		     print_flag = 2;
 	} else
 		dist_flag = 0;
 
-	if (flag.dflt->answer)
-		G_get_default_window (&window);
+	if (!flag.dflt->answer)
+		G_get_window(&window);
 
 	/* region= */
-	if (name = parm.region->answer)
+	if ((name = parm.region->answer))
 	{
 		mapset = G_find_file ("windows", name, "");
 		if (!mapset)
-			G_fatal_error ("region <%s> not found", name);
+			G_fatal_error (_("region <%s> not found"), name);
 		if (G__get_window (&window, "windows", name, mapset) != NULL)
-			G_fatal_error ("can't read region <%s> in <%s>", name, mapset);
+			G_fatal_error (_("can't read region <%s> in <%s>"), name, mapset);
 	}
 
 	/* 3dview= */
-	if (name = parm.view->answer)
+	if ((name = parm.view->answer))
 	{
 		struct G_3dview v;
 		FILE *fp;
@@ -337,19 +368,19 @@ int main (int argc, char *argv[])
 		
 		mapset = G_find_file2 ("3d.view", name, "");
 		if (!mapset)
-			G_fatal_error ("3dview file <%s> not found", name);
+			G_fatal_error (_("3dview file <%s> not found"), name);
 
 		G_3dview_warning(0); /* suppress boundary mismatch warning */
 
 		if(NULL == (fp = G_fopen_old("3d.view",name,mapset)))
-		    G_fatal_error ("can't open 3dview file <%s> in <%s>", name, mapset);
+		    G_fatal_error (_("can't open 3dview file <%s> in <%s>"), name, mapset);
 
 		G_copy (&temp_window, &window, sizeof(window));
 
 		if(0 > (ret = G_get_3dview(name, mapset, &v)))
-		    G_fatal_error ("can't read 3dview file <%s> in <%s>", name, mapset);
+		    G_fatal_error (_("can't read 3dview file <%s> in <%s>"), name, mapset);
 		if (ret == 0)
-		    G_fatal_error ("Old 3dview file. Region not found in <%s> in <%s>", name, mapset);
+		    G_fatal_error (_("Old 3dview file. Region not found in <%s> in <%s>"), name, mapset);
 
                  
 		window.north = v.vwin.north;
@@ -373,20 +404,14 @@ int main (int argc, char *argv[])
 		rast_ptr = parm.raster->answers;
 		for (; *rast_ptr != NULL; rast_ptr++)
 		{
-			char rast_name[100];
+			char rast_name[GNAME_MAX];
 			strcpy (rast_name, *rast_ptr);
 			mapset = G_find_cell2 (rast_name, "");
 			if (!mapset)
-			{
-				sprintf (msg, "raster map <%s> not found", rast_name);
-				G_fatal_error (msg);
-			}
+				G_fatal_error (_("raster map <%s> not found"), rast_name);
 			if (G_get_cellhd (rast_name, mapset, &temp_window) < 0)
-			{
-				sprintf (msg, "can't read header for <%s> in <%s>",
+				G_fatal_error (_("can't read header for <%s> in <%s>"),
 						rast_name, mapset);
-				G_fatal_error (msg);
-			}
 			if (!first) {
 				G_copy (&window, &temp_window, sizeof(window));
 				first = 1;
@@ -406,15 +431,15 @@ int main (int argc, char *argv[])
 				
 
 	/* raster3d= */
-	if (name = parm.raster3d->answer)
+	if ((name = parm.raster3d->answer))
 	{
 	    	G3D_Region win;
 		
 		if( (mapset = G_find_grid3(name, "")) == NULL )
-			G_fatal_error ( "3D raster map <%s> not found", name);
+			G_fatal_error (_("3D raster map <%s> not found"), name);
 		    
 		if ( G3d_readRegionMap (name, mapset, &win) < 0 ) 
-			G_fatal_error ( "can't read header for 3D raster <%s> in <%s>", name, mapset);
+			G_fatal_error (_("can't read header for 3D raster <%s> in <%s>"), name, mapset);
 
 		window.proj = win.proj;
 		window.zone = win.zone;
@@ -437,23 +462,20 @@ int main (int argc, char *argv[])
 	}
 
 	/* vect= */
-	if (name = parm.vect->answer)
+	if ((name = parm.vect->answer))
 	{
 		struct Map_info Map;
 		BOUND_BOX box;
 		
 		mapset = G_find_vector2 (name, "");
 		if (!mapset)
-		{
-			sprintf (msg, "vector map <%s> not found", name);
-			G_fatal_error (msg);
-		}
+			G_fatal_error (_("vector map <%s> not found"), name);
 
 		G_copy (&temp_window, &window, sizeof(window));
 
 		Vect_set_open_level (2);
 		if (2 != Vect_open_old (&Map, name, mapset))
-			G_fatal_error ("can't open vector file <%s> in <%s>", name, mapset);
+			G_fatal_error (_("can't open vector file <%s> in <%s>"), name, mapset);
 
 		Vect_get_map_box (&Map, &box );
 		window.north = box.N;
@@ -472,15 +494,16 @@ int main (int argc, char *argv[])
                       window.east = window.east + 0.5 * temp_window.ew_res;
                 }
 
-		G_align_window (&window, &temp_window);
+		if(flag.res_set->answer)
+		    G_align_window (&window, &temp_window);
 
 		Vect_close (&Map);
 	}
 
 	/* n= */
-	if (value = parm.north->answer)
+	if ((value = parm.north->answer))
 	{
-		if(i = nsew(value, "n+", "n-", "s+"))
+		if((i = nsew(value, "n+", "n-", "s+")))
 		{
 			if (!G_scan_resolution (value+2, &x, window.proj))
 				die(parm.north);
@@ -504,9 +527,9 @@ int main (int argc, char *argv[])
 	}
 
 	/* s= */
-	if (value = parm.south->answer)
+	if ((value = parm.south->answer))
 	{
-		if(i = nsew(value, "s+", "s-", "n-"))
+		if((i = nsew(value, "s+", "s-", "n-")))
 		{
 			if (!G_scan_resolution (value+2, &x, window.proj))
 				die(parm.south);
@@ -530,9 +553,9 @@ int main (int argc, char *argv[])
 	}
 
 	/* e= */
-	if (value = parm.east->answer)
+	if ((value = parm.east->answer))
 	{
-		if(i = nsew(value, "e+", "e-", "w+"))
+		if((i = nsew(value, "e+", "e-", "w+")))
 		{
 			if (!G_scan_resolution (value+2, &x, window.proj))
 				die(parm.east);
@@ -556,9 +579,9 @@ int main (int argc, char *argv[])
 	}
 
 	/* w= */
-	if (value = parm.west->answer)
+	if ((value = parm.west->answer))
 	{
-		if(i = nsew(value, "w+", "w-", "e-"))
+		if((i = nsew(value, "w+", "w-", "e-")))
 		{
 			if (!G_scan_resolution (value+2, &x, window.proj))
 				die(parm.west);
@@ -582,9 +605,9 @@ int main (int argc, char *argv[])
 	}
 
 	/* t= */
-	if (value = parm.top->answer)
+	if ((value = parm.top->answer))
 	{
-		if(i = nsew(value, "t+", "t-", "b+"))
+		if((i = nsew(value, "t+", "t-", "b+")))
 		{
 			if ( sscanf (value+2, "%lf", &x) != 1 )
 				die(parm.top);
@@ -608,9 +631,9 @@ int main (int argc, char *argv[])
 	}
 
 	/* b= */
-	if (value = parm.bottom->answer)
+	if ((value = parm.bottom->answer))
 	{
-		if(i = nsew(value, "b+", "b-", "t-"))
+		if((i = nsew(value, "b+", "b-", "t-")))
 		{
 			if (  sscanf (value+2, "%lf", &x) != 1 )
 				die(parm.bottom);
@@ -634,7 +657,7 @@ int main (int argc, char *argv[])
 	}
 
 	/* res= */
-	if (value = parm.res->answer)
+	if ((value = parm.res->answer))
 	{
 		if (!G_scan_resolution (value, &x, window.proj))
 			die(parm.res);
@@ -650,7 +673,7 @@ int main (int argc, char *argv[])
 	}
 
 	/* res3= */
-	if (value = parm.res3->answer)
+	if ((value = parm.res3->answer))
 	{
 		if (!G_scan_resolution (value, &x, window.proj))
 			die(parm.res);
@@ -660,107 +683,88 @@ int main (int argc, char *argv[])
 	}
 
 	/* nsres= */
-	if (value = parm.nsres->answer)
+	if ((value = parm.nsres->answer))
 	{
 		if (!G_scan_resolution (value, &x, window.proj))
 			die(parm.nsres);
 		window.ns_res = x;
 	
 		if (flag.res_set->answer) {
-			window.north = 2 * x * ( (int)(window.north/2/x));
-                	window.south = 2 * x * ( (int)(window.south/2/x));
+			window.north =  ceil(window.north/x) * x ;
+			window.south = floor(window.south/x) * x ;
 		}
 	}
 
 	/* ewres= */
-	if (value = parm.ewres->answer)
+	if ((value = parm.ewres->answer))
 	{
 		if (!G_scan_resolution (value, &x, window.proj))
 			die(parm.ewres);
 		window.ew_res = x;
 		
 		if (flag.res_set->answer) {
-			window.east =  2 * x * ( (int)(window.east/2/x));
-                	window.west =  2 * x * ( (int)(window.west/2/x));
+			window.east = ceil(window.east/x) * x ;
+			window.west = floor(window.west/x) * x ;
 		}
 	}
 
 	/* tbres= */
-	if (value = parm.tbres->answer)
+	if ((value = parm.tbres->answer))
 	{
 		if ( sscanf (value, "%lf", &x) != 1 )
 			die(parm.tbres);
 		window.tb_res = x;
 
 		if (flag.res_set->answer) {
-			window.top =  2 * x * ( (int)(window.top/2/x));
-                	window.bottom =  2 * x * ( (int)(window.bottom/2/x));
+			window.top = ceil(window.top/x) * x ;
+			window.bottom = floor(window.bottom/x) * x ;
 		}
 	}
 
 	/* zoom= */
-	if (name = parm.zoom->answer)
+	if ((name = parm.zoom->answer))
 	{
 		mapset = G_find_cell2 (name, "");
 		if (!mapset)
-		{
-			sprintf (msg, "raster map <%s> not found", name);
-			G_fatal_error (msg);
-		}
+			G_fatal_error (_("raster map <%s> not found"), name);
 		zoom (&window, name, mapset);
 	}
 
 	/* align= */
-	if (name = parm.align->answer)
+	if ((name = parm.align->answer))
 	{
 		mapset = G_find_cell2 (name, "");
 		if (!mapset)
-		{
-			sprintf (msg, "raster map <%s> not found", name);
-			G_fatal_error (msg);
-		}
+			G_fatal_error (_("raster map <%s> not found"), name);
 		if (G_get_cellhd (name, mapset, &temp_window) < 0)
-		{
-			sprintf (msg, "can't read header for <%s> in <%s>",
+			G_fatal_error (_("can't read header for <%s> in <%s>"),
 			    name, mapset);
-			G_fatal_error (msg);
-		}
-		if (err = G_align_window (&window, &temp_window))
-		{
-			sprintf (msg, "%s in %s: %s", name, mapset, err);
-			G_fatal_error (msg);
-		}
+		if ((err = G_align_window (&window, &temp_window)))
+			G_fatal_error (_("%s in %s: %s"), name, mapset, err);
 	}
 
 	/* save= */
-	if (name = parm.save->answer)
+	if ((name = parm.save->answer))
 	{
 		if (G_legal_filename (name) < 0)
-		{
-			sprintf (msg, "<%s> - illegal region name", name);
-			G_fatal_error (msg);
-		}
+			G_fatal_error (_("<%s> - illegal region name"), name);
 		G_copy (&temp_window, &window, sizeof(window));
 		adjust_window (&temp_window);
 		if (G__put_window (&temp_window, "windows", name) < 0)
-		{
-			sprintf (msg, "can't write region <%s>", name);
-			G_fatal_error (msg);
-		}
+			G_fatal_error (_("can't write region <%s>"), name);
 	}
 
 	adjust_window (&window);
 	if (set_flag)
 	{
 		if (G_put_window (&window) < 0)
-			G_fatal_error ("unable to update current region");
-	}
-	if (print_flag)
-	{
-		print_window (&window, print_flag, dist_flag, flag.z->answer);
+			G_fatal_error (_("unable to update current region"));
 	}
 
-	exit(0);
+	if (print_flag)
+	    print_window (&window, print_flag, dist_flag, flag.z->answer, flag.gprint->answer, flag.bbox->answer);
+
+	exit(EXIT_SUCCESS);
 }
 
 static void die(struct Option *parm)
@@ -768,7 +772,7 @@ static void die(struct Option *parm)
     /*
     G_usage();
     */
-    G_fatal_error("<%s=%s> ** invalid input **", parm->key, parm->answer);
+    G_fatal_error (_("<%s=%s> ** invalid input **"), parm->key, parm->answer);
 }
 
 static int nsew(char *value,char *a,char *b,char *c)
