@@ -1,16 +1,18 @@
-
+#include <grass/gis.h>
+#include <grass/glocale.h>
 #include "globals.h"
 
 #define PT Region.point
 #define SPT Region.saved_point
 
+
 int 
 save_region (void)
 {
   int i;
   
   if (!Region.area.completed || Region.view==NULL || Region.npoints<=0)
-    G_warning("Region is not complete, can not save!");
+    G_warning(_("Region is not complete, can not save."));
   else {
     for(i=0; i<Region.npoints; i++) {
       SPT[i].x = PT[i].x;
