@@ -1,8 +1,10 @@
 #include <stdlib.h>
-#include "imagery.h"
+#include <grass/imagery.h>
+#include <grass/glocale.h>
 #include "signature.h"
 #include "files.h"
 
+
 int get_training_classes (struct files *files, struct Signature *S)
 {
     int fd;
@@ -23,11 +25,12 @@ int get_training_classes (struct files *files, struct Signature *S)
 /* determine the categories in the map */
     I_init_signatures (S, files->nbands);
     G_init_cell_stats (&cell_stats);
-    fprintf (stderr, "Finding training classes ...");
+    G_message(_("Finding training classes ..."));
     for (row = 0; row < nrows; row++)
     {
 	G_percent (row, nrows, 2);
-	if (G_get_c_raster_row(fd, cell, row) < 0) exit(1);
+	if (G_get_c_raster_row(fd, cell, row) < 0)
+            G_fatal_error(_("Unable to read raster row."));
 	G_update_cell_stats (cell, ncols, &cell_stats);
     }
     G_percent (row, nrows, 2);
@@ -49,15 +52,11 @@ int get_training_classes (struct files *files, struct Signature *S)
 		n++;
 	    }
 	    else
-		fprintf (stderr,
-		    "WARNING: Training class [%d] only has one cell - this class will be ignored\n", cat);
+		G_warning(_("Training class [%d] only has one cell - this class will be ignored."), cat);
     }
 
-    if (n==0)
-    {
-	fprintf (stderr, "ERROR: training map has no classes\n");
-	exit(1);
-    }
+    if (n == 0)
+	G_fatal_error(_("Training map has no classes."));
 
     list = (CELL *) G_calloc (n, sizeof(CELL));
     n = 0;
@@ -70,7 +69,11 @@ int get_training_classes (struct files *files, struct Signature *S)
 
     files->ncats = n;
     files->training_cats = list;
-    fprintf (stderr, "%d class%s\n", files->ncats, files->ncats==1?"":"es" );
+
+    if (files->ncats == 1)
+        G_message(_("1 class."));
+    else
+        G_message(_("%d classes."), files->ncats);
 
     return 0;
 }
