@@ -1,10 +1,10 @@
 #include <math.h>
 #include <stdlib.h>
-#include "gis.h"
-#include "imagery.h"
+#include <grass/gis.h>
+#include <grass/imagery.h>
 #include "local_proto.h"
 
-#define PI 3.141592654
+#define PI M_PI
 #define ZERO 1e-10
 #define SMALLEST_SUBCLUST 1
 
