@@ -1,5 +1,5 @@
-#include "gis.h"
-#include "display.h"
+#include <grass/gis.h>
+#include <grass/display.h>
 
 int set_colors (struct Colors *colors)
 {
