@@ -1,7 +1,7 @@
 /* main.c */
-#include <stdio.h>
 #include <stdlib.h>
-#include "imagery.h"
+#include <stdio.h>
+#include <grass/imagery.h>
 #include "orthophoto.h"
 #include "local_proto.h"
 
