@@ -1,5 +1,5 @@
 #include <string.h>
-#include "raster.h"
+#include <grass/raster.h>
 #include "globals.h"
 #include "local_proto.h"
 
