@@ -22,10 +22,12 @@
 /***************************************************************************/
 /***************************************************************************/
 
-#include "stdio.h"
-#include "string.h"
-#include "math.h"
-#include "limits.h"
+#include <stdio.h>
+#include <string.h>
+#include <stdlib.h>
+#include <math.h>
+#include <limits.h>
+#include <grass/gis.h>
 
 /*
 #define MSDOS 1
@@ -47,7 +49,7 @@ typedef double DOUBLE;
 
 #else
 
-#include "imagery.h"
+#include <grass/imagery.h>
 
 typedef double DOUBLE;
 
