@@ -1,8 +1,10 @@
 #include <stdlib.h>
-#include "gis.h"
-#include "imagery.h"
+#include <grass/gis.h>
+#include <grass/glocale.h>
+#include <grass/imagery.h>
 #include "bouman.h"
 
+
 int parse (int argc, char *argv[], struct parms *parms)
 {
     struct Option *group, *subgroup, *sigfile, *output;
@@ -12,44 +14,44 @@ int parse (int argc, char *argv[], struct parms *parms)
 
     group = G_define_option();
     group->key = "group";
-    group->description = "imagery group";
+    group->description = _("imagery group");
     group->required = YES;
     group->type = TYPE_STRING;
     group->gisprompt = "old,group,group";
 
     subgroup = G_define_option();
     subgroup->key = "subgroup";
-    subgroup->description = "imagery subgroup";
+    subgroup->description = _("imagery subgroup");
     subgroup->required = YES;
     subgroup->type = TYPE_STRING;
 
     sigfile = G_define_option();
     sigfile->key = "signaturefile";
-    sigfile->description = "imagery signaturefile";
+    sigfile->description = _("imagery signaturefile");
     sigfile->required = YES;
     sigfile->type = TYPE_STRING;
 
     blocksize = G_define_option();
     blocksize->key = "blocksize";
-    blocksize->description = "size of submatrix to process at one time";
+    blocksize->description = _("size of submatrix to process at one time");
     blocksize->required = NO;
     blocksize->type = TYPE_INTEGER;
     blocksize->answer = "128";
 
     output = G_define_option();
     output->key = "output";
-    output->description = "output raster map";
+    output->description = _("output raster map");
     output->required = YES;
     output->type = TYPE_STRING;
     output->gisprompt = "new,cell,raster";
 
     ml = G_define_flag();
     ml->key = 'm';
-    ml->description = "Use maximum likelihood estimation (instead of smap)";
+    ml->description = _("Use maximum likelihood estimation (instead of smap)");
 
     quiet = G_define_flag();
     quiet->key = 'q';
-    quiet->description = "Run quietly";
+    quiet->description = _("Run quietly");
 
     if (G_parser(argc,argv)) exit(1);
 
@@ -61,17 +63,13 @@ int parse (int argc, char *argv[], struct parms *parms)
     parms->subgroup = subgroup->answer;
     parms->sigfile = sigfile->answer;
 
-/* check all the inputs */
+    /* check all the inputs */
     if (!I_find_group(parms->group))
-    {
-	fprintf (stderr, "ERROR: group [%s] not found\n", parms->group);
-	exit(1);
-    }
+        G_fatal_error(_("Group [%s] not found."), parms->group);
+
     if (!I_find_subgroup(parms->group, parms->subgroup))
-    {
-	fprintf (stderr, "ERROR: subgroup [%s] not found\n", parms->subgroup);
-	exit(1);
-    }
+        G_fatal_error(_("Subgroup [%s] not found."), parms->subgroup);
+
     if (sscanf(blocksize->answer,"%d",&parms->blocksize) !=1
     || parms->blocksize <= 8) parms->blocksize = 8;
 
