@@ -1,5 +1,5 @@
 /*
-* $Id: gis.h,v 1.10 2004/12/17 12:40:06 radim Exp $
+* $Id: gis.h,v 1.31.4.3 2007/06/28 16:21:00 markus Exp $
 *
 *****************************************************************************
 *
@@ -28,8 +28,8 @@
 #endif
 
 /* Grass and local include files */
-#include "config.h"
-#include "datetime.h"
+#include <grass/config.h>
+#include <grass/datetime.h>
 
 /*=========================== Constants/Defines ============================*/
 
@@ -74,6 +74,19 @@ static const char *GRASS_copyright __attribute__((unused))
 #define PROJECTION_FILE "PROJ_INFO"
 #define UNIT_FILE "PROJ_UNITS"
 
+/* define PI and friends */
+#undef M_PI
+#define M_PI    3.14159265358979323846 /* pi */
+
+#undef M_PI_2
+#define M_PI_2  1.57079632679489661923 /* pi/2 */
+
+#undef M_PI_4
+#define M_PI_4  0.78539816339744830962 /* pi/4 */
+
+/* epsilon (IEEE: 2.220446e-16) */
+#define GRASS_EPSILON 1.0e-15
+
 /* Location of envariment variables */
 #define G_VAR_GISRC    0
 #define G_VAR_MAPSET   1
@@ -88,13 +101,61 @@ static const char *GRASS_copyright __attribute__((unused))
 #define TYPE_STRING   3
 #define YES           1
 #define NO            0
+#define GISPROMPT_COLOR "color,grass,color"
+
+/* File/directory name lengths */
+#define GNAME_MAX 256
+#define GMAPSET_MAX 256
+
+
+/* Macros for type size independent integers                    */
+/* Use these for portability to ensure integers are truly 32bit */
+/* and are handled in a uniform manner                          */
+
+/* Convert integer to 4 bytes - little endian */
+#define serialize_int32_le(buf, x) do { \
+    (buf)[0] = ((x) >>  0) & 0xFF; \
+    (buf)[1] = ((x) >>  8) & 0xFF; \
+    (buf)[2] = ((x) >> 16) & 0xFF; \
+    (buf)[3] = ((x) >> 24) & 0xFF; \
+} while(0)
+
+/* Convert 4 bytes to an integer - little endian */
+#define deserialize_int32_le(buf) (((buf)[0] <<  0) | \
+                                   ((buf)[1] <<  8) | \
+                                   ((buf)[2] << 16) | \
+                                   ((buf)[3] << 24))
+
+/* Convert integer to 4 bytes - big endian */
+#define serialize_int32_be(buf, x) do { \
+    (buf)[0] = ((x) >> 24) & 0xFF; \
+    (buf)[1] = ((x) >> 16) & 0xFF; \
+    (buf)[2] = ((x) >>  8) & 0xFF; \
+    (buf)[3] = ((x) >>  0) & 0xFF; \
+} while(0)
+
+/* Convert 4 bytes to an integer - big endian */
+#define deserialize_int32_be(buf) (((buf)[0] << 24) | \
+                                   ((buf)[1] << 16) | \
+                                   ((buf)[2] <<  8) | \
+                                   ((buf)[3] <<  0))
 
 typedef enum {
     G_OPT_WHERE,    /* SQL where conditions */
 
-    G_OPT_R_INPUT,  /* old input raster */
-    G_OPT_R_OUTPUT, /* new output raster */
-    G_OPT_R_MAP,    /* old input raster */
+    G_OPT_R_INPUT,  /* old input raster map */
+    G_OPT_R_INPUTS,  /* old input raster maps */
+    G_OPT_R_OUTPUT, /* new output raster map */
+    G_OPT_R_MAP,    /* old input raster map */
+    G_OPT_R_MAPS,   /* old input rasters map */
+    G_OPT_R_BASE,   /* old input base raster map */
+    G_OPT_R_COVER,  /* old input cover raster map */
+    G_OPT_R_ELEV,  /* old input elevation raster map */
+    G_OPT_R_ELEVS,  /* old input elevation raster maps */
+
+    G_OPT_R3_INPUT,  /* old input raster3d map */
+    G_OPT_R3_INPUTS,  /* old input raster3d maps */
+    G_OPT_R3_OUTPUT, /* new output raster3d map */
 
     G_OPT_V_INPUT,  /* old input vector */
     G_OPT_V_OUTPUT, /* new output vector */
@@ -102,7 +163,11 @@ typedef enum {
     G_OPT_V_TYPE,   /* primitive type */
     G_OPT_V_FIELD,  /* field number */
     G_OPT_V_CAT,    /* one category */
-    G_OPT_V_CATS    /* more categories */
+    G_OPT_V_CATS,   /* more categories */
+
+    G_OPT_F_INPUT,  /* old input file */
+    G_OPT_F_OUTPUT, /* new output file */
+    G_OPT_F_SEP    /* data field separator */
 } STD_OPT;
 
 /* Message format */
@@ -118,6 +183,25 @@ typedef enum {
 #define DEFAULT_FG_COLOR "black"
 #define DEFAULT_BG_COLOR "white"
 
+/* for G_get_raster_sample(), INTERP_TYPE */
+#define UNKNOWN	  0
+#define NEAREST   1  /* nearest neighbor interpolation	*/
+#define BILINEAR  2  /* bilinear interpolation 		*/
+#define CUBIC     3  /* cubic interpolation 		*/
+
+/* for raster maps */
+#define GR_FATAL_EXIT    0
+#define GR_FATAL_PRINT   1
+#define GR_FATAL_RETURN  2
+
+/* Element types */
+enum {            /* Dir */
+    G_ELEMENT_RASTER = 1, /* cell */
+    G_ELEMENT_VECTOR = 2, /* vector */ 
+    G_ELEMENT_GROUP  = 3, /* group */ 
+    G_ELEMENT_REGION = 4  /* window */
+};
+
 /*=========================== Typedefs/Structures ==========================*/
 
 typedef int CELL;
@@ -127,6 +211,9 @@ extern CELL CELL_NODATA;
 
 typedef int RASTER_MAP_TYPE;
 
+/* for G_get_raster_sample() */
+typedef int INTERP_TYPE;
+
 struct Cell_head
 {
     int format;     	/* max numer of bytes per cell minus 1          */
@@ -212,10 +299,24 @@ struct Colors
     DCELL cmax;
 };
 
+
+typedef struct
+{
+    unsigned char r, g, b, a;  /* red, green, blue, and alpha */
+} RGBA_Color ;
+
+typedef RGBA_Color RGB_Color;
+
+/* RGBA_Color alpha presets */
+#define RGBA_COLOR_OPAQUE     255
+#define RGBA_COLOR_TRANSPARENT  0
+#define RGBA_COLOR_NONE         0
+
+
 struct Reclass
 {
-    char name[50];  	    /* name of cell file being reclassed    */
-    char mapset[50]; 	    /* mapset in which "name" is found      */
+    char name[GNAME_MAX];  	    /* name of cell file being reclassed    */
+    char mapset[GMAPSET_MAX]; 	    /* mapset in which "name" is found      */
     int type;	    	    /* type of reclass                      */
     int num;	    	    /* size of reclass table                */
     CELL min;	    	    /* table min    	    	    	    */
@@ -378,16 +479,16 @@ struct Histogram
 
 struct Range
 {
-    CELL min;		
-    CELL max;	
-    int first_time;     /* wether or not range was updated */
+    CELL min;
+    CELL max;
+    int first_time;     /* whether or not range was updated */
 };
 
 struct FPRange
 {
-    DCELL min;		
-    DCELL max;	
-    int first_time;     /* wether or not range was updated */
+    DCELL min;
+    DCELL max;
+    int first_time;     /* whether or not range was updated */
 };
 
 /*
@@ -451,6 +552,7 @@ struct Option                	    /* Structure that stores option info */
     char **answers;                 /* Option answers (for multiple=YES)*/
     struct Option *next_opt;        /* Pointer to next option struct    */
     char *gisprompt;                /* Interactive prompt guidance      */
+    char *guisection;               /* GUI Layout guidance: ';' delimited heirarchical tree position */
     int (*checker)();               /* Routine to check answer or NULL  */
     int count;
 };
@@ -461,6 +563,7 @@ struct Flag                 	    /* Structure that stores flag info  */
     char answer;                    /* Stores flag state: 0/1           */
     char *label;                    /* Optional short label, used in GUI as item label */
     char *description;              /* String describing flag meaning   */
+    char *guisection;               /* GUI Layout guidance: ';' delimited heirarchical tree position */
     struct Flag *next_flag;         /* Pointer to next flag struct      */
 };
 
@@ -468,6 +571,7 @@ struct GModule                      /* Structure that stores module info  */
 {
     char *label;                    /* Optional short description for GUI */
     char *description;              /* String describing module */
+    char *keywords;                 /* Keywords describing module */
 	/* further items are possible: author(s), version */
     int overwrite; /* overwrite old files */
 };
@@ -482,6 +586,6 @@ struct TimeStamp
 
 /* Since there are so many prototypes for the gis library they are stored */
 /* in the file gisdefs.h */
-#include "gisdefs.h"
+#include <grass/gisdefs.h>
 
 #endif /* GRASS_GIS_H */
