@@ -34,8 +34,9 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include "linkm.h"
-#include "bitmap.h"
+#include <grass/linkm.h>
+#include <grass/bitmap.h>
+
 
 #define BM_col_to_byte(x)  ((x)/8)
 #define BM_col_to_bit(x)   ((x)%8)
@@ -43,6 +44,7 @@
 static int Mode = BM_FLAT;
 static int Size = 1;
 
+
 /*!
  * \brief Create bitmap of dimension x/y and return structure token. 
  * Bitmap is initialized to all zeros
@@ -51,6 +53,7 @@ static int Size = 1;
  *  \param int y
  *  \return struct BM or NULL on error
  */
+
 struct BM *BM_create (int x, int y)
 {
     struct BM *map;
@@ -63,7 +66,7 @@ struct BM *BM_create (int x, int y)
 
     map->bytes = (x+7)/8;
 
-    if (NULL == (map->data = (unsigned char *) calloc ( map->bytes * y, 1 )))
+    if (NULL == (map->data = (unsigned char *)calloc (map->bytes * y, sizeof(char))))
 	return (NULL);
 
     map->rows = y;
@@ -88,9 +91,11 @@ BM_destroy (struct BM *map)
 
     free (map->data);
     free (map);
+
     return 0;
 }
 
+
 /*
 **  Caller can specify type of data structure to use for bitmap, as
 **   well as the size of the data values.  Currently since this is
@@ -113,10 +118,36 @@ BM_destroy (struct BM *map)
 **   If error it will print a warning message to stderr and continue
 **   continue by running but will not change the option in error.
 */
+
+/*!
+ * \brief
+ *
+ * Specify the type of data structure to use for bitmap.
+ * 'mode' can be either BM_FLAT or BM_SPARSE:
+ *
+ * BM_FLAT is a basic packed bitmap - eight values stored per byte
+ * thus creating a 1:8 compression over using char arrays and a
+ * 1:32 compression over using CELL arrays.
+ *
+ * BM_SPARSE is a linked array of values. This is much more efficient
+ * for large, very sparse arrays.  It is slower to access, especially 
+ * for writing, but can save several orders of magnitude of memory on
+ * large bitmaps.
+ *
+ * NOTE: At this time 'size' must be passed a value of 1
+ *
+ * returns 0 on success or -1 on error
+ *
+ *  \param int mode
+ *  \param int size
+ *  \return int
+ */
+
 int 
 BM_set_mode (int mode, int size)
 {
     int ret = 0;
+
     switch (mode) {
 	case BM_FLAT:
 	case BM_SPARSE:
@@ -138,11 +169,20 @@ BM_set_mode (int mode, int size)
 }
 
 
-/*
-** Set array value 
-**
-** returns 0;
-*/
+/*!
+ * \brief
+ *
+ * Sets bitmap value to 'val' at location 'x' 'y'
+ *
+ * Returns 0 on success
+ *
+ *  \param map
+ *  \param x
+ *  \param y
+ *  \param val
+ *  \return int
+ */
+
 int 
 BM_set (struct BM *map, int x, int y, int val)
 {
@@ -163,11 +203,20 @@ BM_set (struct BM *map, int x, int y, int val)
     return 0;
 }
 
-/*
-** return array value 
-**
-**  returns 0 or 1  or -1 on error
-*/
+
+/*!
+ * \brief
+ *
+ * Gets 'val' from the bitmap
+ *
+ * Returns 0 or 1 on success or -1 on error
+ *
+ *  \param map
+ *  \param x
+ *  \param y
+ *  \return int
+ */
+
 int 
 BM_get (struct BM *map, int x, int y)
 {
@@ -184,24 +233,41 @@ BM_get (struct BM *map, int x, int y)
     return byte >> BM_col_to_bit(x) & 0x01;
 }
 
-/*
-**  returns size in bytes that bitmap is taking up.
-*/
+
+/*!
+ * \brief
+ *
+ * Returns size in bytes that bitmap is taking up.
+ *
+ *  \param map
+ *  \return int
+ */
+
 int 
 BM_get_map_size (struct BM *map)
 {
     if (map->sparse)
 	return BM_get_map_size_sparse(map);
+
     return map->bytes * map->rows;
 }
 
-/*
-** Write bitmap out to file.
-**  Expects open file pointer fp and existing map structure 
-**  caller is responsible to open and close fp
-**
-**  returns 0 or -1 on error
-*/
+
+/*!
+ * \brief
+ *
+ * Write bitmap out to file
+ *
+ * Expects open file pointer 'fp' and existing map structure.
+ * Caller is responsible to open and close 'fp'.
+ *
+ * Returns 0 or -1 on error
+ *
+ *  \param fp
+ *  \param map
+ *  \return int
+ */
+
 int BM_file_write (FILE *fp, struct BM *map)
 {
     char c;
@@ -211,31 +277,39 @@ int BM_file_write (FILE *fp, struct BM *map)
 	return BM_file_write_sparse (fp, map);
 
     c = BM_MAGIC;
-    fwrite (&c, 1, 1, fp);
+    fwrite (&c, sizeof(char), sizeof(char), fp);
 
-    fwrite (BM_TEXT, BM_TEXT_LEN, 1, fp);
+    fwrite (BM_TEXT, BM_TEXT_LEN, sizeof(char), fp);
 
     c = BM_FLAT;
-    fwrite (&c, 1, 1, fp);
+    fwrite (&c, sizeof(char), sizeof(char), fp);
 
-    fwrite (&(map->rows), sizeof (map->rows), 1, fp);
+    fwrite (&(map->rows), sizeof (map->rows), sizeof(char), fp);
 
-    fwrite (&(map->cols), sizeof (map->cols), 1, fp);
+    fwrite (&(map->cols), sizeof (map->cols), sizeof(char), fp);
 
     for (i = 0 ; i < map->rows ; i++)
-	if(map->bytes != fwrite (&(map->data[i*map->bytes]), 1, map->bytes, fp))
+	if(map->bytes != fwrite (&(map->data[i*map->bytes]), sizeof(char), map->bytes, fp))
 	    return -1;
     fflush (fp);
 
     return 0;
 }
 
-/*
-**  Create map structure and load it from file
-**  File should previously been created by BM_file_write()
-**
-**  returns struct BM *  or NULL on error.
-*/
+
+/*!
+ * \brief
+ *
+ * Create map structure and load it from file
+ *
+ * 'fp' should previously been created by <b>BM_file_write()</b>
+ *
+ * Returns struct BM * or NULL on error
+ *
+ *  \param fp
+ *  \return struct BM
+ */
+
 struct BM *BM_file_read (FILE *fp)
 {
     struct BM *map;
@@ -248,19 +322,19 @@ struct BM *BM_file_read (FILE *fp)
     if (NULL == (map =  (struct BM *) malloc (sizeof (struct BM))))
 	return (NULL);
 
-    fread (&c, 1, 1, fp);
+    fread (&c, sizeof(char), sizeof(char), fp);
     if (c != BM_MAGIC)
 	return NULL;
 
-    fread (buf, BM_TEXT_LEN, 1, fp);
+    fread (buf, BM_TEXT_LEN, sizeof(char), fp);
 
-    fread (&c, 1, 1, fp);
+    fread (&c, sizeof(char), sizeof(char), fp);
     map->sparse = c;
 
 
-    fread (&(map->rows), sizeof (map->rows), 1, fp);
+    fread (&(map->rows), sizeof (map->rows), sizeof(char), fp);
 
-    fread (&(map->cols), sizeof (map->cols), 1, fp);
+    fread (&(map->cols), sizeof (map->cols), sizeof(char), fp);
 
     map->bytes = (map->cols+7)/8;
 
@@ -272,7 +346,7 @@ struct BM *BM_file_read (FILE *fp)
 
 
     for (i = 0 ; i < map->rows ; i++)
-	if(map->bytes != fread (&(map->data[i*map->bytes]), 1, map->bytes, fp))
+	if(map->bytes != fread (&(map->data[i*map->bytes]), sizeof(char), map->bytes, fp))
 	    return NULL;
 
 
@@ -291,7 +365,7 @@ readsparse:
     for (y = 0 ; y < map->rows ; y++)
     {
 	/* first get number of links */
-	fread (&i, sizeof (i), 1, fp);
+	fread (&i, sizeof (i), sizeof(char), fp);
 	cnt = i;
 
 
@@ -311,10 +385,10 @@ readsparse:
 		p = p2;
 	    }
 
-	    fread (&n, sizeof (n), 1, fp);
+	    fread (&n, sizeof (n), sizeof(char), fp);
 	    p->count = n;
 
-	    fread (&n, sizeof (n), 1, fp);
+	    fread (&n, sizeof (n), sizeof(char), fp);
 	    p->val = n;
 	    p->next = NULL;
 	}
