@@ -3,8 +3,8 @@
 #include <stdlib.h>
 #include <dirent.h>
 #include <unistd.h>
-#include "dbmi.h"
-#include "gis.h"
+#include <grass/dbmi.h>
+#include <grass/gis.h>
 
 static
 char *dbmscap_files[] = {
@@ -69,8 +69,8 @@ db_has_dbms()
  \param 
 */
 void
-db_copy_dbmscap_entry(dst, src)
-    dbDbmscap *dst, *src;
+db_copy_dbmscap_entry (dbDbmscap *dst, dbDbmscap *src)
+
 {
     strcpy (dst->driverName, src->driverName);
     strcpy (dst->comment, src->comment);
@@ -155,11 +155,18 @@ db_read_dbmscap()
 /* START OF NEW CODE FOR SEARCH IN $(GISBASE)/driver/db/ */
     
     /* opend db drivers directory */
+#ifdef __MINGW32__
+    dirpath = G_malloc ( strlen("\\driver\\db\\") + strlen(G_gisbase()) + 1 );
+    sprintf ( dirpath, "%s\\driver\\db\\", G_gisbase());
+#else
     G_asprintf (&dirpath, "%s/driver/db/", G_gisbase());
+#endif
+
+    G_debug ( 2, "opendir %s\n", dirpath );
     dir = opendir(dirpath);
     if (dir == NULL)
     {
-	db_syserror (dirpath);
+	db_syserror ("Cannot open drivers directory");
 	return (dbDbmscap *) NULL;
     }
     G_free (dirpath);
@@ -175,7 +182,13 @@ db_read_dbmscap()
 	/* Remove '.exe' from name (windows extension) */
 	name = G_str_replace ( ent->d_name, ".exe", "" );
 	
+#ifdef __MINGW32__
+        dirpath = G_malloc ( strlen("\\driver\\db\\") 
+                  + strlen(G_gisbase()) + strlen(ent->d_name) + 1 );
+        sprintf ( dirpath, "%s\\driver\\db\\%s", G_gisbase(), ent->d_name);
+#else
         G_asprintf (&dirpath, "%s/driver/db/%s", G_gisbase(),ent->d_name);
+#endif
 	add_entry (&list, name, dirpath, "");
 	G_free (name);
 	G_free (dirpath);
@@ -187,11 +200,8 @@ db_read_dbmscap()
 }
 
 static void
-add_entry (list, name, startup, comment)
-    dbDbmscap **list;
-    char *name;
-    char *startup;
-    char *comment;
+add_entry  (dbDbmscap **list, char *name, char *startup, char *comment)
+
 {
     dbDbmscap *head, *cur, *tail;
 
@@ -227,8 +237,8 @@ add_entry (list, name, startup, comment)
  \param 
 */
 void
-db_free_dbmscap (list)
-    dbDbmscap *list;
+db_free_dbmscap  (dbDbmscap *list)
+
 {
     dbDbmscap *next, *cur;
 
