@@ -4,8 +4,8 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
-#include "gis.h"
-#include "dbmi.h"
+#include <grass/gis.h>
+#include <grass/dbmi.h>
 
 typedef struct {
     char *driver;
@@ -86,6 +86,7 @@ read_file ( LOGIN *login )
     while ( fgets (buf, 2000, fd) ) {
 	G_chop ( buf );
 	
+	usr[0] = pwd[0] = '\0';
 	ret = sscanf (buf, "%[^ ] %[^ ] %[^ ] %[^ ]", dr, db, usr, pwd);
 
 	G_debug ( 3, "ret = %d : %s %s %s %s", ret, dr, db, usr, pwd);
@@ -123,7 +124,9 @@ write_file ( LOGIN *login )
     if (fd == NULL)
 	return -1;
 
-    fchmod ( fileno(fd), S_IRUSR | S_IWUSR );
+    /* fchmod is not available on Windows */
+    /* fchmod ( fileno(fd), S_IRUSR | S_IWUSR ); */
+    chmod ( file, S_IRUSR | S_IWUSR );
     
     for ( i = 0; i < login->n; i++ ) { 
 	fprintf ( fd, "%s %s", login->data[i].driver, login->data[i].database );
