@@ -1,4 +1,4 @@
-#include "dbmi.h"
+#include <grass/dbmi.h>
 
 /*!
  \fn 
@@ -6,8 +6,8 @@
  \return 
  \param 
 */
-db_sqltype_to_Ctype(sqltype)
-    int sqltype;
+db_sqltype_to_Ctype (int sqltype)
+
 {	
     switch (sqltype)
     {
