@@ -1,6 +1,7 @@
 #include <stdio.h>
 #include <string.h>
-#include "dbmi.h"
+#include <grass/gis.h>
+#include <grass/dbmi.h>
 
 /*!
  \fn 
@@ -9,10 +10,8 @@
  \param 
 */
 int
-db_convert_Cstring_to_value (Cstring, sqltype, value)
-    char *Cstring;
-    int sqltype;
-    dbValue *value;
+db_convert_Cstring_to_value  (char *Cstring, int sqltype, dbValue *value)
+
 {
     int i;
     double d;
@@ -47,10 +46,8 @@ db_convert_Cstring_to_value (Cstring, sqltype, value)
  \param 
 */
 int
-db_convert_value_to_string(value, sqltype, string)
-    dbValue *value;
-    int sqltype;
-    dbString *string;
+db_convert_value_to_string (dbValue *value, int sqltype, dbString *string)
+
 {
     char buf[64];
     char *bp;
@@ -69,6 +66,7 @@ db_convert_value_to_string(value, sqltype, string)
 	    break;
 	case DB_C_TYPE_DOUBLE:
 	    sprintf (buf, "%lf",db_get_value_double(value));
+	    G_trim_decimal(buf);
 	    break;
 	case DB_C_TYPE_STRING:
 	    bp = db_get_value_string(value);
