@@ -1,6 +1,6 @@
 #include <stdlib.h>
 #include <stdio.h>
-#include "gis.h"
+#include <grass/gis.h>
 
 /*!
  \fn 
