@@ -1,4 +1,4 @@
-#include "dbmi.h"
+#include <grass/dbmi.h>
 
 /*!
  \fn 
@@ -7,8 +7,8 @@
  \param 
 */
 void
-db_zero(s, n)
-    void *s;
+db_zero (void *s, int  n)
+
 {
     char *c = (char *) s;
     while (n-- > 0)
