@@ -1,4 +1,4 @@
-#include "dbmi.h"
+#include <grass/dbmi.h>
 #include "macros.h"
 
 /*!
@@ -7,8 +7,8 @@
  \return 
  \param 
 */
-db_update (cursor)
-    dbCursor *cursor;
+db_update  (dbCursor *cursor)
+
 {
     int ret_code;
 
