@@ -1,7 +1,12 @@
 #include <stdlib.h>
-#include <sys/types.h>
+
+#ifdef __MINGW32__
+#include <process.h>
+#else
 #include <sys/wait.h>
-#include "dbmi.h"
+#endif
+#include <grass/dbmi.h>
+#include "macros.h"
 
 /*!
  \fn 
@@ -17,12 +22,17 @@
  * an argument, instead of returning the pointer to allocated
  * then there would be no hidden free required
  */
-db_shutdown_driver (driver)
-    dbDriver *driver;
+db_shutdown_driver  (dbDriver *driver)
+
 {
     int pid;
     int status;
 
+#ifdef __MINGW32__
+    db__set_protocol_fds (driver->send, driver->recv);
+    DB_START_PROCEDURE_CALL (DB_PROC_SHUTDOWN_DRIVER);
+#endif
+
 /* close the communication FILEs */
     fclose (driver->send);
     fclose (driver->recv);
@@ -32,8 +42,15 @@ db_shutdown_driver (driver)
 
 /* wait for the driver to finish */
     status = -1;
+
+#ifdef __MINGW32__
+    /* TODO: convert status to something like from wait? */
+    _cwait( &status, driver->pid, WAIT_CHILD ); 
+#else
+    /* TODO: Should not be here waitpid() ? */
     while ((pid = wait(&status)) > 0 && pid != driver->pid)
 	 {}
+#endif
 
     driver->pid = 0;
 
