@@ -1,5 +1,5 @@
 #include <stdlib.h>
-#include "dbmi.h"
+#include <grass/dbmi.h>
 #include "macros.h"
 #include "dbstubs.h"
 
