@@ -1,5 +1,5 @@
-#include "gis.h"
-#include "glocale.h"
+#include <grass/gis.h>
+#include <grass/glocale.h>
 #include <unistd.h>
 #include <ctype.h>
 #include <string.h>
@@ -452,8 +452,8 @@ read_ellipsoid_table(int fatal)
     
     (fatal ? G_fatal_error : G_warning)(
 	(err > 1)
-	    ? _("Lines%s of ellipsoid table file <%s> are invalid")
-	    : _("Line%s of ellipsoid table file <%s> is invalid"),
+	    ? _("Lines %s of ellipsoid table file <%s> are invalid")
+	    : _("Line %s of ellipsoid table file <%s> is invalid"),
 	badlines, file);
 
     return 0;
