@@ -57,7 +57,24 @@
  *  opt3->options    = "0-99999",
  *  opt3->description= "Number to test parser" ;
  *
- * parser() will respond to the following command lines as described:
+ *
+ * The only functions which can legitimately be called before G_parser() are:
+ *   G_gisinit()
+ *   G_no_gisinit()
+ *   G_define_module()
+ *   G_define_flag()
+ *   G_define_option()
+ *   G_define_standard_option()
+ *   G_disable_interactive()
+ *
+ * The usual order is:
+ *   G_gisinit()
+ *   G_define_module()
+ *   G_define_{flag,option}()
+ *   G_parser()
+ *
+ *
+ * G_parser() will respond to the following command lines as described:
  *
  * command      (No command line arguments)
  *    Parser enters interactive mode.
@@ -95,19 +112,25 @@
  ***************************************************************************
 */
 
+#include <grass/config.h>
+
+#if defined(HAVE_LANGINFO_H)
+#include <langinfo.h>
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
 #include <unistd.h>
 #include <stdarg.h>
-#include "gis.h"
-#include "glocale.h"
+#include <grass/gis.h>
+#include <grass/glocale.h>
 
 #define BAD_SYNTAX  1
 #define OUT_OF_RANGE    2
 #define MISSING_VALUE   3
-
+#define KEYLENGTH 64
 
 static int interactive_ok = 1 ;
 static int n_opts = 0 ;
@@ -122,7 +145,7 @@ static struct Option *current_option ;
 
 static struct GModule module_info; /* general information on the corresponding module */
 
-static char *pgm_name = NULL;
+static const char *pgm_name = NULL;
 
 struct Item
 {
@@ -135,7 +158,7 @@ static struct Item first_item ;
 static struct Item *current_item ;
 static int n_items = 0 ;
 static int show_options(int ,char *);
-static int show(char *,int);
+static int show(const char *,int);
 static int set_flag (int);
 static int contains (char *,int);
 static int set_option( char *);
@@ -152,6 +175,7 @@ static int interactive( char *);
 static int interactive_flag( struct Flag *);
 static int interactive_option( struct Option *);
 static int gis_prompt( struct Option *, char *);
+static int split_gisprompt (const char *, char *, char *, char *);
 
 static void G_gui (void);
 static void G_tcltk (void);
@@ -274,6 +298,7 @@ G_define_option (void)
 	opt->opts      = NULL ;
 	opt->description  = NULL ;
 	opt->descriptions = NULL ;
+	opt->guisection   = NULL ;
 
 	current_option = opt ;
 	n_opts++ ;
@@ -297,10 +322,27 @@ G_define_option (void)
 	return(opt) ;
 }
 
+
+/*!
+ * \brief Create standardised Option structure
+ *
+ * This function will create a standardised Option structure
+ * defined by parameter opt. A list of valid parameters can be found in gis.h.
+ * It allocates memory for the Option structure and returns a pointer to
+ * this memory (of <i>type struct Option *).</i>
+ *
+ * If an invalid parameter was specified a empty Option structure will be returned (not NULL).
+ *
+ * \param opt
+ *
+ *  \return Option * 
+ */
+
+
 struct Option *
 G_define_standard_option (int opt)
 {
-    struct Option *Opt ;
+    struct Option *Opt;
     
     Opt = G_define_option();
 
@@ -308,52 +350,139 @@ G_define_standard_option (int opt)
 	case G_OPT_WHERE:
 	    Opt->key          = "where";
 	    Opt->type         = TYPE_STRING;
+	    Opt->key_desc     = "sql_query";
 	    Opt->required     = NO;
 	    Opt->description  = _("WHERE conditions of SQL statement without 'where' keyword. (example: income < 1000 and inhab >= 10000)");
 	    break;
 	    
+	/*raster maps*/    
 	case G_OPT_R_INPUT:
 	    Opt->key          = "input";
 	    Opt->type         = TYPE_STRING;
+	    Opt->key_desc     = "name";
 	    Opt->required     = YES;
 	    Opt->gisprompt    = "old,cell,raster";
-	    Opt->description  = _("Name of input raster");
+	    Opt->description  = _("Name of input raster map");
+	    break;
+	case G_OPT_R_INPUTS:
+	    Opt->key          = "input";
+	    Opt->type         = TYPE_STRING;
+	    Opt->key_desc     = "name";
+	    Opt->required     = YES;
+	    Opt->multiple     = YES;
+	    Opt->gisprompt    = "old,cell,raster";
+	    Opt->description  = _("Name of input raster map(s)");
 	    break;
 	case G_OPT_R_OUTPUT:
 	    Opt->key          = "output";
 	    Opt->type         = TYPE_STRING;
+	    Opt->key_desc     = "name";
 	    Opt->required     = YES;
 	    Opt->gisprompt    = "new,cell,raster";
-	    Opt->description  = _("Name of output raster");
+	    Opt->description  = _("Name for output raster map");
 	    break;
 	case G_OPT_R_MAP:
 	    Opt->key          = "map";
 	    Opt->type         = TYPE_STRING;
+	    Opt->key_desc     = "name";
 	    Opt->required     = YES;
 	    Opt->gisprompt    = "old,cell,raster";
-	    Opt->description  = _("Name of input raster");
+	    Opt->description  = _("Name of input raster map");
 	    break;
-	    
+	case G_OPT_R_MAPS:
+	    Opt->key          = "map";
+	    Opt->type         = TYPE_STRING;
+	    Opt->key_desc     = "name";
+	    Opt->required     = YES;
+	    Opt->multiple     = YES;
+	    Opt->gisprompt    = "old,cell,raster";
+	    Opt->description  = _("Name of input raster map(s)");
+	    break;
+	case G_OPT_R_BASE:
+	    Opt->key          = "base";
+	    Opt->type         = TYPE_STRING;
+	    Opt->key_desc     = "name";
+	    Opt->required     = YES;
+	    Opt->gisprompt    = "old,cell,raster";
+	    Opt->description  = _("Name of base raster map");
+	    break;
+	case G_OPT_R_COVER:
+	    Opt->key          = "cover";
+	    Opt->type         = TYPE_STRING;
+	    Opt->key_desc     = "name";
+	    Opt->required     = YES;
+	    Opt->gisprompt    = "old,cell,raster";
+	    Opt->description  = _("Name of cover raster map");
+	    break;
+	case G_OPT_R_ELEV:
+	    Opt->key          = "elevation";
+	    Opt->type         = TYPE_STRING;
+	    Opt->key_desc     = "name";
+	    Opt->required     = YES;
+	    Opt->gisprompt    = "old,cell,raster";
+	    Opt->description  = _("Name of elevation raster map");
+	    break;
+	case G_OPT_R_ELEVS:
+	    Opt->key          = "elevation";
+	    Opt->type         = TYPE_STRING;
+	    Opt->key_desc     = "name";
+	    Opt->required     = YES;
+	    Opt->multiple     = YES;
+	    Opt->gisprompt    = "old,cell,raster";
+	    Opt->description  = _("Name of elevation raster map(s)");
+	    break;
+
+	/*g3d maps*/    
+    	case G_OPT_R3_INPUT:
+	    Opt->key          = "input";
+	    Opt->type         = TYPE_STRING;
+	    Opt->key_desc     = "name";
+	    Opt->required     = YES;
+	    Opt->gisprompt    = "old,grid3,3d-raster";
+	    Opt->description  = _("Name of input raster3d map");
+	    break;
+	case G_OPT_R3_INPUTS:
+	    Opt->key          = "input";
+	    Opt->type         = TYPE_STRING;
+	    Opt->key_desc     = "name";
+	    Opt->required     = YES;
+	    Opt->multiple     = YES;
+	    Opt->gisprompt    = "old,grid3,3d-raster";
+	    Opt->description  = _("Name of input raster3d map(s)");
+	    break;
+	case G_OPT_R3_OUTPUT:
+	    Opt->key          = "output";
+	    Opt->type         = TYPE_STRING;
+	    Opt->key_desc     = "name";
+	    Opt->required     = YES;
+	    Opt->gisprompt    = "new,grid3,3d-raster";
+	    Opt->description  = _("Name for output raster3d map");
+	    break;
+
+	/*vector maps*/    
 	case G_OPT_V_INPUT:
 	    Opt->key          = "input";
 	    Opt->type         = TYPE_STRING;
+	    Opt->key_desc     = "name";
 	    Opt->required     = YES;
 	    Opt->gisprompt    = "old,vector,vector";
-	    Opt->description  = _("Name of input vector");
+	    Opt->description  = _("Name of input vector map");
 	    break;
 	case G_OPT_V_OUTPUT:
 	    Opt->key          = "output";
 	    Opt->type         = TYPE_STRING;
+	    Opt->key_desc     = "name";
 	    Opt->required     = YES;
 	    Opt->gisprompt    = "new,vector,vector";
-	    Opt->description  = _("Name of output vector");
+	    Opt->description  = _("Name for output vector map");
 	    break;
 	case G_OPT_V_MAP:
 	    Opt->key          = "map";
 	    Opt->type         = TYPE_STRING;
+	    Opt->key_desc     = "name";
 	    Opt->required     = YES;
 	    Opt->gisprompt    = "old,vector,vector";
-	    Opt->description  = _("Name of input vector");
+	    Opt->description  = _("Name of input vector map");
 	    break;
 	case G_OPT_V_TYPE:
 	    Opt->key          = "type";
@@ -380,10 +509,37 @@ G_define_standard_option (int opt)
 	case G_OPT_V_CATS:
 	    Opt->key          = "cats";
 	    Opt->type         = TYPE_STRING;
+	    Opt->key_desc     = "range";
 	    Opt->required     = NO;
-	    Opt->label        = _("Category values.");
+	    Opt->label        = _("Category values");
 	    Opt->description  = _("Example: 1,3,7-9,13");
 	    break;
+
+	/* files */
+	case G_OPT_F_INPUT:
+	    Opt->key          = "input";
+	    Opt->type         = TYPE_STRING;
+	    Opt->key_desc     = "name";
+	    Opt->required     = YES;
+	    Opt->gisprompt    = "old_file,file,input";
+	    Opt->description  = _("Name of input file");
+	    break;
+	case G_OPT_F_OUTPUT:
+	    Opt->key          = "output";
+	    Opt->type         = TYPE_STRING;
+	    Opt->key_desc     = "name";
+	    Opt->required     = YES;
+	    Opt->gisprompt    = "new_file,file,output";
+	    Opt->description  = _("Name for output file");
+	    break;
+	case G_OPT_F_SEP:
+	    Opt->key          = "fs";
+	    Opt->type         = TYPE_STRING;
+	    Opt->key_desc     = "character";
+	    Opt->required     = NO;
+	    Opt->answer       = "|";
+	    Opt->description  = _("Field separator");
+	    break;
     }
 
     return(Opt);
@@ -434,6 +590,7 @@ int G_parser (int argc, char **argv)
 	char *ptr ;
 	int i;
 	struct Option *opt ;
+	char force_gui = FALSE;
 
 	error = 0 ;
 	need_first_opt = 1 ;
@@ -554,7 +711,7 @@ int G_parser (int argc, char **argv)
 			strcmp(argv[1], "--help") == 0)
 		{
 			G_usage();
-			return -1;
+			exit(EXIT_SUCCESS);
 		}
 
 		/* If first arg is "--interface-description" then print out
@@ -562,22 +719,15 @@ int G_parser (int argc, char **argv)
 		if (strcmp(argv[1],"--interface-description") == 0)
 		{
 			G_usage_xml();
-			return -1;
+			exit(EXIT_SUCCESS);
 		}
 
 		/* If first arg is "--html-description" then print out
-		 * a xml description of the task */
+		 * a html description of the task */
 		if (strcmp(argv[1],"--html-description") == 0)
 		{
 			G_usage_html();
-			return -1;
-		}
-
-		/* If first arg is "--ui" then run G_gui() */
-		if (strcmp(argv[1],"--ui") == 0)
-		{
-			G_gui();
-			return -1;
+			exit(EXIT_SUCCESS);
 		}
 
 		/* If first arg is "--tcltk" then then generate
@@ -585,7 +735,7 @@ int G_parser (int argc, char **argv)
 		if (strcmp(argv[1],"--tcltk") == 0)
 		{
 			G_tcltk();
-			exit(0);
+			exit(EXIT_SUCCESS);
 		}
 
 		/* Loop thru all command line arguments */
@@ -595,10 +745,17 @@ int G_parser (int argc, char **argv)
 			ptr = *(++argv) ;
 
 			/* Overwrite option */
-			if ( strncmp(ptr,"--o", 3) == 0 || strncmp(ptr,"--overwrite",11) == 0 )
+			if ( strcmp(ptr,"--o") == 0 || strcmp(ptr,"--overwrite") == 0 )
 			{
 			    overwrite = 1;
 			}
+
+			/* Force gui to come up */
+			else if ( strcmp(ptr,"--ui") == 0 )
+			{
+			    force_gui = TRUE;
+			}
+
 			/* If we see a flag */
 			else if(*ptr == '-')
 			{
@@ -620,7 +777,7 @@ int G_parser (int argc, char **argv)
 				need_first_opt = 0 ;
 			}
 
-  	        /* If we see the non valid argument (no "=", just argument) */
+			/* If we see the non valid argument (no "=", just argument) */
 			else if (contains(ptr, '=') == 0)
 			{
 				fprintf(stderr, _("Sorry <%s> is not a valid option\n"), ptr);
@@ -630,6 +787,12 @@ int G_parser (int argc, char **argv)
 		}
 	}
 
+	/* Run the gui if it was specifically requested */
+	if (force_gui) {
+		G_gui();
+		return -1;
+	}
+
 	/* Split options where multiple answers are OK */
 	split_opts() ;
 
@@ -657,6 +820,33 @@ int G_parser (int argc, char **argv)
 }
 
 
+static int uses_new_gisprompt (void)
+{
+	struct Option *opt ;
+	char age[KEYLENGTH] ;
+	char element[KEYLENGTH] ;
+	char desc[KEYLENGTH] ;
+
+	/* figure out if any of the options use a "new" gisprompt */
+	/* This is to see if we should spit out the --o flag      */
+	if(n_opts)
+	{
+		opt= &first_option;
+		while(opt != NULL)
+		{
+			if ( opt->gisprompt )
+			{
+				split_gisprompt (opt->gisprompt, age, element, desc) ;
+				if (strcmp (age, "new") == 0)
+					return 1;
+			}
+			opt=opt->next_opt;
+		}
+	}
+
+	return 0;
+}
+
 /*!
  * \brief command line help/usage message
  *
@@ -685,6 +875,9 @@ int G_usage (void)
 	char *key_desc;
 	int maxlen;
 	int len, n;
+	int new_prompt = 0;
+
+	new_prompt = uses_new_gisprompt();
 	
 	if (!pgm_name)		/* v.dave && r.michael */
 	    pgm_name = G_program_name ();
@@ -695,6 +888,10 @@ int G_usage (void)
 		fprintf (stderr, _("\nDescription:\n"));
 		fprintf (stderr, " %s\n", module_info.description);
 	}
+	if (module_info.keywords) {
+		fprintf (stderr, _("\nKeywords:\n"));
+		fprintf (stderr, " %s\n", module_info.keywords);
+	}
 
 	fprintf (stderr, _("\nUsage:\n "));
 
@@ -724,7 +921,7 @@ int G_usage (void)
 			if (opt->key_desc != NULL)
 				key_desc = opt->key_desc;
 			else if (opt->type == TYPE_STRING)
-				key_desc = "name";
+				key_desc = "string";
 			else
 				key_desc = "value";
 
@@ -751,13 +948,21 @@ int G_usage (void)
 			opt = opt->next_opt ;
 		}
 	}
+	if (new_prompt)
+	{
+		strcpy (item, " [--overwrite]");
+		len=show(item,len);
+	}
+
 	fprintf (stderr, "\n");
 
 	/* Print help info for flags */
 
+	if(n_flags || new_prompt)	
+		fprintf (stderr, _("\nFlags:\n"));
+
 	if(n_flags)
 	{
-		fprintf (stderr, _("\nFlags:\n"));
 		flag= &first_flag;
 		while(flag != NULL)
 		{
@@ -776,6 +981,10 @@ int G_usage (void)
 		}
 	}
 
+	if (new_prompt)
+		fprintf(stderr," --o   %s\n", _("Force overwrite of output files")) ;
+		
+
 	/* Print help info for options */
 
 	if(n_opts)
@@ -850,13 +1059,25 @@ static void G_usage_xml (void)
 	char *type;
 	char *s, *top;
 	int i;
+	char *encoding;
+
+/* gettext converts strings to encoding returned by nl_langinfo(CODESET) */
+
+#if defined(HAVE_LANGINFO_H)
+	encoding = nl_langinfo (CODESET);
+	if ( !encoding || strlen( encoding ) == 0 ) {
+	    encoding = "UTF-8";
+	}
+#else
+	encoding = "UTF-8";
+#endif
 	
 	if (!pgm_name)		/* v.dave && r.michael */
 	    pgm_name = G_program_name ();
 	if (!pgm_name)
 	    pgm_name = "??";
 
-	fprintf(stdout, "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
+	fprintf(stdout, "<?xml version=\"1.0\" encoding=\"%s\"?>\n", encoding);
 	fprintf(stdout, "<!DOCTYPE task SYSTEM \"grass-interface.dtd\">\n");
 
 	fprintf(stdout, "<task name=\"%s\">\n", pgm_name);  
@@ -873,6 +1094,12 @@ static void G_usage_xml (void)
 		fprintf(stdout, "\n\t</description>\n");
 	}
 
+	if (module_info.keywords) {
+		fprintf(stdout, "\t<keywords>\n\t\t");
+		print_escaped_for_xml (stdout, module_info.keywords);
+		fprintf(stdout, "\n\t</keywords>\n");
+	}
+
 	/***** Don't use parameter-groups for now.  We'll reimplement this later 
 	 ***** when we have a concept of several mutually exclusive option
 	 ***** groups
@@ -962,20 +1189,6 @@ static void G_usage_xml (void)
 				print_escaped_for_xml(stdout, opt->def);
 				fprintf(stdout, "\n\t\t\t</default>\n");
 			}
-			if(opt->descs) {
-			    int i = 0;
-
-			    while ( opt->opts[i] ) {
-				fprintf(stdout, "<DD><b>%s</b>: ", opt->opts[i]);
-
-				if (  opt->descs[i] )
-				    fprintf (stdout, "%s", opt->descs[i] );
-				
-				fprintf(stdout, "</DD>\n");
-				
-				i++;
-			    }
-			}
 
 			if(opt->options) {
 			        i = 0;
@@ -1051,6 +1264,9 @@ static void G_usage_html (void)
 	struct Flag *flag ;
 	char *type;
 	char *newbuf;
+	int new_prompt = 0;
+
+	new_prompt = uses_new_gisprompt();
 	
 	if (!pgm_name)		/* v.dave && r.michael */
 	    pgm_name = G_program_name ();
@@ -1058,12 +1274,13 @@ static void G_usage_html (void)
 	    pgm_name = "??";
 
 	fprintf(stdout, "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">\n");
-	fprintf(stdout, "<html>\n<head>\n"),
+	fprintf(stdout, "<html>\n<head>\n");
 	fprintf(stdout, "<title>%s</title>\n", pgm_name);
-	fprintf(stdout, "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\n"),
-	fprintf(stdout, "</head>\n"),
-	fprintf(stdout, "<body bgcolor=\"white\">\n");
-
+	fprintf(stdout, "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\n");
+	fprintf(stdout, "<link rel=\"stylesheet\" href=\"grassdocs.css\" type=\"text/css\">\n");
+	fprintf(stdout, "</head>\n");
+	fprintf(stdout, "<body bgcolor=\"white\">\n\n");
+	fprintf(stdout, "<img src=\"grass.smlogo.gif\" alt=\"GRASS logo\"><hr align=center size=6 noshade>\n\n");
 	fprintf(stdout, "<h2>NAME</h2>\n");
 	fprintf(stdout, "<em><b>%s</b></em> ", pgm_name);
 
@@ -1072,12 +1289,20 @@ static void G_usage_html (void)
 		fprintf(stdout, "%s", module_info.description);
 		fprintf(stdout, "\n");
 	}
+
+	fprintf(stdout, "<h2>KEYWORDS</h2>\n");
+	if (module_info.keywords) {
+		fprintf(stdout, "%s", module_info.keywords);
+		fprintf(stdout, "\n");
+	}
 	fprintf(stdout, "<h2>SYNOPSIS</h2>\n");
 	fprintf(stdout, "<b>%s</b><br>\n", pgm_name);
 	fprintf(stdout, "<b>%s help</b><br>\n", pgm_name);
 
 	fprintf(stdout, "<b>%s</b>", pgm_name);
 
+
+
 	/* print short version first */
 	if(n_flags)
 	{
@@ -1093,7 +1318,6 @@ static void G_usage_html (void)
 	else
 	  fprintf(stdout, " ");
 
-	/* print short version first */
 	if(n_opts)
 	{
 		opt= &first_option;
@@ -1127,23 +1351,27 @@ static void G_usage_html (void)
 			if( !opt->required )
 			     fprintf(stdout,"] ");
 
-
 			opt = opt->next_opt ;
 			fprintf(stdout," ");
 		}
-		fprintf(stdout, "\n");
 	}
+	if (new_prompt)
+	{
+		fprintf(stdout, " [--<b>overwrite</b>] ");
+	}
+	fprintf(stdout, "\n");
+
 
 	/* now long version */
 	fprintf(stdout, "\n");
-	if(n_flags)
+	if(n_flags || new_prompt)
 	{
 		flag= &first_flag;
 		fprintf(stdout, "<h3>Flags:</h3>\n");
 		fprintf(stdout, "<DL>\n");
-		while(flag != NULL)
+		while(n_flags && flag != NULL )
 		{
-			fprintf (stdout, "<DT><b>-%c</b>\n", flag->key);
+			fprintf (stdout, "<DT><b>-%c</b></DT>\n", flag->key);
 
 		        if ( flag->label ) {
 				fprintf(stdout, "<DD>");
@@ -1160,6 +1388,11 @@ static void G_usage_html (void)
 			flag = flag->next_flag ;
 			fprintf (stdout, "\n");
 		}
+		if (new_prompt)
+		{
+			fprintf(stdout, "<DT><b>--overwrite</b></DT>\n");
+			fprintf(stdout, "<DD>Force overwrite of output files</DD>");
+		}
 		fprintf(stdout, "</DL>\n");
 	}
 
@@ -1194,7 +1427,7 @@ static void G_usage_html (void)
 			if (opt->multiple) {
 				fprintf(stdout,"[,<i>%s</i>,...]", type);
 			}
-			fprintf(stdout,"</em>\n");
+			fprintf(stdout,"</em></DT>\n");
 
 		        if ( opt->label ) {
 				fprintf(stdout, "<DD>");
@@ -1246,20 +1479,40 @@ static void G_usage_html (void)
 		fprintf(stdout, "</DL>\n");
 	}
 	
-    fprintf(stdout, "</body></html>\n");
+    fprintf(stdout, "</body>\n</html>\n");
 }
 
 static void generate_tcl(FILE *fp)
 {
-	char *type, *desc;
+	int new_prompt = uses_new_gisprompt();
+	char *type;
 	int optn;
 
-	fprintf(fp, "begin_dialog {%s} {%s}\n", pgm_name,
-		module_info.label ? module_info.label : 
-		module_info.description ? module_info.description : "");
+	fprintf(fp, "begin_dialog {%s} {\n", pgm_name);
+	fprintf(fp, " label {%s}\n", module_info.label ? module_info.label : "");
+	fprintf(fp, " desc {%s}\n", module_info.description ? module_info.description : "");
+	fprintf(fp, " key {%s}\n", module_info.keywords ? module_info.keywords : "");
+	fprintf(fp, "}\n");
 
 	optn = 1;
     
+	if (n_flags)
+	{
+		struct Flag *flag;
+
+		for (flag = &first_flag; flag; flag = flag->next_flag, optn++) {
+			fprintf(fp, "add_flag %d {\n", optn);
+			fprintf(fp, " name {%c}\n", flag->key);
+			fprintf(fp, " desc {%s}\n", flag->description);
+			fprintf(fp, " answer %d\n", flag->answer);
+			/* It should be up to the gui as to what
+			   to do with the label and description */
+			fprintf(fp, " label {%s}\n", flag->label ? flag->label : "");
+			fprintf(fp, " guisection {%s}\n", flag->guisection ? flag->guisection : "");
+			fprintf(fp, "}\n");
+		}
+	}
+
 	if (n_opts)
 	{
 		struct Option *opt;
@@ -1284,31 +1537,35 @@ static void generate_tcl(FILE *fp)
 				break;
 			}
 
-			desc = opt->label ? opt->label : opt->description;
-
 			fprintf(fp, "add_option %d {\n", optn);
 			fprintf(fp, " name {%s}\n", opt->key);
 			fprintf(fp, " type {%s}\n", type);
 			fprintf(fp, " multi %d\n", opt->multiple);
-			fprintf(fp, " desc {%s}\n", desc);
+			fprintf(fp, " desc {%s}\n", opt->description);
 			fprintf(fp, " required %d\n", opt->required);
 			fprintf(fp, " options {%s}\n", opt->options ? opt->options : "");
 			fprintf(fp, " answer {%s}\n", opt->answer ? opt->answer : "");
 			fprintf(fp, " prompt {%s}\n", opt->gisprompt ? opt->gisprompt : "");
+			/* It should be up to the gui as to what
+			   to do with the label and description */
+			fprintf(fp, " label {%s}\n", opt->label ? opt->label : "");
+			fprintf(fp, " guisection {%s}\n", opt->guisection ? opt->guisection : "");
 			fprintf(fp, "}\n");
 		}
 	}
-
-	if (n_flags)
-	{
-		struct Flag *flag;
-
-		for (flag = &first_flag; flag; flag = flag->next_flag, optn++) {
-			desc = flag->label ? flag->label : flag->description;
-			fprintf(fp, "add_flag %d {%c} {%s}\n", optn, flag->key, desc);
-		}
-	}
    
+	if (new_prompt)
+	{
+		fprintf(fp, "add_xflag %d {\n", optn);
+		fprintf(fp, " name {overwrite}\n");
+		fprintf(fp, " desc {Force overwrite of output files}\n");
+		fprintf(fp, " answer %d\n", overwrite);
+		fprintf(fp, " label {Overwrite}\n");
+		fprintf(fp, " guisection {}\n");
+		fprintf(fp, "}\n");
+		optn++;
+	}
+
 	fprintf(fp, "end_dialog %d\n", optn - 1);
 }
 
@@ -1386,7 +1643,7 @@ static int show_options(int maxlen,char *str)
         return 0;
 }
 
-static int show (char *item, int len)
+static int show (const char *item, int len)
 {
 	int n;
 
@@ -1446,11 +1703,11 @@ static int contains (char *s, int c)
 
 static int set_option (char *string)
 {
-	struct Option *at_opt ;
-	struct Option *opt ;
+	struct Option *at_opt = NULL;
+	struct Option *opt = NULL;
 	int got_one ;
 	size_t key_len ;
-	char the_key[64] ;
+	char the_key[KEYLENGTH] ;
 	char *ptr ;
 
 	for(ptr=the_key; *string!='='; ptr++, string++)
@@ -1862,9 +2119,9 @@ static int check_multiple_opts (void)
 static int check_overwrite (void)
 {
 	struct Option *opt ;
-	char age[64] ;
-	char element[64] ;
-	char *ptr1, *ptr2 ;
+	char age[KEYLENGTH] ;
+	char element[KEYLENGTH] ;
+	char desc[KEYLENGTH] ;
 	int error = 0;
 	char *overstr;
 	int over;
@@ -1873,32 +2130,31 @@ static int check_overwrite (void)
 		return (0) ;
 
 	over = 0;
+	/* Check the GRASS OVERWRITE variable */
 	if ( (overstr = G__getenv ( "OVERWRITE" )) ) {
 	    over = atoi ( overstr );
 	}
 
-	if ( overwrite || over )
+	/* Check the GRASS_OVERWRITE environment variable */
+	if ( (overstr = getenv ( "GRASS_OVERWRITE" )) ) {
+	    if (atoi ( overstr ))
+		over = 1;
+	}
+
+	if ( overwrite || over ) {
 	    module_info.overwrite = 1;
+	    /* Set the environment so that programs run in a script also obey --o */
+	    putenv("GRASS_OVERWRITE=1");
+	    /* No need to check options for existing files if overwrite is true */
+	    return error;
+	}
 
 	opt= &first_option;
 	while(opt != NULL)
 	{
 		if ((opt->answer != NULL) && (opt->gisprompt != NULL))
 		{
-			for(ptr1=opt->gisprompt,ptr2=age; *ptr1!='\0'; ptr1++, ptr2++)
-			{
-				if (*ptr1 == ',')
-					break ;
-				*ptr2 = *ptr1 ;
-			}
-			*ptr2 = '\0' ;
-			for(ptr1++, ptr2=element; *ptr1!='\0'; ptr1++, ptr2++)
-			{
-				if (*ptr1 == ',')
-					break ;
-				*ptr2 = *ptr1 ;
-			}
-			*ptr2 = '\0' ;
+			split_gisprompt (opt->gisprompt, age, element, desc);
 	    
 			if ( strcmp(age,"new") == 0 ) {
 			    if ( G_find_file (element, opt->answer, G_mapset()) ) /* found */
@@ -1927,7 +2183,7 @@ static int interactive( char *command)
 	if(!n_items)
 	{
 		fprintf(stderr,"Programmer error: no flags or options\n") ;
-		exit(-1) ;
+		exit(EXIT_FAILURE) ;
 	}
 
 	for (item= &first_item ;;)
@@ -1963,6 +2219,7 @@ static int interactive_option(struct Option *opt )
 	char buff[1024],*bptr ;
 	char buff2[1024] ;
 	int set_one ;
+	int no_prompt ;
 
 	fprintf(stderr,_("\nOPTION:   %s\n"), opt->description) ;
 	fprintf(stderr,_("     key: %s\n"), opt->key) ;
@@ -1984,11 +2241,13 @@ static int interactive_option(struct Option *opt )
 	{
 	   *buff='\0' ;
 	   if(opt->gisprompt)
-		gis_prompt(opt, buff) ;
+		no_prompt = gis_prompt(opt, buff) ;
 	   else
+		no_prompt = -1;
+	   if (no_prompt)
 	   {
 		fprintf(stderr,_("enter option > ")) ;
-		if(fgets(buff,1024,stdin) == 0) exit(1); ;
+		if(fgets(buff,1024,stdin) == 0) exit(EXIT_SUCCESS); ;
                 bptr = buff;  /* strip newline  */
                 while(*bptr) {if(*bptr=='\n') *bptr='\0'; bptr++;}
 
@@ -2004,7 +2263,7 @@ static int interactive_option(struct Option *opt )
 		        if (G_yes(_("   Try again? "), 1))
 		    		continue ;
 	    	        else
-				exit(-1) ;
+				exit(EXIT_FAILURE) ;
 		    }
 		}
 		if (opt->checker)
@@ -2015,7 +2274,7 @@ static int interactive_option(struct Option *opt )
 			    if (G_yes(_("   Try again? "), 1))
 			    	continue ;
 			    else
-				exit(-1) ;
+				exit(EXIT_FAILURE) ;
 		    }
 
 		sprintf(buff2,"%s=%s", opt->key, buff) ;
@@ -2036,7 +2295,7 @@ static int interactive_option(struct Option *opt )
 	   } /* if strlen(buf ) !=0 */
 
 	   if ((strlen(buff) == 0) && opt->required && (set_one == 0))
-		exit(-1) ;
+		exit(EXIT_FAILURE) ;
 	   if ((strlen(buff) == 0) && (set_one > 0) && opt->multiple )
 		break ;
 	   if ((strlen(buff) == 0) && !opt->required)
@@ -2047,14 +2306,12 @@ static int interactive_option(struct Option *opt )
 	return(0) ;
 }
 
-static int gis_prompt (struct Option *opt, char *buff)
+static int split_gisprompt (const char *gisprompt, char *age, char *element, char *desc)
 {
-	char age[64] ;
-	char element[64] ;
-	char desc[64] ;
-	char *ptr1, *ptr2 ;
+	const char *ptr1 ;
+	char *ptr2 ;
 
-	for(ptr1=opt->gisprompt,ptr2=age; *ptr1!='\0'; ptr1++, ptr2++)
+	for(ptr1=gisprompt,ptr2=age; *ptr1!='\0'; ptr1++, ptr2++)
 	{
 		if (*ptr1 == ',')
 			break ;
@@ -2077,6 +2334,19 @@ static int gis_prompt (struct Option *opt, char *buff)
 		*ptr2 = *ptr1 ;
 	}
 	*ptr2 = '\0' ;
+
+	return 0 ;
+}
+
+static int gis_prompt (struct Option *opt, char *buff)
+{
+	char age[KEYLENGTH] ;
+	char element[KEYLENGTH] ;
+	char desc[KEYLENGTH] ;
+	char *ptr1 ;
+
+	split_gisprompt ( opt->gisprompt, age, element, desc );
+
 	/*********ptr1 points to current mapset description***********/
 
 	if (opt->answer)
@@ -2095,14 +2365,18 @@ static int gis_prompt (struct Option *opt, char *buff)
 		ptr1 = G_ask_in_mapset("", buff, element, desc) ;
 	else if (! strcmp("any",age))
 		ptr1 = G_ask_any("", buff, element, desc, 1) ;
-	else if (! strcmp("old_file",age))
+	else if (! strcmp("old_file",age)) /* file must exist */
 		ptr1 = G_ask_old_file("", buff, element, desc) ;
-	else if (! strcmp("new_file",age))
+	else if (! strcmp("new_file",age)) /* file shouldn't exist unless overwrite is enabled*/
 		ptr1 = G_ask_new_file("", buff, element, desc) ;
+	else if (! strcmp("color",age))
+		/* These prompts are only implemented in the gui */
+		/* The data can still be entered in the console */
+		return -1;
 	else
 	{
 		fprintf(stderr,"\nPROGRAMMER ERROR: first item in gisprompt is <%s>\n", age) ;
-		fprintf(stderr,"        Must be either new, old, mapset, any, old_file, or new_file\n") ;
+		fprintf(stderr,"        Must be either new, old, mapset, any, old_file, new_file, or color\n") ;
 		return -1;
 	}
 	if (ptr1 == '\0')
@@ -2113,8 +2387,10 @@ static int gis_prompt (struct Option *opt, char *buff)
 
 char *G_recreate_command (void)
 {
+	static char *buff;
 	char flg[4] ;
-	static char *buff, *cur, *tmp;
+	char *cur;
+	const char *tmp;
 	struct Flag *flag ;
 	struct Option *opt ;
 	int n , len, slen;
