@@ -1,5 +1,5 @@
-#include "gis.h"
-#include "glocale.h"
+#include <grass/gis.h>
+#include <grass/glocale.h>
 
 int G__projection_units(int n)
 {
