@@ -1,4 +1,4 @@
-#include "gis.h"
+#include <grass/gis.h>
 #include <string.h>
 
 
@@ -13,7 +13,8 @@
  *  \return char * 
  */
 
-char *G_store (s) char *s;
+char *G_store  (const char *s)
+
 {
     char *buf;
 
