@@ -1,7 +1,7 @@
 #! /bin/sh
 #############################################################################
 #
-# $Id: init.sh,v 1.60 2005/03/01 20:56:15 markus Exp $
+# $Id: init.sh,v 1.83.2.4 2007/07/12 12:28:14 markus Exp $
 #
 # MODULE:   	GRASS Initialization
 # AUTHOR(S):	Original author unknown - probably CERL
@@ -51,25 +51,25 @@ for i in "$@" ; do
     	# Check if the user asked for help
 	help|-h|-help|--help)
 	    echo "Usage:"
-	    echo "  $CMD_NAME [-h | -help | --help] [-text | -tcltk | -gui] [[[<GISDBASE>/]<LOCATION_NAME>/]<MAPSET>]"
+	    echo "  $CMD_NAME [-h | -help | --help] [-text | -gui | -tcltk] [[[<GISDBASE>/]<LOCATION_NAME>/]<MAPSET>]"
 	    echo
             echo "Flags:"
             echo "  -h or -help or --help          print this help message"
             echo "  -text                          use text based interface and set as default"
-            echo "  -tcltk or -gui                 use Tcl/Tk based graphical user interface"
+            echo "  -gui or -tcltk                 use Tcl/Tk based graphical user interface"
             echo "                                   and set as default"
             echo
             echo "Parameters:"
-            echo "  GISDBASE                       initial database"
+            echo "  GISDBASE                       initial database (path to GIS data)"
             echo "  LOCATION_NAME                  initial location"
             echo "  MAPSET                         initial mapset"
             echo
-            echo "  GISDBASE/LOCATION_NAME/MAPSET  fully qualified initial LOCATION directory"
+            echo "  GISDBASE/LOCATION_NAME/MAPSET  fully qualified initial mapset directory"
             echo
-            echo "Environment variables:"
+            echo "Environment variables relevant for startup:"
             echo "  GRASS_TCLSH                    set tclsh shell name to override 'tclsh'"
             echo "  GRASS_WISH                     set wish shell name to override 'wish'"
-            echo "  GRASS_HTML_BROWSER             set html browser for help pages"
+            echo "  GRASS_HTML_BROWSER             set html web browser for help pages"
             echo "  GRASS_ADDON_PATH               set additional path(s) to local GRASS modules"
 	    exit
 	    ;;
@@ -94,7 +94,7 @@ export GIS_LOCK
 
 # Set the global grassrc file
 GISRCRC="$HOME/.grassrc6"
-export GISRCRC
+
 # Set the session grassrc file
 USER="`whoami`"
 
@@ -142,11 +142,8 @@ if [ ! "$GRASS_GUI" ] ; then
     fi
 fi
 
-# Export the user interface variable
-export GRASS_GUI
-
 # Set PATH to GRASS bin, ETC to GRASS etc
-ETC=$GISBASE/etc
+ETC="$GISBASE/etc"
 
 if [ "$LC_ALL" ] ; then
 	LCL=`echo "$LC_ALL" | sed 's/\(..\)\(.*\)/\1/'`
@@ -156,51 +153,79 @@ else
 	LCL=`echo "$LANG" | sed 's/\(..\)\(.*\)/\1/'`
 fi
 
-PATH=$GISBASE/bin:$GISBASE/scripts:$PATH:$GRASS_ADDON_PATH
+if [ -n "$GRASS_ADDON_PATH" ] ; then
+   PATH="$GISBASE/bin:$GISBASE/scripts:$GRASS_ADDON_PATH:$PATH"
+else
+   PATH="$GISBASE/bin:$GISBASE/scripts:$PATH"
+fi
 export PATH
 
 # Set LD_LIBRARY_PATH to find GRASS shared libraries
 if [ ! "$LD_LIBRARY_PATH_VAR" ] ; then
-  LD_LIBRARY_PATH_VAR=$GISBASE/lib
+  LD_LIBRARY_PATH_VAR="$GISBASE/lib"
 else
-  LD_LIBRARY_PATH_VAR=$GISBASE/lib:$LD_LIBRARY_PATH_VAR
+  LD_LIBRARY_PATH_VAR="$GISBASE/lib:$LD_LIBRARY_PATH_VAR"
 fi
 export LD_LIBRARY_PATH_VAR
 # Additional copy of variable to use with grass-run.sh
-GRASS_LD_LIBRARY_PATH=$LD_LIBRARY_PATH_VAR
+GRASS_LD_LIBRARY_PATH="$LD_LIBRARY_PATH_VAR"
 export GRASS_LD_LIBRARY_PATH
 
-# Once the new environment system is committed we can delete these lines
-# Export the PAGER environment variable for those who have it set
-if [ "$PAGER" ] ; then
-    export PAGER
-fi
-
 # Set some environment variables if they are not set
 if [ ! "$GRASS_PAGER" ] ; then
-    if [ -x /bin/more ] ; then
+    if [ -x /bin/more ] || [ -x /usr/bin/more ] ; then
         GRASS_PAGER=more
-    else 
+    elif [ -x /bin/less ] || [ -x /usr/bin/less ] ; then
         GRASS_PAGER=less
+    else
+        GRASS_PAGER=cat
     fi
     export GRASS_PAGER
 fi
 
+
+# Set up tcltk and wish environment 
+# with options for aqua tcltk with Mac OSX
+
+
 if [ ! "$GRASS_TCLSH" ] ; then
-    GRASS_TCLSH=tclsh
-    export GRASS_TCLSH
-fi
+   if [ "$HOSTTYPE" = "macintosh" ] ; then
+      if [ -d "/usr/local/grasslib" ]; then
+            GRASS_TCLSH=/usr/local/grasslib/bin/tclsh
+      else
+         GRASS_TCLSH=tclsh
+      fi
+   else
+      GRASS_TCLSH=tclsh
+   fi
+   export GRASS_TCLSH
+fi   
+
+
+#WISH_OS=`echo 'puts $tcl_platform(platform) ; exit 0' | wish`
 
 if [ ! "$GRASS_WISH" ] ; then
-   WISH_OS=`echo 'puts $tcl_platform(platform) ; exit 0' | wish`
-   if [ "$?" = 0 -a "$WISH_OS" = macintosh ] ; then
-     #force X11 tcl on Mac:
-     GRASS_WISH=/usr/bin/wish
+   if [ "$HOSTTYPE" = "macintosh" ] ; then
+      if [ "$osxaqua" ] ; then
+         if [ -d "/usr/local/grasslib/bin/Grass.app" ] ; then
+            GRASS_WISH=/usr/local/grasslib/bin/Grass.app/Contents/MacOS/Grass
+         else
+            GRASS_WISH=/usr/bin/wish
+         fi
+         export osxaqua
+      elif [ -d "/usr/local/grasslib" ] ; then
+         GRASS_WISH=/usr/local/grasslib/bin/wish
+      else
+         #force X11 tcl on Mac without grasslib directory:
+         GRASS_WISH=/usr/bin/wish
+      fi
    else
-     GRASS_WISH=wish
-   fi
-   export GRASS_WISH
+      GRASS_WISH=wish
+   fi   
 fi
+export GRASS_WISH
+
+CYGWIN=`uname | grep CYGWIN`
 
 if [ ! "$GRASS_HTML_BROWSER" ] ; then
     for i in `echo "$PATH" | sed 's/^:/.:/
@@ -235,6 +260,14 @@ if [ ! "$GRASS_HTML_BROWSER" ] ; then
         elif [ "$HOSTTYPE" = "arm" ] ; then
             GRASS_HTML_BROWSER=dillo2
             break
+	elif [ "$CYGWIN" ] ; then
+	    iexplore="$SYSTEMDRIVE/Program Files/Internet Explorer/iexplore.exe"
+	    if [ -f "$iexplore" ] ; then
+		GRASS_HTML_BROWSER=$iexplore
+	    else
+		GRASS_HTML_BROWSER="iexplore"
+	    fi
+	    break
         fi
     done
 fi
@@ -301,7 +334,6 @@ if [ "$DISPLAY" ] ; then
 
 	    # Set the tcltkgrass base directory
 	    TCLTKGRASSBASE="$ETC"
-	    export TCLTKGRASSBASE
 	else
 
 	    # Wish was not found - switch to text interface mode
@@ -359,13 +391,15 @@ else
     	fi
     else
     	L="$1"
-    
-    	if [ `echo "$L" | cut -c 1` != "/" ] ; then
-    	    L="`pwd`/$L"
-    	fi
     fi
 
     if [ "$L" ] ; then
+	if [ "$L" = "." ] ; then
+	    L=`pwd`
+	elif [ `echo "$L" | cut -c 1` != "/" ] ; then
+    	    L="`pwd`/$L"
+    	fi
+
     	MAPSET=`basename "$L"`
     	L=`dirname "$L"`
     
@@ -534,7 +568,7 @@ GISDBASE=`g.gisenv GISDBASE`
 LOCATION_NAME=`g.gisenv LOCATION_NAME`
 MAPSET=`g.gisenv MAPSET`
 
-LOCATION=${GISDBASE?}/${LOCATION_NAME?}/${MAPSET?}
+LOCATION="${GISDBASE?}/${LOCATION_NAME?}/${MAPSET?}"
 
 # Check for concurrent use
 lockfile="$LOCATION/.gislock"
@@ -542,7 +576,7 @@ lockfile="$LOCATION/.gislock"
 case $? in
     0) ;;
     1)
-    	echo `whoami` is currently running GRASS in selected mapset. Concurrent use not allowed.
+    	echo "`whoami` is currently running GRASS in selected mapset (file $lockfile found). Concurrent use not allowed."
     	rm -rf "$tmp"  # remove session files from tmpdir
     	exit 1 ;;
     *)
@@ -552,14 +586,14 @@ case $? in
 esac
 
 trap "" 2 3 15
-CYGWIN=`uname | grep CYGWIN`
 
 # cygwin has many problems with the shell setup
 # below, so i hardcoded everything here.
 if [ "$CYGWIN" ] ; then
     sh="cygwin"
     shellname="GNU Bash (Cygwin)"
-    SHELL=/usr/bin/bash.exe
+    export SHELL=/usr/bin/bash.exe
+    export OSTYPE=cygwin
 else 
     sh=`basename "$SHELL"`
     case "$sh" in
@@ -572,12 +606,24 @@ else
     esac
 fi
 
+# check for SHELL
+if [ ! -x "$SHELL" ] ; then
+    echo "ERROR: The SHELL variable is not set" 1>&2
+    rm -f "$lockfile"
+    rm -rf "$tmp"  # remove session files from tmpdir
+    exit 1
+fi
+
 # Start the chosen GUI but ignore text
 case "$GRASS_GUI" in
     
     # Check for tcltk interface
     tcltk)
-        "$GISBASE/scripts/d.m" &
+	if [ "$osxaqua" ] ; then
+		"$GISBASE/scripts/gis.m" | sh &
+	else
+		"$GISBASE/scripts/gis.m" &
+	fi	
 	;;
     
     # Ignore others
@@ -600,9 +646,9 @@ echo "Help is available with the command:      g.manual -i"
 echo "See the licence terms with:              g.version -c"
 
 if [ "$GRASS_GUI" = "text" ] ; then
-    echo "Start the graphical user interface with: d.m &"
+    echo "Start the graphical user interface with: gis.m &"
 else
-    echo "If required, restart the graphical user interface with: d.m &"
+    echo "If required, restart the graphical user interface with: gis.m &"
 fi
 
 echo "When ready to quit enter:                exit"
@@ -654,7 +700,7 @@ csh|tcsh)
     export HOME
     ;;
 
-bash)
+bash|msh)
     USERHOME="$HOME"      # save original home
     HOME="$LOCATION"      # save .bashrc in $LOCATION
     export HOME
@@ -662,10 +708,9 @@ bash)
     rm -f "$bashrc"
     echo "test -z $PROFILEREAD && . /etc/profile" > "$bashrc"
     echo "test -r ~/.alias && . ~/.alias" >> "$bashrc"
-    echo "umask 022" >> "$bashrc"
-    echo "PROMPT_COMMAND='if test -f `g.gisenv GISDBASE`/`g.gisenv LOCATION_NAME`/`g.gisenv MAPSET`/cell/MASK ; then echo "[Raster MASK present]" ; fi'" >> "$bashrc"
     echo "PS1='GRASS GRASS_VERSION_NUMBER ($LOCATION_NAME):\w > '" >> "$bashrc"
-
+    echo "PROMPT_COMMAND=$GISBASE/etc/prompt.sh" >> "$bashrc"
+    
     if [ -r "$USERHOME/.grass.bashrc" ]
     then
         cat "$USERHOME/.grass.bashrc" >> "$bashrc"
@@ -688,7 +733,6 @@ cygwin)
     # this does not work on cygwin for unknown reasons
     # echo "test -z $PROFILEREAD && . /etc/profile" > "$bashrc"
     echo "test -r ~/.alias && . ~/.alias" >> "$bashrc"
-    echo "umask 022" >> "$bashrc"
     echo "PS1='GRASS GRASS_VERSION_NUMBER ($LOCATION_NAME):\w > '" >> "$bashrc"
 
     if [ -r "$USERHOME/.grass.bashrc" ]
