@@ -11,7 +11,7 @@
 **   speed.c or speed2.c
 */
 #include <stdio.h>
-#include "linkm.h"
+#include <grass/linkm.h>
 
 struct link {
     char let;
