@@ -1,12 +1,12 @@
 /*
-* $Id: GK2.c,v 1.1.2.1 2006/01/03 09:17:40 markus Exp $
+* $Id: GK2.c,v 1.5 2006/02/09 03:08:57 glynn Exp $
 */
 
-#include <stdio.h>
 #include <stdlib.h>
-#include "gstypes.h"
-#include "keyframe.h"
-#include "kftypes.h"
+#include <stdio.h>
+#include <grass/gstypes.h>
+#include <grass/keyframe.h>
+#include <grass/kftypes.h>
 
 static int _add_key(Keylist *, int, float);
 static void _remove_key(Keylist *);
@@ -339,7 +339,11 @@ int GK_add_key(float pos, unsigned long fmask, int force_replace,
 /* View Dir is implied from eye and center position */
 /*    GS_get_viewdir(tmp); */
 
-    GS_get_focus(tmp);
+/* ACS 1 line: was 	GS_get_focus(tmp);
+ 	with this kanimator works also for flythrough navigation
+	also changed in gk.c
+*/
+    GS_get_viewdir(tmp);
     newk->fields[KF_DIRX] = tmp[X];
     newk->fields[KF_DIRY] = tmp[Y];
     newk->fields[KF_DIRZ] = tmp[Z];
@@ -459,3 +463,25 @@ void GK_show_vol(int flag)
 
     return;
 }
+
+
+void GK_show_list( int flag)
+{
+
+        if (flag) {
+
+                Fmode |= FM_LABEL;
+
+                if (Views) {
+
+                GS_draw_all_list();
+
+                }
+        }
+        else {
+                Fmode &= ~FM_LABEL;
+        }
+
+        return;
+}
+
