@@ -1,14 +1,14 @@
 /*
-* $Id: gk.c,v 1.2.2.1 2006/01/03 09:17:40 markus Exp $
+* $Id: gk.c,v 1.8 2006/03/15 16:33:12 massimo Exp $
 */
 
+#include <stdlib.h>
 #include <stdio.h>
 #include <math.h>
-#include <stdlib.h>
 
-#include "gstypes.h"
-#include "keyframe.h"
-#include "kftypes.h"
+#include <grass/gstypes.h>
+#include <grass/keyframe.h>
+#include <grass/kftypes.h>
 
 static float spl3(float, double, double, double, double, double, double,
 		  double);
@@ -126,7 +126,11 @@ void gk_follow_frames(Viewnode * view, int numsteps, Keylist * keys, int step,
 	    fprintf(stderr, "FROM: %f %f %f\n", tmp[X], tmp[Y], tmp[Z]);
 	}
 #endif
-	GS_get_focus(tmp);
+/* ACS 1 line: was 	GS_get_focus(tmp);
+ 	with this kanimator works also for flythrough navigation
+	also changed in GK2.c
+*/
+	GS_get_viewdir(tmp);
 	if ((mask & KF_DIRX_MASK)) {
 	    tmp[X] = v->fields[KF_DIRX];
 	}
@@ -136,7 +140,11 @@ void gk_follow_frames(Viewnode * view, int numsteps, Keylist * keys, int step,
 	if ((mask & KF_DIRZ_MASK)) {
 	    tmp[Z] = v->fields[KF_DIRZ];
 	}
-	GS_set_focus(tmp);
+/* ACS 1 line: was 	GS_set_focus(tmp);
+ 	with this kanimator works also for flythrough navigation
+	also changed in GK2.c
+*/
+	GS_set_viewdir(tmp);
 
 
 #ifdef KDEBUG
@@ -198,6 +206,10 @@ void gk_follow_frames(Viewnode * view, int numsteps, Keylist * keys, int step,
 
 	GS_done_draw();
 
+	if (mode & FM_LABEL) {
+		GS_draw_all_list(); /* draw labels and legend */
+	}
+
 	if (onestep) {
 	    return;
 	}
@@ -538,7 +550,10 @@ Viewnode *gk_make_linear_framesfromkeys(Keylist * keys, int keysteps,
 					     tkeys, &k1, &k2);
 		}
 
-		if (len == 0.0) {
+/* ACS 1 line: was	if (len == 0.0) {
+ 	when disabling a channel no calculation must be made at all (otherwise core dump)
+*/
+		if (len == 0.0 || nvk == 0) {
 		    if (!k1) {
 			/* none valid - use first.
 			   (when showing , will be ignored anyway) */
