@@ -1,5 +1,5 @@
 /*
-* $Id: gsdrape.c,v 2.0 2004/11/09 12:31:13 bernhard Exp $
+* $Id: gsdrape.c,v 2.1 2006/02/09 03:08:57 glynn Exp $
 */
 
 /* drape.c
@@ -45,7 +45,7 @@ Let calling routine worry about copying points for caching.
 #include <stdio.h>
 #include <stdlib.h>
 
-#include "gstypes.h"
+#include <grass/gstypes.h>
 #include "gsget.h"
 #include "rowcol.h"
 #include "math.h"
