@@ -1,5 +1,5 @@
 /*
- * $Id: convert.c,v 1.15 2005/02/03 09:56:12 paul Exp $
+ * $Id: convert.c,v 1.24.4.2 2007/03/06 17:40:38 markus Exp $
  *
  ****************************************************************************
  *
@@ -15,14 +15,14 @@
  *
  *****************************************************************************/
 
-#include "config.h"
+#include <grass/config.h>
 
 #ifdef HAVE_OGR
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include "gis.h"
-#include "gprojects.h"
+#include <grass/gis.h>
+#include <grass/gprojects.h>
 #include <cpl_csv.h>
 #include "local_proto.h"
 
@@ -53,7 +53,7 @@ char *GPJ_grass_to_wkt(struct Key_Value *proj_info,
 		       struct Key_Value *proj_units,
 		       int esri_style, int prettify)
 {
-    OGRSpatialReferenceH *hSRS = NULL;
+    OGRSpatialReferenceH hSRS;
     char *wkt;
 
     hSRS = GPJ_grass_to_osr(proj_info, proj_units);
@@ -79,17 +79,16 @@ char *GPJ_grass_to_wkt(struct Key_Value *proj_info,
  * \param proj_info Set of GRASS PROJ_INFO key/value pairs
  * \param proj_units Set of GRASS PROJ_UNIT key/value pairs
  * 
- * \return Pointer to an OGRSpatialReferenceH object representing the
- *         co-ordinate system defined by proj_info and proj_units
- *         or NULL if it fails
+ * \return OGRSpatialReferenceH object representing the co-ordinate system
+ *         defined by proj_info and proj_units or NULL if it fails
  **/
 
-OGRSpatialReferenceH *GPJ_grass_to_osr(struct Key_Value * proj_info,
+OGRSpatialReferenceH GPJ_grass_to_osr(struct Key_Value * proj_info,
 				       struct Key_Value * proj_units)
 {
     struct pj_info pjinfo;
     char *proj4, *proj4mod, *wkt, *modwkt, *startmod, *lastpart;
-    OGRSpatialReferenceH *hSRS, *hSRS2;
+    OGRSpatialReferenceH hSRS, hSRS2;
     OGRErr errcode;
     struct gpj_datum dstruct;
     size_t len;
@@ -174,7 +173,7 @@ OGRSpatialReferenceH *GPJ_grass_to_osr(struct Key_Value * proj_info,
 	end = "";
     }
     else {
-	if ((strncmp(sysname, "unnamed", 7) == 0) &&
+	if ((strcmp(sysname, "unnamed") == 0) &&
 	    (G_find_key_value("name", proj_info) != NULL))
 	    G_asprintf(&start, "PROJCS[\"%s\",",
 		       G_find_key_value("name", proj_info));
@@ -226,7 +225,7 @@ OGRSpatialReferenceH *GPJ_grass_to_osr(struct Key_Value * proj_info,
 }
 
 int GPJ_osr_to_grass(struct Cell_head *cellhd, struct Key_Value **projinfo, 
-                     struct Key_Value **projunits, OGRSpatialReferenceH *hSRS,
+                     struct Key_Value **projunits, OGRSpatialReferenceH hSRS,
 		     int interactive)
 {
     struct Key_Value *temp_projinfo;
@@ -235,7 +234,7 @@ int GPJ_osr_to_grass(struct Cell_head *cellhd, struct Key_Value **projinfo,
     
     if( hSRS == NULL )
         goto default_to_xy;
- 
+
     /* Set finder function for locating OGR csv co-ordinate system tables */
     SetCSVFilenameHook( GPJ_set_csv_loc );
      
@@ -345,7 +344,8 @@ int GPJ_osr_to_grass(struct Cell_head *cellhd, struct Key_Value **projinfo,
 /* -------------------------------------------------------------------- */
 /*      Derive the user name for the projection.                        */
 /* -------------------------------------------------------------------- */
-    {
+     if( pszProj )
+     {
         char	path[4095];
         char    name[80];
 
@@ -354,9 +354,12 @@ int GPJ_osr_to_grass(struct Cell_head *cellhd, struct Key_Value **projinfo,
             G_set_key_value( "name", name, *projinfo );
         else
             G_set_key_value( "name", pszProj, *projinfo );
+	
+	G_set_key_value( "proj", pszProj, *projinfo );
     }
+    else
+	G_warning("No projection name! Projection parameters likely to be meaningless.");
 
-    G_set_key_value( "proj", pszProj, *projinfo );
        
 /* -------------------------------------------------------------------- */
 /*      Find the GRASS datum name and choose parameters either          */
@@ -373,6 +376,7 @@ int GPJ_osr_to_grass(struct Cell_head *cellhd, struct Key_Value **projinfo,
         {
 	    /* Need to make a new copy of the string so we don't mess
 	     * around with the memory inside the OGRSpatialReferenceH? */
+
 	    G_asprintf( &pszDatumName, pszDatumNameConst );
             GPJ_DatumNameMassage( &pszDatumName );
 
@@ -461,11 +465,15 @@ int GPJ_osr_to_grass(struct Cell_head *cellhd, struct Key_Value **projinfo,
             double	es, flat;
             char	es_str[100];
 
-            flat = 1 / atof(pszInvFlat);
+	    flat = atof(pszInvFlat);
+	    /* Allow for incorrect WKT describing a sphere where InvFlat 
+	     * is given as 0 rather than inf */
+	    if( flat > 0 )
+                flat = 1 / flat;
             
             es = flat * (2.0 - flat);
 
-            sprintf( es_str, "%.10f", es );
+            sprintf( es_str, "%.16g", es );
             G_set_key_value( "es", es_str, *projinfo );
         }
     }
@@ -518,7 +526,7 @@ int GPJ_osr_to_grass(struct Cell_head *cellhd, struct Key_Value **projinfo,
 
     }
 
-    return 1;
+    return 2;
 
 /* -------------------------------------------------------------------- */
 /*      Fallback to returning an ungeoreferenced definition.            */
@@ -547,7 +555,7 @@ int GPJ_wkt_to_grass(struct Cell_head *cellhd, struct Key_Value **projinfo,
         retval = GPJ_osr_to_grass(cellhd, projinfo, projunits, NULL, interactive);
     else
     {
-        OGRSpatialReferenceH *hSRS;
+        OGRSpatialReferenceH hSRS;
 
         /* Set finder function for locating OGR csv co-ordinate system tables */
         SetCSVFilenameHook( GPJ_set_csv_loc );
@@ -603,10 +611,16 @@ static const char *papszDatumEquiv[] =
     "European_Terrestrial_Reference_System_1989",
     "European_Reference_System_1989",
     "European_Terrestrial_Reference_System_1989",
+    "ETRS_1989",
+    "European_Terrestrial_Reference_System_1989",
     "NZGD_2000",
     "New_Zealand_Geodetic_Datum_2000",
     "Monte_Mario_Rome",
     "Monte_Mario",
+    "Campo_Inchauspe_1969",
+    "Campo_Inchauspe",
+    "S_JTSK_Ferro",
+    "Militar_Geographische_Institut",
     NULL
 };
 
