@@ -14,16 +14,23 @@
 *
 *****************************************************************************/
 #include <stdlib.h>
-#include "gis.h"
-#include "dbmi.h"
-#include "Vect.h"
+#include <grass/gis.h>
+#include <grass/dbmi.h>
+#include <grass/Vect.h>
 
-/* 
- *  Create new VARRAY and allocate space for given number of items.
- *  Space allocated is 'size + 1' so that lines are accessed by line id.
- *  Array values are set to 0.
- *  Returns : pointer to new VARRAY
- *            NULL if failed
+
+/* function prototypes */
+static int cmp(const void *pa, const void *pb);
+static int in_array(int *cats, size_t ncats, int cat);
+
+
+/*!
+  \fn VARRAY *Vect_new_varray (int size)
+  \brief Create new VARRAY and allocate space for given number of items.
+  Space allocated is 'size + 1' so that lines are accessed by line id.
+  Array values are set to 0.
+  Returns : pointer to new VARRAY
+            NULL if failed
  */
 
 VARRAY *
@@ -36,7 +43,7 @@ Vect_new_varray (int size)
     if ( p == NULL ) return NULL;
   
     p->size = size;
-    p->c = (int *) G_calloc ( size + 1, sizeof(int) );
+    p->c = (int *) G_calloc(sizeof(char)*size + 1, sizeof(int));
     
     if ( p->c == NULL ) {
 	G_free (p);
@@ -46,16 +53,18 @@ Vect_new_varray (int size)
     return p;
 }
 
-/* 
- *  Set values in 'varray' to 'value' if category of object of given type is in 
- *  'cstring' (string representing category list like: '1,3,5-7').
- *  'type' may be either: GV_AREA
- *                    or: GV_POINT | GV_LINE | GV_BOUNDARY | GV_CENTROID  
- *
- *  Array is not reset to zero before, but old values (if any > 0) are overwritten.
- * 
- *  Return: number of items set
- *          -1 on error
+/*!
+  \fn int Vect_set_varray_from_cat_string ( struct Map_info *Map, int field, char *cstring,
+                                int type, int value, VARRAY *varray )
+  \brief Set values in 'varray' to 'value' if category of object of given type is in 
+  'cstring' (string representing category list like: '1,3,5-7').
+  'type' may be either: GV_AREA
+                    or: GV_POINT | GV_LINE | GV_BOUNDARY | GV_CENTROID  
+
+  Array is not reset to zero before, but old values (if any > 0) are overwritten.
+
+  Return: number of items set
+          -1 on error
  */
 int 
 Vect_set_varray_from_cat_string ( struct Map_info *Map, int field, char *cstring,
@@ -81,15 +90,18 @@ Vect_set_varray_from_cat_string ( struct Map_info *Map, int field, char *cstring
     return ret;
 }
 
-/* 
- *  Set values in 'varray' to 'value' if category of object of given type is in 'clist' (category list).
- *  'type' may be either: GV_AREA
- *                    or: GV_POINT | GV_LINE | GV_BOUNDARY | GV_CENTROID  
- *
- *  Array is not reset to zero before, but old values (if any > 0) are overwritten.
- * 
- *  Return: number of items set
- *          -1 on error
+/*!
+  \fn int Vect_set_varray_from_cat_list ( struct Map_info *Map, int field, struct cat_list *clist,
+                                int type, int value, VARRAY *varray )
+  \brief
+   Set values in 'varray' to 'value' if category of object of given type is in 'clist' (category list).
+  'type' may be either: GV_AREA
+                    or: GV_POINT | GV_LINE | GV_BOUNDARY | GV_CENTROID  
+		    
+  Array is not reset to zero before, but old values (if any > 0) are overwritten.
+
+  Return: number of items set
+          -1 on error
  */
 int 
 Vect_set_varray_from_cat_list ( struct Map_info *Map, int field, struct cat_list *clist,
@@ -159,7 +171,7 @@ Vect_set_varray_from_cat_list ( struct Map_info *Map, int field, struct cat_list
 }
 
 /* compare 2 integers in array */
-int cmp ( const void *pa, const void *pb)
+static int cmp ( const void *pa, const void *pb)
 {
     int *p1 = (int *) pa;
     int *p2 = (int *) pb;
@@ -170,33 +182,36 @@ int cmp ( const void *pa, const void *pb)
 }
 
 /* check if cat is in array */
-int
-in_array ( int *cats, int ncats, int cat ) 
+static int in_array (int *cats, size_t ncats, int cat)
 {
     int *p;
     
     p = (int *) bsearch((void *) &cat, cats, ncats, sizeof(int), cmp); 
 
     if ( p == NULL ) return 0;
+
     return 1;
 }
 
-/* 
- *  Set values in 'varray' to 'value' if category of object of given type is in 
- *  categories selected from DB based on where statement (given without where).
- *  'type' may be either: GV_AREA
- *                    or: GV_POINT | GV_LINE | GV_BOUNDARY | GV_CENTROID  
- *
- *  Array is not reset to zero before, but old values (if any > 0) are overwritten.
- * 
- *  Return: number of items set
- *          -1 on error
+/*!
+  \fn int Vect_set_varray_from_db ( struct Map_info *Map, int field, char *where,
+                                int type, int value, VARRAY *varray )
+  \brief Set values in 'varray' to 'value' if category of object of given type is in 
+  categories selected from DB based on where statement (given without where).
+  'type' may be either: GV_AREA
+                    or: GV_POINT | GV_LINE | GV_BOUNDARY | GV_CENTROID  
+
+  Array is not reset to zero before, but old values (if any > 0) are overwritten.
+
+  Return: number of items set
+          -1 on error
  */
 int 
 Vect_set_varray_from_db ( struct Map_info *Map, int field, char *where,
                                 int type, int value, VARRAY *varray )
 {
-    int i, n, c, centr, cat, *cats, ncats;
+    int i, n, c, centr, cat, *cats;
+    size_t ncats;
     int ni = 0; /* number of items set */
     int ltype; /* line type */
     struct line_cats *Cats;
