@@ -16,8 +16,9 @@
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
-#include "gis.h"
-#include "Vect.h"
+#include <grass/gis.h>
+#include <grass/Vect.h>
+#include <grass/glocale.h>
 
 /* 
 *   Line offset is
@@ -30,7 +31,7 @@
 
 
 #ifdef HAVE_OGR
-#include "ogr_api.h"
+#include <ogr_api.h>
 
 extern FILE *Msgout;
 extern int prnmsg (char *msg, ...);
@@ -107,7 +108,7 @@ static int add_line ( struct Map_info *Map, int type, struct line_pnts *Points,
 {
     int     line;
     struct  Plus_head *plus;
-    int     offset;
+    long    offset;
     BOUND_BOX box;
 
     plus = &(Map->plus);
@@ -118,7 +119,7 @@ static int add_line ( struct Map_info *Map, int type, struct line_pnts *Points,
 	/* TODO : could be used to statore category ? */
         offset = FID; /* because centroids are read from topology, not from layer */
     }
-    G_debug (4, "Register line: FID = %d offset = %d", FID, offset );
+    G_debug (4, "Register line: FID = %d offset = %ld", FID, offset );
     line = dig_add_line (plus, type, Points, offset );
     G_debug (4, "Line registered with line = %d", line);
 
@@ -149,7 +150,7 @@ static int add_geometry ( struct Map_info *Map, OGRGeometryH hGeom, int FID, GEO
     struct  Plus_head *plus;
     int     i, ret;
     int     line;
-    int     area, isle, outer_area;
+    int     area, isle, outer_area=0;
     int     lines[1];
     static struct line_pnts **Points = NULL;
     static int alloc_points = 0;
@@ -254,7 +255,7 @@ static int add_geometry ( struct Map_info *Map, OGRGeometryH hGeom, int FID, GEO
 	    /* create virtual centroid */
 	    ret = Vect_get_point_in_poly_isl ( Points[0], Points+1, nRings-1, &x, &y );
 	    if (ret < -1) {
-		G_warning ( "Cannot calculate centroid for area %d", outer_area );
+		G_warning (_("Cannot calculate centroid for area %d"), outer_area );
 	    } else { 
                 P_AREA  *Area;
 
@@ -289,7 +290,7 @@ static int add_geometry ( struct Map_info *Map, OGRGeometryH hGeom, int FID, GEO
 	    break;
 
 	default:
-	    G_warning ("OGR feature type %d not supported\n", eType);
+	    G_warning (_("OGR feature type %d not supported)"), eType);
 	    break;
     }
 
@@ -328,8 +329,7 @@ Vect_build_ogr (struct Map_info *Map, int build, FILE * msgout)
     init_parts (&parts);
 
     /* Note: Do not use OGR_L_GetFeatureCount (it may scan all features)!!! */
-
-    prnmsg ("Feature: ", iFeature);
+    prnmsg ("Feature: ");
 
     OGR_L_ResetReading ( Map->fInfo.ogr.layer );
     count = iFeature = 0;
@@ -347,14 +347,14 @@ Vect_build_ogr (struct Map_info *Map, int build, FILE * msgout)
 
 	hGeom = OGR_F_GetGeometryRef (hFeature);
 	if (hGeom == NULL) {
-	    G_warning ("Feature %d without geometry ignored", iFeature);
+	    G_warning (_("Feature %d without geometry ignored"), iFeature);
 	    OGR_F_Destroy( hFeature );
 	    continue;
 	}
 
 	FID = (int) OGR_F_GetFID ( hFeature );
 	if ( FID == OGRNullFID ) {
-	    G_warning ("OGR feature without ID ignored." );
+	    G_warning (_("OGR feature without ID ignored."));
 	    OGR_F_Destroy( hFeature );
 	    continue;
 	}
