@@ -13,15 +13,18 @@
 *               This program is free software under the GNU General Public
 *   	    	License (>=v2). Read the file COPYING that comes with GRASS
 *   	    	for details.
-*
+* TODO: see Vect_read_dblinks; activate auto-FID detection once 
+*       OGR_L_GetFIDColumn() is working or solution found if FID not available
 *****************************************************************************/
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
-#include "glocale.h"
-#include "gis.h"
-#include "dbmi.h"
-#include "Vect.h"
+#include <grass/glocale.h>
+#include <grass/gis.h>
+#include <grass/dbmi.h>
+#include <grass/Vect.h>
+
+#include <gdal_version.h> /* needed for FID detection */
 
 /*!
  \fn struct dblinks *Vect_new_dblinks_struct ( void )
@@ -183,6 +186,7 @@ Vect_add_dblink ( struct dblinks *p, int number, char *name, char *table, char *
 {
     int ret;
     
+    G_debug (3, "Field number <%d>, name <%s>", number, name);
     ret = Vect_check_dblink ( p, number );
     if ( ret == 1 ) {
          G_warning (_("Field number <%d> or name <%s> already exists"), number, name);
@@ -360,7 +364,7 @@ struct field_info
  \param pointer to map structure
 */
 int
-Vect_read_dblinks ( struct Map_info *Map )    
+Vect_read_dblinks ( struct Map_info *Map )
 {
     int  ndef;	
     FILE *fd;
@@ -375,11 +379,58 @@ Vect_read_dblinks ( struct Map_info *Map )
     
     dbl = Map->dblnk;
     Vect_reset_dblinks ( dbl );
-    
+   
+    G_debug (3, "Searching for FID column in OGR DB");
     if ( Map->format == GV_FORMAT_OGR ) {
+
+#if GDAL_VERSION_NUM > 1320 /* seems to be fixed after 1320 release */
+	int i, layer, nLayers;
+	OGRDataSourceH Ogr_ds;
+	OGRLayerH Ogr_layer=NULL;
+	OGRFeatureDefnH Ogr_featuredefn;
+	char ogr_fid_col[1024];
+
+
+	G_debug (3, "GDAL_VERSION_NUM: %d", GDAL_VERSION_NUM);
+
+	/* we open the connection to fetch the FID column name */
+	OGRRegisterAll ();
+
+	/*Data source handle */
+	Ogr_ds = OGROpen (Map->fInfo.ogr.dsn, FALSE, NULL);
+	if (Ogr_ds == NULL)
+	   G_fatal_error ("Cannot open OGR data source '%s'", Map->fInfo.ogr.dsn);
+	Map->fInfo.ogr.ds = Ogr_ds;
+
+	/* Layer number */
+	layer = -1;
+	nLayers = OGR_DS_GetLayerCount (Ogr_ds); /* Layers = Maps in OGR DB */
+
+	G_debug (3, "%d layers (maps) found in data source", nLayers);
+
+	G_debug (3, "Trying to open OGR layer: %s", Map->fInfo.ogr.layer_name);
+	Ogr_layer = OGR_DS_GetLayerByName (Ogr_ds, Map->fInfo.ogr.layer_name);
+	if (Ogr_layer == NULL) {
+	   OGR_DS_Destroy (Ogr_ds);
+	   G_fatal_error ("Cannot open layer '%s'", Map->fInfo.ogr.layer_name);
+	}
+	Ogr_featuredefn = OGR_L_GetLayerDefn (Ogr_layer);
+        G_debug (3, "layer %s, FID col name: %s", OGR_FD_GetName (Ogr_featuredefn), 
+			OGR_L_GetFIDColumn( Ogr_layer ));
+	Map->fInfo.ogr.layer = Ogr_layer;
+	G_debug (3, "OGR Map->fInfo.ogr.layer %p opened", Map->fInfo.ogr.layer);
+
+	/* TODO what to do if OGR_L_GetFIDColumn() doesn't return FID name */
+	sprintf ( ogr_fid_col, "%s", OGR_L_GetFIDColumn( Map->fInfo.ogr.layer ));
+	G_debug (3, "Using FID column <%s> in OGR DB", ogr_fid_col);
+	Vect_add_dblink ( dbl, 1, NULL, Map->fInfo.ogr.layer_name, ogr_fid_col, Map->fInfo.ogr.dsn, "ogr") ;
+#else
 	dbDriver *driver;
 	dbCursor cursor;
 	dbString sql;
+	int FID=0, OGC_FID=0, OGR_FID=0, GID=0;
+
+	G_debug (3, "GDAL_VERSION_NUM: %d", GDAL_VERSION_NUM);
 
 	/* FID is not available for all OGR drivers */
 	db_init_string (&sql);
@@ -391,20 +442,69 @@ Vect_read_dblinks ( struct Map_info *Map )
 	    return -1;
 	}
 
-	sprintf ( buf, "select FID from %s where FID = -1", Map->fInfo.ogr.layer_name );
+      /* this is a bit stupid, but above FID auto-detection doesn't work yet...: */
+	db_auto_print_errors(0);
+	sprintf ( buf, "select FID from %s where FID > 0", Map->fInfo.ogr.layer_name );
 	db_set_string ( &sql, buf );
 
 	if (db_open_select_cursor(driver, &sql, &cursor, DB_SEQUENTIAL) != DB_OK) {
-	    /* FID not available */
-	    db_close_database_shutdown_driver ( driver );
-	    return 0;
-	}
+	    /* FID not available, so we try ogc_fid */
+	    G_debug (3, "Failed. Now searching for ogc_fid column in OGR DB");
+	    sprintf ( buf, "select ogc_fid from %s where ogc_fid > 0", Map->fInfo.ogr.layer_name );
+	    db_set_string ( &sql, buf );
+
+	    if (db_open_select_cursor(driver, &sql, &cursor, DB_SEQUENTIAL) != DB_OK) {
+	        /* Neither FID nor ogc_fid available, so we try ogr_fid */
+	        G_debug (3, "Failed. Now searching for ogr_fid column in OGR DB");
+	        sprintf ( buf, "select ogr_fid from %s where ogr_fid > 0", Map->fInfo.ogr.layer_name );
+	        db_set_string ( &sql, buf );
+
+		if (db_open_select_cursor(driver, &sql, &cursor, DB_SEQUENTIAL) != DB_OK) {
+		   /* Neither FID nor ogc_fid available, so we try gid */
+		   G_debug (3, "Failed. Now searching for gid column in OGR DB");
+		   sprintf ( buf, "select gid from %s where gid > 0", Map->fInfo.ogr.layer_name );
+		   db_set_string ( &sql, buf );
+
+		   if (db_open_select_cursor(driver, &sql, &cursor, DB_SEQUENTIAL) != DB_OK) {
+		      /* neither FID nor ogc_fid nor ogr_fid nor gid available */
+		      G_warning ("All FID tests failed. Neither 'FID' nor 'ogc_fid' nor 'ogr_fid' nor 'gid' available in OGR DB table");
+		      db_close_database_shutdown_driver ( driver );
+		      return 0;
+		   } else
+		      GID=1;
+	        } else
+	            OGR_FID=1;
+	    } else
+	        OGC_FID=1;
+	} else
+	    FID=1;
 	
+	G_debug(3,"FID: %d, OGC_FID: %d, OGR_FID: %d, GID: %d",FID, OGC_FID, OGR_FID, GID);
+
 	db_close_cursor(&cursor);
 	db_close_database_shutdown_driver ( driver );
+	db_auto_print_errors(1);
 	
-	Vect_add_dblink ( dbl, 1, NULL, Map->fInfo.ogr.layer_name, "FID", Map->fInfo.ogr.dsn, "ogr" ) ; 
-	
+	if (FID) {
+	    G_debug (3, "Using FID column in OGR DB");
+	    Vect_add_dblink ( dbl, 1, NULL, Map->fInfo.ogr.layer_name, "FID", Map->fInfo.ogr.dsn, "ogr" ) ;
+	} else {
+	     if (OGC_FID) {
+	         G_debug (3, "Using ogc_fid column in OGR DB");
+	         Vect_add_dblink ( dbl, 1, NULL, Map->fInfo.ogr.layer_name, "ogc_fid", Map->fInfo.ogr.dsn, "ogr" ) ;
+	     } else {
+	         if (OGR_FID) {
+	             G_debug (3, "Using ogr_fid column in OGR DB");
+	             Vect_add_dblink ( dbl, 1, NULL, Map->fInfo.ogr.layer_name, "ogr_fid", Map->fInfo.ogr.dsn, "ogr" ) ;
+		 } else {
+		     if (GID) {
+			G_debug (3, "Using gid column in OGR DB");
+			Vect_add_dblink ( dbl, 1, NULL, Map->fInfo.ogr.layer_name, "gid", Map->fInfo.ogr.dsn, "ogr" ) ;
+		     }
+	         }
+	     }
+	}
+#endif /* GDAL_VERSION_NUM > 1320 */
 	return ( 1 );
     } else if ( Map->format != GV_FORMAT_NATIVE ) {
 	G_fatal_error (_("Don't know how to read links for format %d"), Map->format );
