@@ -14,15 +14,16 @@
 *   	    	for details.
 *
 *****************************************************************************/
-#include "stdlib.h"
-#include "stdio.h"
-#include "string.h"
+
+#include <stdlib.h>
+#include <stdio.h>
+#include <string.h>
 #include <unistd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include "glocale.h"
-#include "gis.h"
-#include "Vect.h"
+#include <grass/glocale.h>
+#include <grass/gis.h>
+#include <grass/Vect.h>
 /*
 
    Routines:    
@@ -38,8 +39,9 @@
 #define MAX_OPEN_LEVEL 2
 
 static int open_old_dummy () { return 0; }
-static int open_new_dummy () { return 0; }
+#ifndef HAVE_OGR
 static int format () { G_fatal_error (_("Requested format is not compiled in this version")); return 0; }
+#endif
 
 static int Open_level = 0;
 
@@ -110,7 +112,7 @@ Vect_set_open_level (int level)
  \param update open for update
  \param head_only Read only header info from 'head', 'dbln', 'topo' and 'cidx'. 
              'cidx' is not opened.
-             The headed may be opened on level 2 only. 
+             The header may be opened on level 2 only. 
 */
 int
 Vect__open_old ( struct Map_info *Map, char *name, char *mapset, int update, int head_only ) 
@@ -191,8 +193,7 @@ Vect__open_old ( struct Map_info *Map, char *name, char *mapset, int update, int
   /* Read vector head */
   if ( Vect__read_head (Map) != GRASS_OK ) {
       sprintf ( errmsg, _("Cannot open old vector %s on level %d"), Vect_get_full_name(Map), level_request ); 
-      fatal_error (ferror, errmsg);
-      return -1;
+      G_warning ( "Cannot read head file." );
   }
   
   G_debug ( 1, "Level request = %d", level_request);
@@ -316,11 +317,11 @@ Vect__open_old ( struct Map_info *Map, char *name, char *mapset, int update, int
           fatal_error (ferror, errmsg);
 	  return (-1);
       }
-      fseek ( Map->hist_fp, 0, SEEK_END);
+      fseek ( Map->hist_fp, (long)0, SEEK_END);
       Vect_hist_write ( Map, "---------------------------------------------------------------------------------\n");
       
   } else {
-      if ( Map->format == GV_FORMAT_NATIVE ) {
+      if ( Map->format == GV_FORMAT_NATIVE || Map->format == GV_FORMAT_OGR ) {
           Map->hist_fp = G_fopen_old (buf, GRASS_VECT_HIST_ELEMENT, Map->mapset);
           /* If NULL (does not exist) then Vect_hist_read() handle that */
       } else { 
@@ -567,6 +568,15 @@ Vect_coor_info ( struct Map_info *Map, struct Coor_info *Info )
 		Info->size = (long) stat_buf.st_size;      /* file size */
 		Info->mtime = (long) stat_buf.st_mtime;    /* last modified time */
 	    }
+            /* stat does not give correct size on MINGW 
+             * if the file is opened */
+#ifdef __MINGW32__
+            if ( Map->open == VECT_OPEN_CODE ) {
+               dig_fseek ( &(Map->dig_fp), 0L, SEEK_END);
+               G_debug ( 2, "ftell = %d", dig_ftell ( &(Map->dig_fp) ) );
+               Info->size = dig_ftell ( &(Map->dig_fp) );
+            }
+#endif
 	    break;
         case GV_FORMAT_OGR :
  	    Info->size = 0L;
@@ -589,7 +599,7 @@ Vect_maptype_info ( struct Map_info *Map )
 {
     char *maptype;
 
-    maptype = G_malloc ( 200 );
+    maptype = G_malloc(sizeof(char) * 200);
     switch (  Map->format ) {
         case GV_FORMAT_NATIVE :
             sprintf (maptype, "native");
