@@ -1,5 +1,5 @@
 /*
-* $Id: list.c,v 1.5 2003/09/11 16:12:48 markus Exp $
+* $Id: list.c,v 1.6 2006/02/09 03:08:58 glynn Exp $
 *
 ****************************************************************************
 *
@@ -18,8 +18,8 @@
 *
 *****************************************************************************/
 #include <stdlib.h>
-#include "gis.h"
-#include "Vect.h"
+#include <grass/gis.h>
+#include <grass/Vect.h>
 
 /* Init int_list */
 int 
