@@ -15,24 +15,19 @@
 *****************************************************************************/
 #include <stdio.h>
 #include <math.h>
+#include <grass/gis.h>
 
-#ifndef M_PI
-#	define M_PI 3.1415926535
-#endif
 #ifndef ABS
 #	define ABS(a) ((a) > 0 ? (a) : -(a))
 #endif
 
 #define EP .0000000001
 
-/* const double log_pi = log(M_PI); */ /* complains: initializer element is not constant */
-double log_pi = 0.49714987268;
-
 double sphere_volume(double dimension)
 {
 	double log_gamma, log_volume;
-	log_gamma = gamma(dimension/2.0 + 1);
-	log_volume = dimension/2.0 * log_pi - log_gamma;
+	log_gamma = lgamma(dimension/2.0 + 1);
+	log_volume = dimension/2.0 * log(M_PI) - log_gamma;
 	return exp(log_volume);
 }
 
