@@ -4,10 +4,13 @@
 */
 
 #include <string.h>
+#include <grass/glocale.h>
+
 #include "ps_info.h"
 #include "colortable.h"
 #include "local_proto.h"
 
+
 #define NSTEPS 3
 #define NNSTEP 4 /* number of nice steps */
 
@@ -32,6 +35,8 @@ int PS_fcolortable (void)
     struct Colors colors;
     struct FPRange range;
     double ex, cur_d, cur_ex;
+    int do_color;
+    double grey_color_val;
 
     /* let user know what's happenning */
     if (verbose > 1)
@@ -43,27 +48,33 @@ int PS_fcolortable (void)
 
     /* Get color range */
     if (G_read_fp_range(ct.name, ct.mapset, &range) == -1) {
-         G_warning( "Range information not available (run r.support).");
-	 return 1;
+	G_warning(_("Range information not available (run r.support)."));
+	return 1;
     }
+
     G_get_fp_range_min_max(&range, &dmin, &dmax);
 
-    if(dmin == dmax)  /* if step==0 all sorts of infinite loops and DIV by 0 errors follow */
-        G_fatal_error("A floating point colortable must contain a range of values.");
-    
-    if (G_read_colors(ct.name, ct.mapset, &colors) == -1)
-    {
-	    G_warning( "Unable to read colors for colorbar\n");
+    /* override if range command is set */
+    if(ct.range_override) {
+	dmin = ct.min;
+	dmax = ct.max;
     }
-    
+
+    if(dmin == dmax) { /* if step==0 all sorts of infinite loops and DIV by 0 errors follow */
+	G_warning(_("A floating point colortable must contain a range of values."));
+	return 1;
+    }
+
+    if (G_read_colors(ct.name, ct.mapset, &colors) == -1)
+	G_warning(_("Unable to read colors for colorbar"));
+
+    do_color = (PS.grey == 0 && PS.level == 2);
+
     /* set font */
     fontsize = (double)ct.fontsize;
     fprintf(PS.fp, "(%s) FN %.1f SF\n", ct.font, fontsize);
 
     /* set colortable location,  */
-    G_debug(3, "pwidth = %f pheight = %f", PS.page_width, PS.page_height);
-    G_debug(3, "ct.width = %f ct.height = %f", ct.width, ct.height);
-
     /* if height and width are not given, calculate defaults */
     if ( ct.width <= 0 )
 	ct.width = 2 * ct.fontsize / 72.0 ;
@@ -72,18 +83,27 @@ int PS_fcolortable (void)
 
     dy = 1.5 * fontsize;
 
+    G_debug(3, "pwidth = %f pheight = %f", PS.page_width, PS.page_height);
+    G_debug(3, "ct.width = %f ct.height = %f", ct.width, ct.height);
+    G_debug(3, "ct.x = %f ct.y = %f", ct.x, ct.y);
+
     /* reset position to get at least something in BBox */
-    if (ct.y < PS.top_marg ) { /* heigher than top margin */
-       	ct.y = PS.top_marg; 
+    if (ct.y < PS.top_marg ) { /* higher than top margin */
+	G_warning(_("Colorbar y location beyond page margins. Adjusting."));
+       	ct.y = PS.top_marg + 0.1;
     } else if (ct.y > PS.page_height - PS.bot_marg ) {
-        /* lower than bottom margin - simply move one inch up from bottom margin */
+	/* lower than bottom margin - simply move one inch up from bottom margin */
+	G_warning(_("Colorbar y location beyond page margins. Adjusting."));
 	ct.y = PS.page_height - PS.bot_marg - 1 ; 
-    };
+    }
     t = 72.0 * ( PS.page_height - ct.y); 
 
     if ( ct.x < PS.left_marg ) {
-	ct.x = PS.left_marg;
-    } else if ( ct.x > PS.page_width - PS.right_marg ) { /* move 1 inch to the left from right marg */
+	G_warning(_("Colorbar x location beyond page margins. Adjusting."));
+	ct.x = PS.left_marg + 0.1;
+    } else if ( ct.x > PS.page_width - PS.right_marg ) {
+	/* move 1 inch to the left from right marg */
+	G_warning(_("Colorbar x location beyond page margins. Adjusting."));
 	ct.x = PS.page_width - PS.right_marg - 1;
     }
     l = 72.0 * ct.x;
@@ -110,7 +130,14 @@ int PS_fcolortable (void)
 /*	val = dmin + i * step;   flip*/
         val = dmax - i * step;
 	G_get_d_raster_color(&val, &R, &G, &B, &colors);
-	fprintf(PS.fp, "%.2f %.2f %.2f C\n", (double)R/255., (double)G/255., (double)B/255.);
+
+	if(do_color)
+	    fprintf(PS.fp, "%.3f %.3f %.3f C\n", (double)R/255., (double)G/255., (double)B/255.);
+	else {
+	    grey_color_val = (.3 * (double)R + .59 * (double)G + .11 * (double)B)/255.;
+	    fprintf(PS.fp, "%.3f setgray\n", grey_color_val);
+	}
+
 	fprintf(PS.fp, "NP\n");
         fprintf(PS.fp, "%f %f M\n", x1, y); 
         fprintf(PS.fp, "%f %f LN\n", x2, y); 
@@ -161,9 +188,10 @@ int PS_fcolortable (void)
     if ( val < dmin ) val += step;
     
     x1 = l + width + 0.1; 
-    /* changed to draw tic through bar ?? */
-    x2 = x1 - width;
-    /* x2 = x1 + 0.5 * width; */
+    if(ct.tickbar)    /* switch to draw tic all the way through bar */
+	x2 = x1 - width;
+    else
+	x2 = x1 + 0.37 * width;
 
     /* do nice label: we need so many decimal places to hold all step decimal digits */	
     if ( step > 100 ) { /* nice steps do not have > 2 digits, important separate, otherwise */
@@ -175,7 +203,7 @@ int PS_fcolortable (void)
 	k = k - (int) ( strchr( buf, '.') - (unsigned) buf );
 	ddig = k;
     }
-	
+
     fprintf(PS.fp, "%.8f W\n", lwidth);
     while ( val <= dmax ) {
 /*      y = t - (val - dmin) * height / (dmax - dmin) ;  flip*/
@@ -191,9 +219,11 @@ int PS_fcolortable (void)
 	if ( ddig > 0 ) ch++;
 	*ch = '\0';
 
-	/* changed text X-location to x1 */
-	fprintf(PS.fp, "(%s) %f %f MS\n", buf, x1 + 0.2 * fontsize , y - 0.35 * fontsize);
-	
+	if(ct.tickbar)    /* switch to draw tic all the way through bar */
+	    fprintf(PS.fp, "(%s) %f %f MS\n", buf, x1 + 0.2 * fontsize , y - 0.35 * fontsize);
+	else
+	    fprintf(PS.fp, "(%s) %f %f MS\n", buf, x2 + 0.2 * fontsize , y - 0.35 * fontsize);
+
 	val += step;
     }
 
