@@ -5,7 +5,7 @@
 */
 
 #include "vector.h"
-#include "Vect.h"
+#include <grass/Vect.h>
 #include "ps_info.h"
 #include "local_proto.h"
 
