@@ -17,11 +17,13 @@ static char *help[] =
     "width      table_width",
     "height     fptable_height",
     "raster	raster_name",
+    "range	min max",
     "cols       columns",
     "font       fontname",
     "fontsize   fontsize",
     "color      color",
-    "nodata	nodata",
+    "nodata     Y|n",
+    "tickbar    y|N"
     ""
 };
 
@@ -31,14 +33,20 @@ read_colortable (void)
     char buf[1024];
     char *key, *data;
     char name[100], mapset[50];
-    int color, fontsize, cols, nodata;
+    int color, fontsize, cols, nodata, tickbar;
     double w, h, x, y;
+    int range_override;
+    double min,max,tmpD;
+
 
     fontsize = 0;
     color = BLACK;
     cols = 1;
     h = w = x = y = 0.0;
     ct.nodata = 1;
+    ct.tickbar = 0;
+    range_override = FALSE;
+
     while (input(2, buf, help))
     {
 	if (!key_data(buf, &key, &data)) continue;
@@ -80,6 +88,25 @@ read_colortable (void)
 		}
 	}
 
+	if (KEY("range"))
+	{
+	    if (sscanf(data, "%lf %lf", &min, &max) != 2)
+	    {
+		range_override = FALSE;
+		error(key, data, "illegal range request");
+	    }
+	    else
+	    {
+		range_override = TRUE;
+		if(min > max) { /* flip if needed */
+		    tmpD = min;
+		    min = max;
+		    max = tmpD;
+		}
+		continue;
+	    }
+	}
+
         if (KEY("cols"))
  	{
 	    if (sscanf(data, "%d", &cols) != 1)
@@ -120,6 +147,12 @@ read_colortable (void)
 	    ct.nodata = nodata;
 	    continue;
         }
+	if (KEY("tickbar"))
+	{
+	    tickbar = yesno(key, data);
+	    ct.tickbar = tickbar;
+	    continue;
+        }
 
 	error(key, data, "illegal colortabe sub-request");
     }
@@ -137,6 +170,9 @@ read_colortable (void)
 	    }
     }
 
+    ct.min = min;
+    ct.max = max;
+    ct.range_override = range_override;
     ct.width = w;
     ct.height = h;
     ct.color = color;
