@@ -1,21 +1,18 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
-#include "gis.h"
-#include "glocale.h"
+#include <grass/gis.h>
+#include <grass/glocale.h>
+#include "local_proto.h"
 #define GLOBAL
 #include "kappa.h"
 
-int calc_kappa();
-int prn_header();
-int prn_error_mat(int,int);
-int stats();
-int layer (char *);
 
-int
-main (argc, argv)
- int argc;
- char *argv[];
+/* function prototypes */
+static void layer(char *s);
+
+
+int main (int argc, char **argv)
 {
  int i;
  struct GModule *module;
@@ -30,7 +27,8 @@ main (argc, argv)
  G_gisinit(argv[0]);
 
  module = G_define_module();
- module->description =
+ module->keywords = _("raster");
+    module->description =
   _("Calculate error matrix and kappa "
   "parameter for accuracy assessment of classification "
   "result.");
@@ -114,8 +112,8 @@ main (argc, argv)
  return 0;
 }
 
-layer (s)
-char *s;
+
+static void layer(char *s)
 {
   char msg[100], name[200], *mapset;
   int n;
@@ -125,6 +123,7 @@ char *s;
     sprintf (msg, "%s: <%s> raster file not found\n", G_program_name(), s);
     G_fatal_error (msg);
   }
+
   n = nlayers++;
   layers = (LAYER *) G_realloc(layers, 2*sizeof(LAYER));
   layers[n].name = G_store (name);
