@@ -1,5 +1,5 @@
 /*
-*$Id: driver.c,v 2.0 2004/11/09 13:43:13 bernhard Exp $
+*$Id: driver.c,v 2.3.4.1 2006/10/06 04:00:08 hamish Exp $
 ************************************************************
 * MODULE: r.le.pixel/driver.c                              *
 *         Version 5.0                Nov. 1, 2001          *
@@ -21,8 +21,9 @@
 ************************************************************/
 
 
+#include <grass/gis.h>
 #include "pixel.h"
-#include "config.h"
+#include <grass/config.h>
 
 
 
@@ -47,7 +48,7 @@ void texture_fore()
 {  
   FILE  *fp0, *fp1, *fp2, *fp3, *fp4, *fp5;
 
-  fprintf(stdout, "\nR.LE.PIXEL IS WORKING....;\n\n", stderr);
+  fprintf(stdout, "\nR.LE.PIXEL IS WORKING....;\n\n");
 
 					/* check for input raster map */
 
@@ -477,7 +478,7 @@ void  mv_driver()
 	   break;
      }
      G_free(nul_buf);
-     free(richwhole);
+     G_free (richwhole);
   }
 
 					/* main loop for clipping & measuring 
@@ -575,7 +576,7 @@ void  mv_driver()
            G_set_null_value(tmp_buf2, x0 + nc + u_w, DCELL_TYPE);
 	   for (b = 0; b < u_l/2; b++)
               G_put_d_raster_row(b1, tmp_buf2);
-           free(tmp_buf2);
+           G_free (tmp_buf2);
 	}
      }
      if (choice->att[2]) {
@@ -597,7 +598,7 @@ void  mv_driver()
            G_set_null_value(tmp_buf2, x0 + nc + u_w, DCELL_TYPE);
 	   for (b = 0; b < u_l/2; b++)
               G_put_d_raster_row(b2, tmp_buf2);
-           free(tmp_buf2);
+           G_free (tmp_buf2);
 	}
      }
      if (choice->att[3]) {
@@ -619,7 +620,7 @@ void  mv_driver()
            G_set_null_value(tmp_buf2, x0 + nc + u_w, DCELL_TYPE);
 	   for (b = 0; b < u_l/2; b++)
               G_put_d_raster_row(b3, tmp_buf2);
-           free(tmp_buf2);
+           G_free (tmp_buf2);
 	}
      }
      if (choice->att[4]) {
@@ -641,7 +642,7 @@ void  mv_driver()
            G_set_null_value(tmp_buf2, x0 + nc + u_w, DCELL_TYPE);
 	   for (b = 0; b < u_l/2; b++)
               G_put_d_raster_row(b4, tmp_buf2);
-           free(tmp_buf2);
+           G_free (tmp_buf2);
 	}
      }
      if (choice->div[1]) {
@@ -663,7 +664,7 @@ void  mv_driver()
            G_set_null_value(tmp_buf2, x0 + nc + u_w, DCELL_TYPE);
 	   for (b = 0; b < u_l/2; b++)
               G_put_d_raster_row(d1, tmp_buf2);
-           free(tmp_buf2);
+           G_free (tmp_buf2);
 	}
      }
      if (choice->div[2]) {
@@ -685,7 +686,7 @@ void  mv_driver()
            G_set_null_value(tmp_buf2, x0 + nc + u_w, DCELL_TYPE);
 	   for (b = 0; b < u_l/2; b++)
               G_put_d_raster_row(d2, tmp_buf2);
-           free(tmp_buf2);
+           G_free (tmp_buf2);
 	}
      }
      if (choice->div[3]) {
@@ -707,7 +708,7 @@ void  mv_driver()
            G_set_null_value(tmp_buf2, x0 + nc + u_w, DCELL_TYPE);
 	   for (b = 0; b < u_l/2; b++)
               G_put_d_raster_row(d3, tmp_buf2);
-           free(tmp_buf2);
+           G_free (tmp_buf2);
 	}
      }
      if (choice->div[4]) {
@@ -729,7 +730,7 @@ void  mv_driver()
            G_set_null_value(tmp_buf2, x0 + nc + u_w, DCELL_TYPE);
 	   for (b = 0; b < u_l/2; b++)
               G_put_d_raster_row(d4, tmp_buf2);
-           free(tmp_buf2);
+           G_free (tmp_buf2);
 	}
      }
      if (choice->te2[1]) {
@@ -751,7 +752,7 @@ void  mv_driver()
            G_set_null_value(tmp_buf2, x0 + nc + u_w, DCELL_TYPE);
 	   for (b = 0; b < u_l/2; b++)
               G_put_d_raster_row(t1, tmp_buf2);
-           free(tmp_buf2);
+           G_free (tmp_buf2);
 	}
      }
      if (choice->te2[2]) {
@@ -773,7 +774,7 @@ void  mv_driver()
            G_set_null_value(tmp_buf2, x0 + nc + u_w, DCELL_TYPE);
 	   for (b = 0; b < u_l/2; b++)
               G_put_d_raster_row(t2, tmp_buf2);
-           free(tmp_buf2);
+           G_free (tmp_buf2);
 	}
      }
      if (choice->te2[3]) {
@@ -795,7 +796,7 @@ void  mv_driver()
            G_set_null_value(tmp_buf2, x0 + nc + u_w, DCELL_TYPE);
 	   for (b = 0; b < u_l/2; b++)
               G_put_d_raster_row(t3, tmp_buf2);
-           free(tmp_buf2);
+           G_free (tmp_buf2);
 	}
      }
      if (choice->te2[4]) {
@@ -817,7 +818,7 @@ void  mv_driver()
            G_set_null_value(tmp_buf2, x0 + nc + u_w, DCELL_TYPE);
 	   for (b = 0; b < u_l/2; b++)
               G_put_d_raster_row(t4, tmp_buf2);
-           free(tmp_buf2);
+           G_free (tmp_buf2);
 	}
      }
      if (choice->te2[5]) {
@@ -839,7 +840,7 @@ void  mv_driver()
            G_set_null_value(tmp_buf2, x0 + nc + u_w, DCELL_TYPE);
 	   for (b = 0; b < u_l/2; b++)
               G_put_d_raster_row(t5, tmp_buf2);
-           free(tmp_buf2);
+           G_free (tmp_buf2);
 	}
      }
      if (choice->jux[1]) {
@@ -861,7 +862,7 @@ void  mv_driver()
            G_set_null_value(tmp_buf2, x0 + nc + u_w, DCELL_TYPE);
 	   for (b = 0; b < u_l/2; b++)
               G_put_d_raster_row(j1, tmp_buf2);
-           free(tmp_buf2);
+           G_free (tmp_buf2);
 	}
      }
      if (choice->jux[2]) {
@@ -883,7 +884,7 @@ void  mv_driver()
            G_set_null_value(tmp_buf2, x0 + nc + u_w, DCELL_TYPE);
 	   for (b = 0; b < u_l/2; b++)
               G_put_d_raster_row(j2, tmp_buf2);
-           free(tmp_buf2);
+           G_free (tmp_buf2);
 	}
      }
      if (choice->edg[1]) {
@@ -905,7 +906,7 @@ void  mv_driver()
            G_set_null_value(tmp_buf2, x0 + nc + u_w, DCELL_TYPE);
 	   for (b = 0; b < u_l/2; b++)
               G_put_d_raster_row(e1, tmp_buf2);
-           free(tmp_buf2);
+           G_free (tmp_buf2);
 	}
      }
      if (choice->edg[2]) {
@@ -927,12 +928,12 @@ void  mv_driver()
            G_set_null_value(tmp_buf2, x0 + nc + u_w, DCELL_TYPE);
 	   for (b = 0; b < u_l/2; b++)
               G_put_d_raster_row(e2, tmp_buf2);
-           free(tmp_buf2);
+           G_free (tmp_buf2);
 	}
      }
 
 
-     free(tmp_buf);
+     G_free (tmp_buf);
   }
 
   time(&finished_time); 
@@ -943,10 +944,10 @@ void  mv_driver()
 					   mask and other buffer */
 
   if (fmask > 0)
-     free(row_buf);
+     G_free (row_buf);
   for (p = 0; p < nc + 1; p++)
-     free(buff[p]);
-  free(buff);
+     G_free (buff[p]);
+  G_free (buff);
 
 					/* close the raster files, set the
 					   color table for the new raster
@@ -1070,8 +1071,8 @@ void  mv_driver()
 					/* SET "OUT" RASTER FILE COLOR
 					   TABLE TO G-Y-R */
 
-void  set_colors(name)
-char *name;
+void set_colors (char *name)
+
 {
   struct Colors colors;
   struct FPRange  fprange;
@@ -1089,8 +1090,8 @@ char *name;
 
 					/* OPEN OUTPUT FILE WITH ERROR TRAP */
 
-FILE  *fopen0(name, flag)
-char *name, *flag;
+FILE *fopen0 (char *name, char *flag)
+
 {
   FILE *fp;
 
@@ -1112,8 +1113,8 @@ char *name, *flag;
 
 					/* OPEN INPUT FILE WITH ERROR TRAP */
 
-FILE  *fopen1(name, flag)
-char *name, *flag;
+FILE *fopen1 (char *name, char *flag)
+
 {
   FILE *fp;
 
@@ -1135,8 +1136,8 @@ char *name, *flag;
 
 					/* OPEN WEIGHT FILE WITH ERROR TRAP */
 
-FILE  *fopen2(name, flag)
-char *name, *flag;
+FILE *fopen2 (char *name, char *flag)
+
 {
   FILE *fp;
 
@@ -1157,8 +1158,8 @@ char *name, *flag;
 
 					/* OPEN EDGE FILE WITH ERROR TRAP */
 
-FILE  *fopen3(name, flag)
-char *name, *flag;
+FILE *fopen3 (char *name, char *flag)
+
 {
   FILE *fp;
 
@@ -1181,8 +1182,8 @@ char *name, *flag;
 					   AS A COUNT AND ESTIMATED COMPLETION
                                            TIME WHILE THE PROGRAM RUNS */
 
-void   meter2(n, i, div)
-int  n, i, div;
+void meter2 (int n, int i, int div)
+
 { 
   long  current_time, time_left, elapsed, complete;
   static long start;
@@ -1226,9 +1227,8 @@ int  n, i, div;
 					/* READ IN THE MOVING WINDOW
 					   PARAMETERS */
 
-void  read_mwind(uw, ul, nc, nr, x0, y0, radius)
-int *uw, *ul, *nc, *nr, *x0, *y0;
-float *radius;
+void read_mwind (int *uw, int *ul, int *nc, int *nr, int *x0, int *y0, float *radius)
+
 {
   FILE  *fp;
   int   ww, wl;
@@ -1252,7 +1252,7 @@ float *radius;
   *nc = ww - *uw + 1;  
   *nr = wl - *ul + 1;
 
-  free(buf);
+  G_free (buf);
   fclose(fp);
 
   return;
@@ -1380,7 +1380,7 @@ void  unit_driver()
 	   break;
      }
      G_free(nul_buf);
-     free(richwhole);
+     G_free (richwhole);
   }
 
                       			/* dynamically allocate storage for the
@@ -1476,16 +1476,16 @@ void  unit_driver()
            G_put_raster_row(fd, unit_buf, CELL_TYPE);
         }
         G_close_cell(fd);
-        free(unit_buf);
+        G_free (unit_buf);
      }
   }
 
   if (choice->units) {
      for (m = 0; m < wind.rows + 3; m++)
-        free(units[m]);
-     free(units);
+        G_free (units[m]);
+     G_free (units);
   }
-  free(buf);
+  G_free (buf);
   fclose(fp);
   return;
 }
@@ -1498,10 +1498,8 @@ void  unit_driver()
 					   CALL CELL CLIP DRIVER */
 
 
-void  run_clip(ncols, nrows, u_w, u_l, left, top, units, id, cntwhole, radius)
-int  ncols, nrows, u_w, u_l, left, top, id, cntwhole;
-float radius;
-CELL  **units;
+void run_clip (int ncols, int nrows, int u_w, int u_l, int left, int top, CELL **units, int id, int cntwhole, float radius)
+
 {
 int i,j;
 double center_row, center_col;
@@ -1676,7 +1674,7 @@ void  whole_reg_driver()
 	   break;
      }
      G_free(nul_buf);
-     free(richwhole);
+     G_free (richwhole);
   }
 
   if(choice->wrum != 'r') {
@@ -1736,8 +1734,8 @@ void  whole_reg_driver()
         ptrthis = ptrthis->next;
      }
      G_close_cell(fr);
-     free (row_buf);
-     free(ptrnew);
+     G_free (row_buf);
+     G_free (ptrnew);
   }
 
   return;
@@ -1753,9 +1751,8 @@ void  whole_reg_driver()
                                            THE RICHNESS ARRAY IN UNSORTED
                                            ORDER */
 
-void  get_rich_whole(att, rich, cnt)
-double   att, rich[]; 
-int     *cnt;
+void get_rich_whole (double att, double rich[], int *cnt)
+
 {
   register int i;
                                         /* if this attribute is already
