@@ -23,102 +23,80 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include "gis.h"
-#include "display.h"
-#include "raster.h"
+#include <sys/types.h>
+#include <dirent.h>
 
-#define MAIN
+#include <grass/config.h>
+#include <grass/gis.h>
+#include <grass/raster.h>
+#include <grass/display.h>
+#include <grass/glocale.h>
 #include "setup.h"
-#include "config.h"
 
 
-void user_input(int, char **);
+static void get_pwd(void);
+
+jmp_buf jmp;
 				/* MAIN PROGRAM */
 
-int
-main(argc, argv)
-int  argc;
-char *argv[];
+int main (int argc, char *argv[])
 {
 
-				/* setup a structure to store the window
-				   parameters */
+    struct GModule *module;
+    struct Option *input, *vect;
 
-  struct Cell_head  window;
-  int               bot, right, t0, b0, l0, r0, respond, clear=0;
-  double 	    Rw_l, Rscr_wl;
-  char 		    tmp[20], *v_name=NULL, *s_name=NULL;
+    struct Cell_head  window;
+    int bot, right, t0, b0, l0, r0, clear=0;
+    double Rw_l, Rscr_wl;
+    char *map_name=NULL, *v_name=NULL, *s_name=NULL;
+
+    /* Initialize the GIS calls */
+    G_gisinit(argv[0]);
+
+    /* must run in a term window */
+    G_putenv("GRASS_UI_TERM","1");
+
+    module = G_define_module();
+    module->keywords = _("raster");
+    module->description =
+      _("Interactive tool used to setup the sampling and analysis framework "
+	"that will be used by the other r.le programs.");
+
+    input = G_define_standard_option(G_OPT_R_MAP);
+    input->description = _("Raster map to use to setup sampling");
+
+    vect = G_define_standard_option(G_OPT_V_INPUT);
+    vect->key	      = "vect";
+    vect->description = _("Vector map to overlay");
+    vect->required    = NO ;
+
+    if (G_parser(argc, argv))
+        exit(EXIT_FAILURE);
 
-  char              name[20];
-  char              map_name[20];
-  char              info[20];
-  char              *mapset;
 
   setbuf (stdout, NULL);	/* unbuffered */
   setbuf (stderr, NULL);
-  G_gisinit(argv[0]); 
 
-  G_sleep_on_error(0);
+  G_sleep_on_error(1);  /* error messages get lost on clear screen */
 
 
-				/* get the user input */
-
-  user_input(argc,argv) ; 
-
-				/* query for the map to be setup */
-
-  fprintf(stderr, "\n") ;
-  fprintf(stderr, "OPTION   Raster map to use to setup sampling\n") ;
-  fprintf(stderr, "     key:map\n") ;
-  fprintf(stderr, "required:YES\n") ;
-  fprintf(stderr, "\n") ;
-
-  mapset = G_ask_cell_old("enter raster map name: ",map_name) ;
-  if (mapset == NULL) exit(0) ;
-
-
-				/* query for a vector map overlay */
-
-  fprintf(stderr, "\n") ;
-  fprintf(stderr, "OPTION   Vector map to overlay.\n") ;
-  fprintf(stderr, "     key:vect\n") ;
-  fprintf(stderr, "required:NO\n") ;
-  fprintf(stderr, "\n") ;
-
-  if ( G_yes("Overlay a vector file? ",0)) {
-      G_ask_vector_old("enter vector file name to be overlaid: ",name) ;
-      v_name = G_malloc(30);
-      strcpy(v_name, name);
-     }
-
-				/* query for a site map overlay */
-
-  fprintf(stderr, "\n") ;
-  fprintf(stderr, "OPTION   Site map to overlay.\n") ;
-  fprintf(stderr, "     key:site\n") ;
-  fprintf(stderr, "required:NO\n") ;
-  fprintf(stderr, "\n") ;
-
-
-   if ( G_yes("Overlay a site file? ",0)) {
-      mapset=G_ask_sites_old("enter site map to overlay", info) ;
-      if (mapset == NULL) exit(0) ;
-      G_fopen_sites_old(info,mapset) ;
-      s_name = G_malloc(30);
-      strcpy(s_name, info);
-   }
-
+  map_name = input->answer;
+  v_name = vect->answer;
+  s_name = NULL;  /* sites not used in GRASS 6 */
 
+  /* setup the r.le.para directory */
   get_pwd();
 
-  				/* setup the current window for 
-				   display */
+  /* query for the map to be setup */
+  if (R_open_driver() != 0)
+      G_fatal_error ("No graphics device selected");
+
+  /* setup the current window for display & clear screen */
+  D_setup(1);
 
-  G_system(" d.colormode fixed");
-  G_system(" d.frame -e");
   Rw_l = (double)G_window_cols()/G_window_rows();
-  R_open_driver(); 
-  R_font("romant");
+  /*R_open_driver(); */
+  /* R_font("romant");*/
   G_get_set_window(&window);
   t0 = R_screen_top();
   b0 = R_screen_bot();
@@ -135,7 +113,6 @@ char *argv[];
     right = r0;
     bot = t0 + (r0 - l0) / Rw_l; 
   }
-
   D_new_window("a", t0, bot, l0, right);
   D_set_cur_wind("a");
   D_show_window(D_translate_color("green"));
@@ -143,18 +120,16 @@ char *argv[];
   R_close_driver();
 
   				/* invoke the setup modules */
-
   set_map(map_name, v_name, s_name, window, t0, bot, l0, right);
+
+  return (EXIT_SUCCESS);
 }
 
 
 
 
-
-
-				/* SETUP THE R.LE.PARA DIRECTORY */
-
-void   get_pwd()
+/* SETUP THE R.LE.PARA DIRECTORY */
+static void get_pwd(void)
 {
   DIR    *dp;
 
