@@ -21,11 +21,14 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
-#include "gis.h"
-#include "raster.h"
-#include "display.h"
-#include "config.h"
+#include <grass/config.h>
+#include <grass/gis.h>
+#include <grass/raster.h>
+#include <grass/display.h>
+#include <grass/glocale.h>
+
 #include "r.le.trace.h"
+#include "local_proto.h"
 
 struct CHOICE 		*choice;
 int   			finput;
@@ -33,32 +36,33 @@ int   			total_patches=0;
 PATCH 			*patch_list = NULLPTR;
 FILE  			*fp;
 
-
-void user_input(int, char **);
-
 				/* MAIN PROGRAM */
-
-int main(argc, argv)
-int  argc;
-char *argv[];
+int main (int argc, char *argv[])
 {
+  struct GModule *module;
   struct Cell_head  window;
-  int               bot, right, t0, b0, l0, r0;
+  int               bot, right, t0, b0, l0, r0, clear=0;
   double 	    Rw_l, Rscr_wl;
   char 		    tmp[20];
   void 		    set_map();
 
   setbuf (stdout, NULL);	/* unbuffered */
   setbuf (stderr, NULL);
+
   G_gisinit(argv[0]); 
 
-
   choice = (struct CHOICE *) G_calloc(1, sizeof(struct CHOICE));
 
+    module = G_define_module();
+    module->keywords = _("raster");
+    module->description =
+      _("Display the boundary of each r.le patch and show how the boundary "
+	"is traced, display the attribute, size, perimeter, and shape "
+	"indices for each patch, and save the data in an output file.");
+
   user_input(argc,argv) ;
 
   				/* setup the current window for display */
-
   G_system(" d.colormode float");
   G_system(" d.frame -e");
   Rw_l = (double)G_window_cols()/G_window_rows();
@@ -79,7 +83,7 @@ char *argv[];
     bot = t0 + (r0 - l0) / Rw_l; 
   }
 
-  D_setup(0);
+  D_setup(clear);
   D_new_window("a", t0, bot, l0, right);
   D_set_cur_wind("a");
   D_show_window(D_translate_color("green"));
@@ -95,7 +99,9 @@ char *argv[];
   else
      set_map(choice->fn, window, t0, bot, l0, right, NULL);
 
-  free(choice) ;
+  G_free (choice) ;
+
+  return (EXIT_SUCCESS);
 }
 
 
@@ -105,10 +111,8 @@ char *argv[];
 				/* DISPLAY A MESSAGE AND THE MAP, THEN
 				   TRACE THE PATCHES AND DISPLAY THEM */
 
-void set_map( name, window, top, bot, left, right, fn)
-char   *name, *fn;
-struct Cell_head    window;
-int                 top, bot, left, right;
+void set_map (char *name, struct Cell_head window, int top, int bot, int left, int right, char *fn)
+
 {
   char    cmd[30];
   int     i, k=0, j,  btn, d, class;
@@ -149,9 +153,8 @@ int                 top, bot, left, right;
 
 				/* DISPLAY THE PATCH INFORMATION */
 
-void  show_patch(fn, msc, cmd)
-char    *fn, *cmd;
-double  *msc;
+void show_patch (char *fn, double *msc, char *cmd)
+
 {
   PATCH   *tmp, *tmp0;
   register int  i;
@@ -189,7 +192,7 @@ double  *msc;
         }
         else{
            G_warning("\nThe patch is not in the patch-list.\n");
-	   sleep(1);
+	   G_sleep(1);
         }
      }
   }
@@ -237,9 +240,9 @@ double  *msc;
         patch_attr(fp, tmp, 1);
         tmp0 = tmp;
         tmp = tmp->next;
-        free(tmp0->row);
-        free(tmp0->col);
-        free(tmp0);
+        G_free (tmp0->row);
+        G_free (tmp0->col);
+        G_free (tmp0);
      }
   }
   else {
@@ -250,9 +253,9 @@ double  *msc;
            patch_attr(fp, tmp, 1);
            tmp0 = tmp;
            tmp = tmp->next;
-           free(tmp0->row);
-           free(tmp0->col);
-           free(tmp0);
+           G_free (tmp0->row);
+           G_free (tmp0->col);
+           G_free (tmp0);
         }
      }
      else {
@@ -260,9 +263,9 @@ double  *msc;
            patch_attr(fp, tmp, 0);
            tmp0 = tmp;
            tmp = tmp->next;
-           free(tmp0->row);
-           free(tmp0->col);
-           free(tmp0);
+           G_free (tmp0->row);
+           G_free (tmp0->col);
+           G_free (tmp0);
         }
      }
   }
@@ -273,10 +276,8 @@ double  *msc;
 
 				/* DISPLAY PATCH ATTRIBUTES ON THE SCREEN */
 
-void  patch_attr(fp, p, show)
-PATCH *p;
-FILE *fp;
-int   show;
+void patch_attr (FILE *fp, PATCH *p, int show)
+
 {
   double  shp1, shp2, shp3;
 
@@ -322,9 +323,8 @@ skip:
 
 				/* PLACE PATCH NUMBERS ON THE SCREEN */
 
-void   draw_patch(p, m)
-PATCH  *p;
-double *m;
+void draw_patch (PATCH *p, double *m)
+
 {
   register int  i;
   int           r0, c0, r1, c1;
@@ -352,10 +352,8 @@ double *m;
 				/* SETUP THE CONVERSION BETWEEN SCREEN AND
 				   ARRAY SYSTEMS */
 
-void  scr_cell(wind, top, bot, left, right, m)
-struct Cell_head  *wind;
-int    top, bot, left, right;
-double  *m;
+void scr_cell (struct Cell_head *wind, int top, int bot, int left, int right, double *m)
+
 { 
   m[0] = (right - left) / (double)wind->cols;
   m[1] = (bot - top) / (double)wind->rows;
@@ -369,9 +367,8 @@ double  *m;
 				/* DRIVER FOR CELL CLIPPING, TRACING,
 				   AND CALCULATIONS */
 
-void  cell_clip_drv(col0, row0, ncols, nrows, value, index)
-int     row0, col0, nrows, ncols, index;
-double  **value;
+void cell_clip_drv (int col0, int row0, int ncols, int nrows, double **value, int index)
+
 {
   CELL         	**pat, *pat_buf;
   DCELL         **buf;
@@ -481,9 +478,9 @@ double  **value;
 /*  if (total_patches) {
      list_head = patch_list;
      while(list_head) {
-        free(list_head->col);
-        free(list_head->row);
-        free(list_head);
+        G_free (list_head->col);
+        G_free (list_head->row);
+        G_free (list_head);
         list_head = list_head->next;
      }
   }
@@ -496,11 +493,7 @@ double  **value;
 				/* OPEN THE RASTER FILE TO BE CLIPPED,
 				   AND DO THE CLIPPING */
 
-void  cell_clip(buf, null_buf, row0, col0, nrows, ncols, index,
-                centernull)
-DCELL  **buf;
-DCELL  **null_buf;
-int      row0, col0, nrows, ncols, index, *centernull;
+void cell_clip (DCELL **buf, DCELL **null_buf, int row0, int col0, int nrows, int ncols, int index, int *centernull)
 
 {
   CELL            *tmp, *tmp1;
@@ -711,13 +704,13 @@ int      row0, col0, nrows, ncols, index, *centernull;
 
   switch (data_type) {
      case CELL_TYPE:
-        free(tmp);
+        G_free (tmp);
         break;
      case FCELL_TYPE:
-        free(ftmp);
+        G_free (ftmp);
         break;
      case DCELL_TYPE:
-        free(dtmp);
+        G_free (dtmp);
         break;
   }
   return;
@@ -729,11 +722,8 @@ int      row0, col0, nrows, ncols, index, *centernull;
 				   THE TRACING ROUTINE, AND ADD NEW PATCHES
 				   TO THE PATCH LIST */
 
-void  trace(nrows, ncols, buf, null_buf, pat)
-int     nrows, ncols;
-DCELL **buf;
-DCELL **null_buf;
-CELL  **pat;
+void trace (int nrows, int ncols, DCELL **buf, DCELL **null_buf, CELL **pat)
+
 {
   double        class=0.0;
   register int  i, j, x;
@@ -851,13 +841,8 @@ CELL  **pat;
 				   SAVE THE PATCH CHARACTERISTICS IN
 				   THE PATCH STRUCTURE */
 
-PATCH *get_bd(row0, col0, nrows, ncols, class, buf, null_buf, p_list, pat)
-int       row0, col0, nrows, ncols;
-double    class;
-DCELL   **buf;
-DCELL   **null_buf;
-CELL    **pat;
-PATCH    *p_list;
+PATCH *get_bd (int row0, int col0, int nrows, int ncols, double class, DCELL **buf, DCELL **null_buf, PATCH *p_list, CELL **pat)
+
 {
   int       i = row0, j = col0, pts=0, di=0, dj=-1,
             not_done, k, m, tmp, lng=0, roww=0, rowe=0,
@@ -1286,7 +1271,7 @@ i,j,i+1,j-1,*(*(buf + i + 1) + j - 1),*(*(patchmap + i + 1) + j - 1),
         }
 
         ptrthis = ptrthis->next;
-        free(ptrfree);
+        G_free (ptrfree);
         i++;
      }
 
@@ -1313,14 +1298,14 @@ i,j,i+1,j-1,*(*(buf + i + 1) + j - 1),*(*(patchmap + i + 1) + j - 1),
 
         twist2 = (int ***)G_calloc(trows + 3, sizeof(int **));
         for (i = 0; i < trows + 3; i++) {
-           twist2[i] = (int **)G_calloc(tcols + 3, sizeof(int));
+           twist2[i] = (int **)G_calloc(tcols + 3, sizeof(int*));
            for (j = 0; j < tcols + 3; j++)
               twist2[i][j] = (int *)G_calloc(7, sizeof(int));
         }
 
         twistP = (float ***)G_calloc(trows + 3, sizeof(float **));
         for (i = 0; i < trows + 3; i++) {
-          twistP[i] = (float **)G_calloc(tcols + 3, sizeof(float));
+          twistP[i] = (float **)G_calloc(tcols + 3, sizeof(float*));
           for (j = 0; j < tcols + 3; j++)
              twistP[i][j] = (float *)G_calloc(7, sizeof(float));
         }
@@ -1495,8 +1480,8 @@ patch->omega,patch->area);
 				/* free the memory allocated for patchmap */
 
      for (i = 0; i < nrows + 3; i++)
-        free(patchmap[i]);
-     free(patchmap);
+        G_free (patchmap[i]);
+     G_free (patchmap);
 
          			/* send the patch info back to trace */
 
@@ -1517,10 +1502,7 @@ patch->omega,patch->area);
 				   THE FIRST PIXEL FOUND; OTHERWISE RETURN
 				   A ZERO */
 
-int  yes_nb(di, dj, buf, class, i, j, nrows, ncols)
-int      *di, *dj, i, j, nrows, ncols;
-double    class;
-DCELL   **buf;
+int yes_nb (int *di, int *dj, DCELL **buf, double class, int i, int j, int nrows, int ncols)
 
 {
 
@@ -1653,8 +1635,7 @@ ncols=%d\n",i,*di,j,*dj,nrows,ncols);*/
 
 				/* CIRCLE CLOCKWISE AROUND THE CURRENT PT */
 
-void  clockwise(i, j)
-int    *i, *j;
+void clockwise (int *i, int *j)
 
 {
   if (*i != 0 && *j != -*i)
@@ -1663,8 +1644,3 @@ int    *i, *j;
      *i += *j;
   return;
 }
-
-
-
-
-
