@@ -1,6 +1,6 @@
 
-#include "gis.h"
-#include "G3d.h"
+#include <grass/gis.h>
+#include <grass/G3d.h>
 #include "globals.h"
 #include "globals3.h"
 #include "expression.h"
