@@ -1,7 +1,7 @@
 
 #include <math.h>
 
-#include "gis.h"
+#include <grass/gis.h>
 #include "globals.h"
 #include "expression.h"
 #include "func_proto.h"
