@@ -1,5 +1,5 @@
 
-#include "gis.h"
+#include <grass/gis.h>
 #include "globals.h"
 #include "expression.h"
 #include "func_proto.h"
