@@ -1,4 +1,4 @@
-#include "gis.h"
+#include <grass/gis.h>
 
 DCELL c_ave (
     register DCELL *values,
