@@ -2,14 +2,14 @@
 
 #include <stdio.h>
 #include <math.h>
-#include "gis.h"
+#include <grass/gis.h>
 #include "flag.h"
 
 #define ODD(a)	((a) & 1)
 
 #define SEED_MAX		54772
 #define SEED_MIN		0
-#define PI       		3.141592653589793116
+#define PI       		M_PI
 
 #ifdef MAIN
 #define GLOBAL
@@ -30,7 +30,6 @@ GLOBAL  FLAG	*Cells;
 GLOBAL  CELLSORTER *DoNext;
 GLOBAL	CELL	**Out, *CellBuffer;
 GLOBAL	int	Seed, OutFD;
-GLOBAL	char	Buf[240], *OutName, *Mapset;
 GLOBAL	struct Flag *Verbose;
 GLOBAL  struct Option *Distance;
 GLOBAL  struct Option *Output;
