@@ -1,20 +1,17 @@
 /* makepp.c								*/
 
-#define TRACE
 #undef TRACE
-#define DEBUG
 #undef DEBUG
 
 #undef MAIN
 #include "ransurf.h"
+#include "local_proto.h"
 
-double
-MakePP( Row, Col, OutRows, OutCols, Randoms, BigF)
-	int	Row, Col, OutRows, OutCols;
-	double	**Randoms;
-	BIGF	BigF;
+
+double MakePP(int Row, int Col, int OutRows, int OutCols,
+              double **Randoms, BIGF BigF)
 {
-	int	DRow, DCol, LR, HR, LC, HC;
+	int	DRow, DCol;
 	int	RRow, RCol;
 	double	Effect, Value;
 
@@ -23,9 +20,11 @@ MakePP( Row, Col, OutRows, OutCols, Randoms, BigF)
 	Value = 0.0;
 	RRow = Row + BigF.RowPlus;
 	RCol = Col + BigF.ColPlus;
+
 	for( DRow = RRow - BigF.RowPlus;
 	     DRow <= RRow + BigF.RowPlus; DRow++) {
 	    /* if( BigF.LowBF  this to speed up function */
+
 	    for( DCol = RCol - BigF.ColPlus;
 		 DCol <= RCol + BigF.ColPlus; DCol++) {
 		DistDecay( &Effect, RRow-DRow, RCol-DCol);
@@ -36,6 +35,7 @@ MakePP( Row, Col, OutRows, OutCols, Randoms, BigF)
 		Value += Effect * Randoms[ DRow][ DCol];
 	    }
 	}
+
 	return( Value);
 	FUNCTION(end MakePP);
 }
