@@ -1,33 +1,30 @@
 /* save.c								*/
 
-#define TRACE
 #undef TRACE
-#define DEBUG
 #undef DEBUG
 
 #undef MAIN
 #include <string.h>
+#include <grass/gis.h>
 #include "ransurf.h"
 
-SaveMap( NumMap, MapSeed)
-	int	NumMap, MapSeed;
+
+void SaveMap(int NumMap, int MapSeed)
 {
 	int	Index, Row, Col, NormIndex;
-	int	LowColor, MidColor, HighColor;
-	double	DownInterval, UpInterval, Value, 
-		Ratio, Mean, StdDev, MeanMod;
-        double  MaxDist, Me, Va, SD, DI, UI, AD, Sk, Cu;
+	int	LowColor, HighColor;
+	double	DownInterval, UpInterval, Value=0,
+		Ratio, MeanMod;
 	struct Categories	Cats;
     	struct Colors 		Colr;
 	char	String[80], Label[240];
 	FUNCTION(SaveMap);
 
 	OutFD = G_open_cell_new( OutNames[ NumMap]);
-	if( OutFD < 0) {
-		sprintf( Buf, "%s: unable to open new raster map [%s]",
+	if (OutFD < 0)
+		G_fatal_error("%s: unable to open new raster map [%s]",
 			G_program_name(), OutNames[ NumMap]);
-		G_fatal_error( Buf);
-	}
+
 	MeanMod = 0.0;
 	INT(FDM);
 	if( FDM == -1) {
@@ -37,6 +34,7 @@ SaveMap( NumMap, MapSeed)
 			MeanMod += Value;
 		}
 	    }
+
 	    MeanMod /= MapCount;
 	    /* Value = (Value - MeanMod) / FilterSD + MeanMod / FilterSD; */
 	    Value /= FilterSD;
@@ -50,8 +48,10 @@ SaveMap( NumMap, MapSeed)
 			*/
 			Value /= FilterSD;
 			Surface[ Row][ Col] = Value;
+
 			if( UpInterval < Value)
 				UpInterval = Value;
+
 			if( DownInterval > Value)
 				DownInterval = Value;
                 }
@@ -66,6 +66,7 @@ SaveMap( NumMap, MapSeed)
                     }
                 }
             }
+
 	    MeanMod /= MapCount;
 	    DOUBLE(MeanMod);
 	    DOUBLE(FilterSD);
@@ -74,6 +75,7 @@ SaveMap( NumMap, MapSeed)
 	    DOUBLE(Value);
 	    RETURN;
 	    DownInterval = UpInterval = Value;
+
             for (Row = 0; Row < Rs; Row++) {
                 G_get_map_row_nomask( FDM, CellBuffer, Row);
                 for (Col = 0; Col < Cs; Col++) {
@@ -85,26 +87,32 @@ SaveMap( NumMap, MapSeed)
 			*/
 			Value /= FilterSD;
 			Surface[ Row][ Col] = Value;
+
 			if( UpInterval < Value)
 				UpInterval = Value;
+
 			if( DownInterval > Value)
 				DownInterval = Value;
 		    }
                 }
             }
         }
+
 	if(! Verbose->answer) {
 		printf("\n%s: saving [%s] raster map layer.\nPercent complete:",
 			G_program_name(), OutNames[ NumMap]);
 	}
+
         for (Index = 0; Index < CatInfo.NumCat; Index++) {
                 CatInfo.Max[Index] =  DownInterval;
                 CatInfo.Min[Index] =  UpInterval;
                 CatInfo.NumValue[Index] = 0;
                 CatInfo.Average[Index] =  0.0;
         }
+
 	if( DownInterval == UpInterval)
 		UpInterval += .1;
+
         if( ! Uniform->answer) {
 	     FUNCTION(NOT_UNIFORM);
              /* normal distribution */
@@ -116,16 +124,21 @@ SaveMap( NumMap, MapSeed)
 			} else if( Value < DownInterval) {
 				Value = DownInterval;
 			}
+
                         Ratio = (Value - DownInterval) /
                                         (UpInterval - DownInterval);
+
                         /* Ratio in the range of [0..1] */
                         Index = (int) ((Ratio * CatInfo.NumCat) - .5);
                         CatInfo.NumValue[Index]++;
                         CatInfo.Average[Index] += Value;
+
                         if ( Value > CatInfo.Max[Index])
                                 CatInfo.Max[Index] = Value;
+
                         if ( Value < CatInfo.Min[Index])
                                 CatInfo.Min[Index] = Value;
+
                         Surface[Row][ Col] = 1 + Index;
                 }
              }
@@ -142,15 +155,19 @@ SaveMap( NumMap, MapSeed)
                         /* record the catogory information */
                         CatInfo.NumValue[NormIndex]++;
                         CatInfo.Average[NormIndex] += Value;
+
                         if ( Value > CatInfo.Max[NormIndex])
                                 CatInfo.Max[NormIndex] = Value;
+
                         if ( Value < CatInfo.Min[NormIndex])
                                 CatInfo.Min[NormIndex] = Value;
+
                         /* NormIndex in range of [0 .. (CatInfo.NumCat-1)] */
                         Surface[ Row][ Col] = 1 + NormIndex;
                 }
              }
         }
+
 	for( Row = 0; Row < Rs; Row++) {
 		for( Col = 0; Col < Cs; Col++) {
 			CellBuffer[ Col] = (CELL) Surface[ Row][ Col];
@@ -159,14 +176,17 @@ SaveMap( NumMap, MapSeed)
         	if(! Verbose->answer)
 			G_percent( Row + 1, Rs, 1);
 	}
+
 	G_close_cell( OutFD);
 	strcpy( Label, Buf);
 	sprintf( String, " seed=%d", MapSeed);
 	strcat ( Label, String);
+
 	/*
 	if( NumMap == 0 && Theory > 0)
 		TheoryCovariance( TheoryName, Label);
 	*/
+
 	G_init_cats( CatInfo.NumCat, Label, &Cats);
 	for( Index = 0; Index < CatInfo.NumCat; Index++) {
 	      if( CatInfo.NumValue[Index] != 0){
@@ -178,20 +198,22 @@ SaveMap( NumMap, MapSeed)
 	              G_set_cat( 1 + Index, Label, &Cats);
 	      }
 	}
+
 	G_write_cats( OutNames[ NumMap], &Cats);
     	G_init_colors( &Colr);
 	LowColor = (int) (127.5 * (CatInfo.Average[0] + 3.5) / 3.5);
 	HighColor = (int) (255.0 - 127.5 * 
 			(3.5 - CatInfo.Average[CatInfo.NumCat-1]) / 3.5);
+
 	if( Uniform->answer || LowColor < 0) LowColor = 0;
 	if( Uniform->answer || HighColor > 255) HighColor = 255;
 	INT(LowColor);
 	INT(HighColor);
+
     	G_add_color_rule( 1, LowColor, LowColor, LowColor,
 			  High, HighColor, HighColor, HighColor, &Colr);
-    	if( G_write_colors( OutNames[ NumMap], G_mapset(), &Colr) == -1) {
-        	sprintf( Buf, "%s: unable to write colr file for %s\n",
+
+    	if( G_write_colors( OutNames[ NumMap], G_mapset(), &Colr) == -1)
+        	G_warning("%s: unable to write colr file for %s\n",
                 	G_program_name(), OutNames[ NumMap]);
-        	G_warning( Buf);
-    	}
 }
