@@ -7,9 +7,9 @@
 
 #include <stdlib.h>
 #include <stdio.h>
-#include "gis.h"
+#include <grass/gis.h>
 #include "local_proto.h"
-#include "glocale.h"
+#include <grass/glocale.h>
 
 int 
 main (int argc, char *argv[])
@@ -34,7 +34,8 @@ main (int argc, char *argv[])
 					recalled using G_program_name(). */
 
 	module = G_define_module();
-	module->description =
+	module->keywords = _("raster");
+    module->description =
 		_("GRASS module to produce a raster map layer of "
 		"gaussian deviates whose mean and standard deviation "
 		"can be expressed by the user. It uses a gaussian "
