@@ -1,6 +1,6 @@
-#include <unistd.h>
 #include <stdlib.h>
-#include "gis.h"
+#include <unistd.h>
+#include <grass/gis.h>
 #include "local_proto.h"
 
 int read_cell (char *name)
