@@ -31,8 +31,9 @@
 #include <math.h>
 #include "binio.h"
 #include "v5d.h"
-#include "gis.h"
-#include "G3d.h"
+#include <grass/gis.h>
+#include <grass/G3d.h>
+#include <grass/glocale.h>
 
 #define MAX(a,b) (a > b ? a : b)
 
@@ -42,9 +43,7 @@ void *map = NULL;
 
 /*---------------------------------------------------------------------------*/
 static void
-fatalError (errorMsg)
-
-     char *errorMsg;
+fatalError  (char *errorMsg)
 
 {
   if (map != NULL) {
@@ -93,11 +92,7 @@ setParams ()
 /*---------------------------------------------------------------------------*/
 
 static void
-getParams (input, output, convertNull, nullValue)
-
-     char **input, **output;
-     int *convertNull;
-     double *nullValue;
+getParams  (char **input, char **output, int *convertNull, double *nullValue)
 
 {
  *input = param.input->answer;
@@ -110,12 +105,7 @@ getParams (input, output, convertNull, nullValue)
 
 /*---------------------------------------------------------------------------*/
 
-void convert (openFile, region, convertNull, nullValue)
-
-     char *openFile;
-     G3D_Region *region;
-     int convertNull;
-     double nullValue;
+void convert  (char *openFile, G3D_Region *region, int convertNull, double nullValue)
 
 {
   double tmp;
@@ -159,7 +149,7 @@ void convert (openFile, region, convertNull, nullValue)
 	region->bottom = v5d.VertArgs[0];
 	region->top = region->bottom + region->depths * res_l;
 
-        data1 = (float *) malloc( nrncnl * sizeof(float) );
+        data1 = (float *) G_malloc ( nrncnl * sizeof(float) );
         if (!data1)
         G_fatal_error("Not enough memory for data1");
 
@@ -181,7 +171,7 @@ void convert (openFile, region, convertNull, nullValue)
          }
        }
 
-        free(data1);
+        G_free (data1);
 
         }
    }
@@ -193,10 +183,7 @@ void convert (openFile, region, convertNull, nullValue)
 /*---------------------------------------------------------------------------*/
 
 int
-main (argc, argv) 
-     
-     int argc;
-     char *argv[];
+main  (int argc, char *argv[])
 
 {
   char *input, *output;
@@ -212,7 +199,8 @@ main (argc, argv)
 
   G_gisinit(argv[0]);
   module = G_define_module();
-  module->description =
+  module->keywords = _("raster3d, voxel");
+    module->description =
    "  import of 3-dimensional Vis5D files (i.e. the v5d file with 1 variable and 1 time step)";
 
   setParams ();
