@@ -1,22 +1,23 @@
-/* ***************************************************************
- * *
- * * MODULE:       v.topo.check
- * * 
- * * AUTHOR(S):    Radim Blazek
- * *               
- * * PURPOSE:      Check vector topology.
- * *               
- * * COPYRIGHT:    (C) 2001 by the GRASS Development Team
- * *
- * *               This program is free software under the 
- * *               GNU General Public License (>=v2). 
- * *               Read the file COPYING that comes with GRASS
- * *               for details.
- * *
- * **************************************************************/
+/***************************************************************
+ *
+ * MODULE:       v.topo.check
+ * 
+ * AUTHOR(S):    Radim Blazek
+ *               
+ * PURPOSE:      Check vector topology.
+ *               
+ * COPYRIGHT:    (C) 2001 by the GRASS Development Team
+ *
+ *               This program is free software under the 
+ *               GNU General Public License (>=v2). 
+ *               Read the file COPYING that comes with GRASS
+ *               for details.
+ *
+ **************************************************************/
 #include <stdlib.h> 
-#include "gis.h"
-#include "Vect.h"
+#include <grass/gis.h>
+#include <grass/Vect.h>
+#include <grass/glocale.h>
 
 int 
 main (int argc, char *argv[])
@@ -36,7 +37,8 @@ main (int argc, char *argv[])
 	double tarea1, tarea2, darea, pdarea;
 
 	module = G_define_module();
-	module->description = "Break lines at intersections.";
+	module->keywords = _("vector");
+    module->description = "Break lines at intersections.";
 
 	in_opt = G_define_standard_option(G_OPT_V_INPUT);
 	out_opt = G_define_standard_option(G_OPT_V_OUTPUT);
