@@ -1,6 +1,6 @@
 #include <stdlib.h>
-#include "gis.h"
-#include "Vect.h"
+#include <grass/gis.h>
+#include <grass/Vect.h>
 #include "conv.h"
 #include "local_proto.h"
 
