@@ -14,14 +14,19 @@
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
-#include "gis.h"
-#include "Vect.h"
-#include "dbmi.h"
+#include <grass/gis.h>
+#include <grass/display.h>
+#include <grass/raster.h>
+#include <grass/Vect.h>
+#include <grass/dbmi.h>
+#include <grass/glocale.h>
 
-#define PI    3.1415926535897932384626433832795029L
+#define PI M_PI
 
 struct Option *Xoffset, *Yoffset, *Reference, *Font, *Color, *Size;
 struct Option *Width, *Hcolor, *Hwidth, *Bcolor, *Border, *Opaque;
+int fontsize;
+char ref_pt[24];
 
 void print_label ( FILE *, double, double, double, char *);
 
@@ -31,7 +36,7 @@ main (int argc, char **argv)
     int    i, cnt, nrows, txtlength, field, more;
     int    type, ltype;
     int    cat, direction;
-    double x, y, linlength, lablength, space, ldist;
+    double x, y, linlength, lablength, size, space, ldist;
     double rotate, rot;
     char   *mapset;
     char   *txt, buf[2000];
@@ -42,8 +47,8 @@ main (int argc, char **argv)
     struct Map_info Map;
     struct GModule *module;
     struct Option *Vectfile, *Typopt, *Fieldopt, *Colopt;
-    struct Option *Labelfile, *Space;
-    struct Flag   *Along_flag;
+    struct Option *Labelfile, *Space, *FontSize, *Rotation;
+    struct Flag   *Along_flag, *Curl_flag;
 
     struct field_info *fi;
     dbDriver *driver;
@@ -54,7 +59,9 @@ main (int argc, char **argv)
 
     G_gisinit(argv[0]);
     module = G_define_module();
-    module->description = "Create paint labels for GRASS vector file and attached attributes.";
+    module->keywords = _("vector, paint labels");
+    module->description =
+	_("Create paint labels for GRASS vector file and attached attributes.");
 
     Vectfile = G_define_standard_option(G_OPT_V_MAP);
 
@@ -68,103 +75,131 @@ main (int argc, char **argv)
     Colopt->key         = "column" ;
     Colopt->type        = TYPE_STRING ;
     Colopt->required    = YES;
-    Colopt->description = "Name of attribute column to be used for labels" ;
-    
-    Along_flag = G_define_flag ();
+    Colopt->description = _("Name of attribute column to be used for labels");
+
+    Along_flag = G_define_flag();
     Along_flag->key            = 'a';
-    Along_flag->description    = "Create labels along lines";
-    
+    Along_flag->description    = _("Rotate labels to align with lines");
+
+    Curl_flag = G_define_flag();
+    Curl_flag->key             = 'c';
+    Curl_flag->description     = _("Curl labels along lines");
+
     Labelfile = G_define_option();
     Labelfile->key = "labels";
-    Labelfile->description = "Name of a paint-label file";
+    Labelfile->description = _("Name for new paint-label file");
     Labelfile->type = TYPE_STRING;
     Labelfile->required = YES;
+    Labelfile->key_desc = "name";
 
     Xoffset = G_define_option();
     Xoffset->key = "xoffset";
-    Xoffset->description = "Offset label in x-direction";
+    Xoffset->description = _("Offset label in x-direction");
     Xoffset->type = TYPE_DOUBLE;
     Xoffset->answer = "0";
 
     Yoffset = G_define_option();
     Yoffset->key = "yoffset";
-    Yoffset->description = "Offset label in y-direction";
+    Yoffset->description = _("Offset label in y-direction");
     Yoffset->type = TYPE_DOUBLE;
     Yoffset->answer = "0";
 
     Reference = G_define_option();
     Reference->key = "reference";
-    Reference->description = "Reference position";
+    Reference->description = _("Reference position");
     Reference->type = TYPE_STRING;
+    Reference->multiple = YES;
     Reference->answer = "center";
     Reference->options = "center,left,right,upper,lower";
 
     Font = G_define_option();
     Font->key = "font";
-    Font->description = "Font";
+    Font->description = _("Font name");
     Font->type = TYPE_STRING;
     Font->answer = "standard";
 
     Size = G_define_option();
     Size->key = "size";
-    Size->description = "Label size (in map-units)";
+    Size->description = _("Label size (in map-units)");
     Size->type = TYPE_DOUBLE;
     Size->answer = "100";
 
+    Space = G_define_option();
+    Space->key = "space";
+    Space->description = _("Space between letters for curled labels (in map-units)");
+    Space->type = TYPE_DOUBLE;
+    Space->required = NO;
+
+    FontSize = G_define_option();
+    FontSize->key = "fontsize";
+    FontSize->description = _("Label size (in points)");
+    FontSize->type = TYPE_INTEGER;
+    FontSize->required = NO;
+    FontSize->options = "1-1000";
+
     Color = G_define_option();
     Color->key = "color";
-    Color->description = "Text color";
+    Color->description = _("Text color");
     Color->type = TYPE_STRING;
     Color->answer = "black";
-    Color->options = "aqua,black,blue,brown,cyan,gray,green,grey,indigo,magenta, orange,purple,red,violet,white,yellow";
+    Color->options = "aqua,black,blue,brown,cyan,gray,green,grey,indigo,magenta,orange,purple,red,violet,white,yellow";
+
+    Rotation = G_define_option();
+    Rotation->key = "rotation";
+    Rotation->description = _("Rotation angle (degrees counter-clockwise from East)");
+    Rotation->type = TYPE_DOUBLE;
+    Rotation->required = NO;
+    Rotation->options = "0-360";
+    Rotation->answer = "0";
+    Rotation->key_desc = "angle";
 
     Width = G_define_option();
     Width->key = "width";
-    Width->description = "Border width (only for ps.map output)";
+    Width->description = _("Border width (only for ps.map output)");
     Width->type = TYPE_DOUBLE;
     Width->answer = "1";
 
     Hcolor = G_define_option();
     Hcolor->key = "hcolor";
-    Hcolor->description = "Highlight color for text (only for ps.map output)";
+    Hcolor->description = _("Highlight color for text");
     Hcolor->type = TYPE_STRING;
     Hcolor->answer = "none";
-    Hcolor->options = "none,aqua,black,blue,brown,cyan,gray,green,grey,indigo,magenta, orange,purple,red,violet,white,yellow";
+    Hcolor->options = "none,aqua,black,blue,brown,cyan,gray,green,grey,indigo,magenta,orange,purple,red,violet,white,yellow";
 
     Hwidth = G_define_option();
     Hwidth->key = "hwidth";
-    Hwidth->description = "Line width of highlight color (only for ps.map output)";
+    Hwidth->description = _("Width of highlight coloring");
     Hwidth->type = TYPE_DOUBLE;
     Hwidth->answer = "0";
 
     Bcolor = G_define_option();
     Bcolor->key = "background";
-    Bcolor->description = "Background color";
+    Bcolor->description = _("Background color");
     Bcolor->type = TYPE_STRING;
     Bcolor->answer = "none";
-    Bcolor->options = "none,aqua,black,blue,brown,cyan,gray,green,grey,indigo,magenta, orange,purple,red,violet,white,yellow";
+    Bcolor->options = "none,aqua,black,blue,brown,cyan,gray,green,grey,indigo,magenta,orange,purple,red,violet,white,yellow";
 
     Border = G_define_option();
     Border->key = "border";
-    Border->description = "Border color";
+    Border->description = _("Border color");
     Border->type = TYPE_STRING;
     Border->answer = "none";
-    Border->options = "none,aqua,black,blue,brown,cyan,gray,green,grey,indigo,magenta, orange,purple,red,violet,white,yellow";
+    Border->options = "none,aqua,black,blue,brown,cyan,gray,green,grey,indigo,magenta,orange,purple,red,violet,white,yellow";
 
     Opaque = G_define_option();
     Opaque->key = "opaque";
-    Opaque->description = "Opaque to vector (only relevant if background color is selected)";
+    Opaque->description =
+	_("Opaque to vector (only relevant if background color is selected)");
     Opaque->type = TYPE_STRING;
     Opaque->answer = "yes";
     Opaque->options = "yes,no";
+    Opaque->key_desc = "yes|no";
 
-    Space = G_define_option();
-    Space->key = "space";
-    Space->description = "Space between letters (in map-units)";
-    Space->type = TYPE_DOUBLE;
-    Space->answer = "100";
 
-    if (G_parser (argc, argv ) ) exit (-1 );
+    if (G_parser (argc, argv))
+	exit (EXIT_FAILURE);
+
+    if(Curl_flag->answer) Along_flag->answer = 1;
 
     db_init_string (&stmt);
     db_init_string (&valstr);
@@ -174,21 +209,62 @@ main (int argc, char **argv)
     
     type = Vect_option_to_types ( Typopt );
 
-    space = atof (Space->answer);
+    size = atof (Size->answer);
+    space = size;  /* default: set spacing according to letter size (map units) */
+    rotate = atof (Rotation->answer);
+
+    if(FontSize->answer) {
+	fontsize = atoi(FontSize->answer);
+
+	/* figure out space param dynamically from current dispay */
+	/* don't bother if Space was explicitly given (bypasses xmon req) */
+	if(Along_flag->answer && ! Space->answer) {
+	    if (R_open_driver() != 0)  /* connect to the driver */
+		G_fatal_error(_("No graphics device selected"));
+
+	    /* Read in the map region associated with graphics window */
+	    D_setup(0);
+	    space = fontsize / D_get_u_to_d_xconv();  /* in earth units */
+
+	    R_close_driver();
+	}
+    }
+    else
+	fontsize = 0;
+
+    /* or if user explicitly gave a number for letter spacing, use that */
+    if(Space->answer)
+	space = atof (Space->answer);
+
+    if(Along_flag->answer && !fontsize && ( size/space >= 2  ||  size/space <= 0.5 ))
+	G_warning(_("size and space options vary significantly which may lead to crummy output"));
+
+
+    /* parse reference answers */
+    i=0;
+    strcpy(ref_pt,"");
+    while(Reference->answers[i]) {
+	if(i>1) G_fatal_error(_("Too many parameters for <reference>"));
+	if(i>0) strcat(ref_pt, " ");
+	strncat(ref_pt, Reference->answers[i], 7);
+	i++;
+    }
 
     /* open vector */	
     mapset = G_find_vector2 ( Vectfile->answer, NULL) ; 
-    if (mapset == NULL) G_fatal_error("Vector file [%s] not available", Vectfile->answer) ;
+    if (mapset == NULL)
+	G_fatal_error(_("Vector file [%s] not available"), Vectfile->answer);
 
     Vect_open_old (&Map, Vectfile->answer, mapset);
 	
     /* open database */	
     field = atoi ( Fieldopt->answer );
     fi = Vect_get_field(&Map, field);
-    if ( fi == NULL ) G_fatal_error ( "Cannot get layer info for vector map" );
+    if ( fi == NULL ) G_fatal_error (_("Cannot get layer info for vector map"));
     driver = db_start_driver_open_database ( fi->driver, fi->database );
     if ( driver == NULL ) 
-	G_fatal_error ( "Cannot open database %s by driver %s", fi->database, fi->driver );
+	G_fatal_error(_("Cannot open database %s by driver %s"), 
+	    fi->database, fi->driver);
 
     /* open labels */	
     labels = G_fopen_new ("paint/labels", Labelfile->answer);
@@ -198,7 +274,7 @@ main (int argc, char **argv)
 
     while (1) {
         ltype =  Vect_read_next_line (&Map, Points, Cats);
-        if ( ltype == -1 ) G_fatal_error ( "Cannot read vector" );
+        if ( ltype == -1 ) G_fatal_error (_("Cannot read vector"));
         if ( ltype == -2 ) break;  /* EOF */
 	if ( !( type & ltype) ) continue;
 
@@ -207,20 +283,22 @@ main (int argc, char **argv)
 	
 	/* Read label from database */
 
-	sprintf (buf, "select %s from %s where %s = %d", Colopt->answer, fi->table, fi->key, cat);
+	sprintf(buf, "select %s from %s where %s = %d", Colopt->answer, 
+	    fi->table, fi->key, cat);
 	G_debug (3, "SQL: %s", buf);
 	db_set_string ( &stmt, buf);
 	
         if (db_open_select_cursor(driver, &stmt, &cursor, DB_SEQUENTIAL) != DB_OK)
-            G_fatal_error ("Cannot select attribute.");
+            G_fatal_error (_("Cannot select attribute."));
 
 	nrows = db_get_num_rows ( &cursor );
 	if ( nrows < 1 ) {
-	    G_warning ( "No database record for category %d", cat);
+	    G_warning (_("No database record for category %d"), cat);
 	    continue;
 	}
 
 	if( db_fetch (&cursor, DB_NEXT, &more) != DB_OK || !more ) continue;
+
 	table = db_get_cursor_table (&cursor);
 	column = db_get_table_column(table, 0); /* first column */
 
@@ -237,13 +315,13 @@ main (int argc, char **argv)
 	linlength = Vect_line_length ( Points );
 	
 	if ( ltype & GV_POINTS ) {
-	    print_label (labels, Points->x[0], Points->y[0], 0.0, txt);
+	    print_label (labels, Points->x[0], Points->y[0], rotate, txt);
 	} else if ( !Along_flag->answer ) { /* Line, but not along */
 	    /* get centre */
             Vect_point_on_line ( Points, linlength/2, &x, &y, NULL, NULL, NULL);
-	    print_label (labels, x, y, 0.0, txt);
+	    print_label (labels, x, y, rotate, txt);
 	} else { /* Along line */
-	
+
 	    /* find best orientation (most letters by bottom to down side */
 	    rotate = 0;
 	    for (i=0; i < txtlength; i++)
@@ -251,7 +329,7 @@ main (int argc, char **argv)
 		/* distance of the letter from the beginning of line */
 		lablength = txtlength * space;
 		ldist = i * space + ( linlength - lablength ) / 2; 
-	
+
 		if ( ldist < 0 ) ldist = 0;
 		if ( ldist > linlength ) ldist = linlength;
 
@@ -261,27 +339,38 @@ main (int argc, char **argv)
 	    }
 	    if ( rotate >= 0 ) { direction = 0; } else { direction = 1; }
 
-	    for (i=0; i < txtlength; i++)
-	    {
-		/* distance of the letter from the beginning of line */
-		lablength = txtlength * space;
+	    if(Curl_flag->answer) {
+		for (i=0; i < txtlength; i++) {
+		    /* distance of the letter from the beginning of line */
+		    lablength = txtlength * space;
 	    
-		ldist = i * space + ( linlength - lablength ) / 2;
+		    ldist = i * space + ( linlength - lablength ) / 2;
 
+		    if ( ldist < 0 ) ldist = 0;
+		    if ( ldist > linlength ) ldist = linlength;
+
+		    Vect_point_on_line ( Points, ldist, &x, &y, NULL, &rotate, NULL);
+		    rotate = rotate * 180 / PI;
+		
+		    if ( direction == 0 ) {
+			sprintf (buf, "%c", txt[i]);
+		    } else {
+			sprintf (buf, "%c", txt[txtlength - i - 1]);
+			rotate += 180;
+		    }
+		    print_label (labels, x, y, rotate, buf);
+		}
+	    }
+	    else { /* same as above but take center value for placement & rotation */
+		i = (int)(txtlength/2.0 + 0.5);
+		lablength = txtlength * space;
+		ldist = i * space + ( linlength - lablength ) / 2;
 		if ( ldist < 0 ) ldist = 0;
 		if ( ldist > linlength ) ldist = linlength;
-
 		Vect_point_on_line ( Points, ldist, &x, &y, NULL, &rotate, NULL);
 		rotate = rotate * 180 / PI;
-		
-		if ( direction == 0 ) {
-		    sprintf (buf, "%c", txt[i]);
-		} else {
-		    sprintf (buf, "%c", txt[txtlength - i - 1]);
-		    rotate += 180;
-		}
-	    
-		print_label (labels, x, y, rotate, buf);
+		if ( direction != 0 ) rotate += 180;
+		print_label (labels, x, y, rotate, txt);
 	    }
 	}
 	cnt++;
@@ -293,9 +382,9 @@ main (int argc, char **argv)
     db_close_database_shutdown_driver ( driver );
     fclose (labels);
 
-    fprintf (stderr, "Labeled %d lines.\n", cnt);
+    G_message( _("Labeled %d lines."), cnt);
 
-    exit (0);
+    exit (EXIT_SUCCESS);
 }
 
 void print_label ( FILE *labels, double x, double y, double rotate, char *label) {
@@ -303,10 +392,13 @@ void print_label ( FILE *labels, double x, double y, double rotate, char *label)
     fprintf (labels, "north: %f\n", y);
     fprintf (labels, "xoffset: %s\n", Xoffset->answer);
     fprintf (labels, "yoffset: %s\n", Yoffset->answer);
-    fprintf (labels, "ref: %s\n", Reference->answer);
+    fprintf (labels, "ref: %s\n", ref_pt);
     fprintf (labels, "font: %s\n", Font->answer);
     fprintf (labels, "color: %s\n", Color->answer);
-    fprintf (labels, "size: %s\n", Size->answer);
+
+    if(fontsize) fprintf (labels, "fontsize: %d\n", fontsize);
+    else fprintf (labels, "size: %s\n", Size->answer);
+
     fprintf (labels, "width: %s\n", Width->answer);
     fprintf (labels, "hcolor: %s\n", Hcolor->answer);
     fprintf (labels, "hwidth: %s\n", Hwidth->answer);
@@ -315,6 +407,6 @@ void print_label ( FILE *labels, double x, double y, double rotate, char *label)
     fprintf (labels, "opaque: %s\n", Opaque->answer);
     if ( rotate != 0 ) 
         fprintf (labels, "rotate: %f\n", rotate);
-    
-    fprintf (labels, "\ntext: %s\n\n", label);
+
+    fprintf (labels, "text: %s\n\n", label);
 }
