@@ -7,9 +7,8 @@
  */
 
 #include<stdio.h>
-int scan_cats (s, x, y)
-    char *s;
-    long *x, *y;
+int scan_cats  (char *s, long *x, long *y)
+
 {
     char dummy[2];
  
