@@ -18,13 +18,14 @@
  * **************************************************************/
 #include <stdlib.h> 
 #include <string.h> 
-#include "gis.h"
-#include "dbmi.h"
-#include "Vect.h"
+#include <grass/gis.h>
+#include <grass/dbmi.h>
+#include <grass/Vect.h>
 #include "ogr_api.h"
 #include "cpl_string.h"
-#include "config.h"
-#include "gprojects.h"
+#include <grass/config.h>
+#include <grass/gprojects.h>
+#include <grass/glocale.h>
 
 int    fout, fskip; /* features written/ skip */
 int    nocat, noatt, nocatskip; /* number of features without cats/atts written/skip */
@@ -38,12 +39,12 @@ char OGRdrivers[2000];
 int 
 main (int argc, char *argv[])
 {
-    int    i, j, k, centroid, otype, wkbtype=wkbUnknown, donocat;
+    int    i, j, k, centroid, otype, donocat;
     char   *mapset;
     int    field;
     struct GModule *module;
     struct Option *in_opt, *dsn_opt, *layer_opt, *type_opt, *frmt_opt, *field_opt, *dsco, *lco;
-    struct Flag   *cat_flag, *esristyle;
+    struct Flag   *cat_flag, *esristyle, *poly_flag;
     char   buf[2000];
     char   key1[200], key2[200];
     struct Key_Value *projinfo, *projunits;
@@ -73,6 +74,7 @@ main (int argc, char *argv[])
     OGRFeatureH Ogr_feature;  
     OGRFeatureDefnH Ogr_featuredefn;
     OGRGeometryH Ogr_geometry;
+    unsigned int wkbtype=wkbUnknown;  /* ?? */
     OGRSpatialReferenceH Ogr_projection;
     char **papszDSCO = NULL, **papszLCO = NULL;
 
@@ -80,30 +82,32 @@ main (int argc, char *argv[])
 
     /* Module options */
     module = G_define_module();
-    module->description = "Convert to OGR format.";
+    module->keywords = _("vector");
+    module->description = _("Convert to one of the supported OGR vector formats.");
 
     in_opt = G_define_standard_option(G_OPT_V_INPUT);
 
     type_opt = G_define_standard_option(G_OPT_V_TYPE) ;
+    type_opt->options = "point,kernel,centroid,line,boundary,area,face";
     type_opt->answer = "line,boundary";
-    type_opt->description = "Feature type. Possible combinations of more types: "
-			    "point,centroid or line,boundary.";
+    type_opt->description = _("Feature type. Combination of types is not supported"
+                              " by all formats.");
     
     dsn_opt = G_define_option();
     dsn_opt->key = "dsn";
     dsn_opt->type =  TYPE_STRING;
     dsn_opt->required = YES;
-    dsn_opt->description = "OGR datasource name.\n"
-			   "\t\tESRI Shapefile: directory containing shapefiles\n"
-			   "\t\tMapInfo File: directory containing mapinfo files";
+    dsn_opt->description = _("OGR output datasource name. For example:\n"
+			   "\t\tESRI Shapefile: filename or directory for storage\n"
+			   "\t\tMapInfo File: filename or directory for storage");
 
     layer_opt = G_define_option();
     layer_opt->key = "olayer";
     layer_opt->type = TYPE_STRING;
     layer_opt->required = YES;
-    layer_opt->description = "OGR layer name.\n"
+    layer_opt->description = _("OGR layer name.\n"
 			   "\t\tESRI Shapefile: shapefile name\n"
-			   "\t\tMapInfo File: mapinfo file name";
+			   "\t\tMapInfo File: mapinfo file name");
     
     field_opt = G_define_standard_option(G_OPT_V_FIELD);
     field_opt->answer = "1";
@@ -115,7 +119,7 @@ main (int argc, char *argv[])
     frmt_opt->multiple = NO;
     frmt_opt->answer = "ESRI_Shapefile";
     frmt_opt->options = OGR_list_write_drivers();
-    frmt_opt->description = "OGR format.";
+    frmt_opt->description = _("OGR format.");
     
     dsco              = G_define_option();
     dsco->key         = "dsco";
@@ -123,7 +127,7 @@ main (int argc, char *argv[])
     dsco->required    = NO;
     dsco->multiple    = NO;
     dsco->answer      = "";
-    dsco->description = "OGR dataset creation option (format specific, NAME=VALUE)";
+    dsco->description = _("OGR dataset creation option (format specific, NAME=VALUE)");
     
     lco               = G_define_option();
     lco->key          = "lco";
@@ -131,34 +135,48 @@ main (int argc, char *argv[])
     lco->required     = NO;
     lco->multiple     = NO;
     lco->answer       = "";
-    lco->description  = "OGR layer creation option (format specific, NAME=VALUE)";
+    lco->description  = _("OGR layer creation option (format specific, NAME=VALUE)");
     
     cat_flag = G_define_flag ();
     cat_flag->key            = 'c';
-    cat_flag->description    = "Export features with category (labeled) only. "
-			       "Otherwise all features are exported";
+    cat_flag->description    = _("Export features with category (labeled) only. "
+			       "Otherwise all features are exported");
 
     esristyle = G_define_flag();
     esristyle->key = 'e';
-    esristyle->description = "Use ESRI-style .prj file format (applies to SHAPE output only)";
+    esristyle->description = _("Use ESRI-style .prj file format (applies to SHAPE output only)");
+
+    poly_flag = G_define_flag();
+    poly_flag->key = 'p';
+    poly_flag->description = _("Export lines as polygons");
 		
-    if (G_parser (argc, argv)) exit(1); 
+    if (G_parser (argc, argv)) exit(EXIT_FAILURE); 
     
     /* read options */
     field = atoi( field_opt->answer );
     
     /* Check output type */
     otype = Vect_option_to_types ( type_opt ); 
-    if ( ((GV_POINTS & otype) && (GV_LINES & otype)) ||
-	 ((GV_POINTS & otype) && (GV_AREA & otype)) || 
-	 ((GV_LINES & otype) && (GV_AREA & otype)) ) 
-      {
-	 G_fatal_error ("The combination of types is not allowed.");
-      }
-
+    
     if ( otype & GV_POINTS ) wkbtype = wkbPoint;
     else if ( otype & GV_LINES ) wkbtype = wkbLineString;
     else if ( otype & GV_AREA ) wkbtype = wkbPolygon;
+    else if ( otype & GV_FACE ) wkbtype = wkbPolygon25D;
+
+    if ( poly_flag->answer ) wkbtype = wkbPolygon;
+
+    if ( ((GV_POINTS & otype) && (GV_LINES & otype)) ||
+	 ((GV_POINTS & otype) && (GV_AREA & otype)) || 
+	 ((GV_POINTS & otype) && (GV_FACE & otype)) || 
+	 ((GV_LINES & otype) && (GV_AREA & otype)) ||
+	 ((GV_LINES & otype) && (GV_FACE & otype))
+       ) 
+      {
+	 G_warning (_("The combination of types is not supported "
+                      " by all formats."));
+          wkbtype=wkbUnknown;
+      }
+
     
     if ( cat_flag->answer ) donocat = 0; else donocat = 1;
     
@@ -167,7 +185,7 @@ main (int argc, char *argv[])
     
     /* open input vector */
     if ((mapset = G_find_vector2 (in_opt->answer, "")) == NULL) {
-	 G_fatal_error ("Could not find input map <%s>\n", in_opt->answer);
+	 G_fatal_error (_("Could not find input vector map <%s>"), in_opt->answer);
     }
     
     Vect_set_open_level (2); 
@@ -201,17 +219,17 @@ main (int argc, char *argv[])
 	    G_debug (2, " -> driver = %d" ); 
 	}
     }
-    if ( drn == -1 ) G_fatal_error ( "Driver %s not found", frmt_opt->answer ); 
+    if ( drn == -1 ) G_fatal_error ( _("Driver %s not found"), frmt_opt->answer ); 
     Ogr_driver = OGRGetDriver( drn );
     papszDSCO = CSLSetNameValue( papszDSCO, dsco->answer,"YES");
     Ogr_ds = OGR_Dr_CreateDataSource( Ogr_driver, dsn_opt->answer, papszDSCO );
     CSLDestroy( papszDSCO );
-    if ( Ogr_ds == NULL ) G_fatal_error ("Cannot open OGR data source '%s'", dsn_opt->answer);
+    if ( Ogr_ds == NULL ) G_fatal_error (_("Cannot open OGR data source '%s'"), dsn_opt->answer);
     
     papszLCO = CSLSetNameValue( papszLCO, lco->answer,"YES");
     Ogr_layer = OGR_DS_CreateLayer( Ogr_ds, layer_opt->answer, Ogr_projection, wkbtype, papszLCO );
     CSLDestroy( papszLCO );
-    if ( Ogr_layer == NULL ) G_fatal_error ("Cannot create layer");
+    if ( Ogr_layer == NULL ) G_fatal_error (_("Cannot create layer"));
     
     db_init_string(&dbstring);
 
@@ -220,7 +238,7 @@ main (int argc, char *argv[])
 	 doatt = 1; /* do attributes */
 	 Fi = Vect_get_field( &In, field);
 	 if ( Fi == NULL ) {
-	     G_warning ("No attribute table found -> using only category numbers as attributes");
+	     G_warning (_("No attribute table found -> using only category numbers as attributes"));
 	     
 	     Ogr_field = OGR_Fld_Create( "cat", OFTInteger ); 
 	     OGR_L_CreateField( Ogr_layer, Ogr_field, 0 ); 
@@ -228,16 +246,16 @@ main (int argc, char *argv[])
 	     doatt = 0;
 	 } else {  
 	     Driver = db_start_driver(Fi->driver);
-	     if (Driver == NULL) G_fatal_error("Cannot open driver %s", Fi->driver);
+	     if (Driver == NULL) G_fatal_error(_("Cannot open driver %s"), Fi->driver);
 
 	     db_init_handle (&handle);
 	     db_set_handle (&handle, Fi->database, NULL);
 	     if (db_open_database(Driver, &handle) != DB_OK)
-		 G_fatal_error("Cannot open database %s", Fi->database);
+		 G_fatal_error(_("Cannot open database %s"), Fi->database);
 
 	     db_set_string(&dbstring, Fi->table);
 	     if(db_describe_table (Driver, &dbstring, &Table) != DB_OK) 
-		 G_fatal_error("Cannot describe table %s", Fi->table);
+		 G_fatal_error(_("Cannot describe table %s"), Fi->table);
 
 	     ncol = db_get_table_number_of_columns(Table); 
 	     G_debug (2, "ncol = %d", ncol );
@@ -274,7 +292,7 @@ main (int argc, char *argv[])
 		 Ogr_field = OGR_Fld_Create( db_get_column_name(Column), ogr_ftype ); 
 		 OGR_L_CreateField( Ogr_layer, Ogr_field, 0 ); 
 	     }
-	     if ( keycol == -1 ) G_fatal_error ("Key column '%s' not found", Fi->key );
+	     if ( keycol == -1 ) G_fatal_error (_("Key column '%s' not found"), Fi->key );
 	 }
 	 
     }
@@ -286,21 +304,24 @@ main (int argc, char *argv[])
 
     /* check what users wants to export and what's present in the map */
     if ( Vect_get_num_primitives(&In, GV_POINT) > 0 && !(otype & GV_POINTS) )
-      G_warning("%d Point(s) found, but not requested to be exported. Verify 'type' parameter.",Vect_get_num_primitives(&In, GV_POINT));
+      G_warning(_("%d Point(s) found, but not requested to be exported. Verify 'type' parameter."),Vect_get_num_primitives(&In, GV_POINT));
 
     if ( Vect_get_num_primitives(&In, GV_LINE) > 0 && !(otype & GV_LINES) )
-      G_warning("%d Line(s) found, but not requested to be exported. Verify 'type' parameter.",Vect_get_num_primitives(&In, GV_LINE));
+      G_warning(_("%d Line(s) found, but not requested to be exported. Verify 'type' parameter."),Vect_get_num_primitives(&In, GV_LINE));
 
     if ( Vect_get_num_primitives(&In, GV_BOUNDARY) > 0 && !(otype & GV_BOUNDARY) && !(otype & GV_AREA) )
-      G_warning("%d Boundary(ies) found, but not requested to be exported. Verify 'type' parameter.",Vect_get_num_primitives(&In, GV_BOUNDARY));
+      G_warning(_("%d Boundary(ies) found, but not requested to be exported. Verify 'type' parameter."),Vect_get_num_primitives(&In, GV_BOUNDARY));
 
     if ( Vect_get_num_primitives(&In, GV_CENTROID) > 0 && !(otype & GV_CENTROID) && !(otype & GV_AREA) )
-      G_warning("%d Centroid(s) found, but not requested to be exported. Verify 'type' parameter.",Vect_get_num_primitives(&In, GV_CENTROID));
+      G_warning(_("%d Centroid(s) found, but not requested to be exported. Verify 'type' parameter."),Vect_get_num_primitives(&In, GV_CENTROID));
 
     if ( Vect_get_num_primitives(&In, GV_AREA) > 0  && !(otype & GV_AREA) )
-       G_warning("%d Areas found, but not requested to be exported. Verify 'type' parameter.",Vect_get_num_primitives(&In, GV_AREA));
+       G_warning(_("%d Areas found, but not requested to be exported. Verify 'type' parameter."),Vect_get_num_primitives(&In, GV_AREA));
 
-    /* add? GV_FACE GV_KERNEL */
+    if ( Vect_get_num_primitives(&In, GV_FACE) > 0  && !(otype & GV_FACE) )
+       G_warning(_("%d Faces found, but not requested to be exported. Verify 'type' parameter."),Vect_get_num_primitives(&In, GV_FACE));
+
+    /* add? GV_KERNEL */
 
     /* Lines (run always to count features of different type) */
     if ( (otype & GV_POINTS) || (otype & GV_LINES) ) {
@@ -325,10 +346,38 @@ main (int argc, char *argv[])
 
 
 	    /* Geometry */
-	    Ogr_geometry = OGR_G_CreateGeometry( wkbtype );
-	    for ( j = 0; j < Points->n_points; j++ ) {
-		OGR_G_AddPoint( Ogr_geometry, Points->x[j], Points->y[j], Points->z[j] );
-	    }
+            if ( type == GV_LINE && poly_flag->answer ) 
+            {
+                OGRGeometryH    ring;
+
+                ring = OGR_G_CreateGeometry( wkbLinearRing );
+                Ogr_geometry = OGR_G_CreateGeometry( wkbPolygon );
+
+                /* Area */
+                for ( j = 0; j < Points->n_points; j++ ) {
+                    OGR_G_AddPoint( ring, Points->x[j], Points->y[j], Points->z[j] );
+                }
+                if ( Points->x[Points->n_points-1] != Points->x[0] ||
+                     Points->y[Points->n_points-1] != Points->y[0] ||
+                     Points->z[Points->n_points-1] != Points->z[0] )
+                {
+                    OGR_G_AddPoint( ring, Points->x[0], Points->y[0], Points->z[0] );
+                }  
+                
+                OGR_G_AddGeometryDirectly ( Ogr_geometry, ring );
+            } 
+            else if ( type == GV_POINT )
+            {
+                Ogr_geometry = OGR_G_CreateGeometry( wkbPoint );
+                OGR_G_AddPoint( Ogr_geometry, Points->x[0], Points->y[0], Points->z[0] );
+            }
+            else  /* GV_LINE or GV_BOUNDARY */
+            {
+                Ogr_geometry = OGR_G_CreateGeometry( wkbLineString );
+                for ( j = 0; j < Points->n_points; j++ ) {
+                    OGR_G_AddPoint( Ogr_geometry, Points->x[j], Points->y[j], Points->z[j] );
+                }
+            }
 	    OGR_F_SetGeometry( Ogr_feature, Ogr_geometry ); 
 
 	    /* Output one feature for each category */
@@ -372,9 +421,7 @@ main (int argc, char *argv[])
 	    Vect_get_area_points ( &In, i, Points );
 
 	    /* Geometry */
-	    /* TODO: Use something better than WKT */
-	    Ogr_geometry = OGR_G_CreateGeometry( wkbtype ); /* wkbPolygon */
-	    
+	    Ogr_geometry = OGR_G_CreateGeometry( wkbPolygon );
 	
 	    ring = OGR_G_CreateGeometry( wkbLinearRing );
 	    
@@ -415,6 +462,63 @@ main (int argc, char *argv[])
 	    OGR_G_DestroyGeometry( Ogr_geometry );
 	}
     }
+
+    /* Faces (run always to count features of different type)  - Faces are similar to lines */
+    if ( otype & GV_FACE ) {
+	fprintf(stderr,"Exporting %i faces (may take some time) ...\n", Vect_get_num_faces(&In) );
+	for ( i = 1; i <= Vect_get_num_faces(&In) ; i++ ) {
+	    OGRGeometryH    ring;
+	    
+	    G_percent(i,Vect_get_num_faces(&In),1);
+	    
+	    type = Vect_read_line(&In, Points, Cats, i);
+	    G_debug(3, "line type = %d", type);
+
+	    cat = -1;
+	    Vect_cat_get (Cats, field, &cat);
+
+	    G_debug (3, "face = %d ncats = %d", i, Cats->n_cats );
+	    if ( cat < 0 && !donocat ) { /* Do not export not labeled */ 
+		nocatskip++;
+		continue; 
+	    }
+
+	    if ( type & GV_FACE ) {
+
+		/* Geometry */
+		Ogr_geometry = OGR_G_CreateGeometry( wkbPolygon25D );
+		ring = OGR_G_CreateGeometry( wkbLinearRing );
+	    
+		/* Face */
+		for ( j = 0; j < Points->n_points; j++ ) {
+		    OGR_G_AddPoint( ring, Points->x[j], Points->y[j], Points->z[j] );
+		}
+	    
+		OGR_G_AddGeometryDirectly ( Ogr_geometry, ring );
+	    
+		/* Output one feature for each category */
+		for ( j = -1; j < Cats->n_cats; j++ ) {
+		  if ( j == -1 ) {
+		    if ( cat >= 0 ) continue; /* cat(s) exists */
+		  } else {
+		    if ( Cats->field[j] == field )
+			cat = Cats->cat[j];
+		    else 
+			continue;
+		  }
+	        
+		  mk_att ( cat, Fi, Driver, ncol, keycol, doatt, Ogr_feature);
+	          OGR_L_CreateFeature( Ogr_layer, Ogr_feature ); 
+		}
+
+		OGR_F_SetGeometry( Ogr_feature, Ogr_geometry ); 
+
+		OGR_G_DestroyGeometry( Ogr_geometry );
+            } /* if type & GV_FACE */
+
+	} /* for */
+    }
+
 	    
     OGR_F_Destroy( Ogr_feature );
     OGR_DS_Destroy( Ogr_ds );
@@ -430,7 +534,7 @@ main (int argc, char *argv[])
     fprintf (stderr, "%d features written\n", fout);
     if ( nocat > 0 ) G_warning ( "%d features without category written", nocat);
     if ( noatt > 0 ) G_warning ( "%d features without attributes written", noatt);
-    if ( nocatskip > 0 ) G_warning ( "%d features without category skip", nocatskip);
+    if ( nocatskip > 0 ) G_warning ( "%d features found without category skip", nocatskip);
 
     /* Enable this? May be confusing that for area type are not reported all boundaries/centroids.
     *  OTOH why should be reported? */
@@ -439,7 +543,7 @@ main (int argc, char *argv[])
 	G_warning ( "%d features of different type skip", fskip);
     */
 	 
-    exit(0) ;
+    exit(EXIT_SUCCESS) ;
 }
 
 int
@@ -473,9 +577,9 @@ mk_att ( int cat, struct field_info *Fi, dbDriver *Driver, int ncol, int keycol,
 	    G_debug (2, "SQL: %s", buf);
 	    db_set_string(&dbstring, buf);
 	    if ( db_open_select_cursor(Driver, &dbstring, &cursor, DB_SEQUENTIAL) != DB_OK ) {
-		G_fatal_error ( "Cannot select attributes for cat = %d", cat);
+		G_fatal_error ( _("Cannot select attributes for cat = %d"), cat);
 	    } else {
-		if(db_fetch (&cursor, DB_NEXT, &more) != DB_OK) G_fatal_error ("Cannot fetch data");
+		if(db_fetch (&cursor, DB_NEXT, &more) != DB_OK) G_fatal_error (_("Cannot fetch data"));
 		if (!more) {
 		    /* G_warning ("No database record for cat = %d", cat); */
 		    /* Set at least key column to category */
