@@ -1,5 +1,5 @@
 /*-
- * s.qcount - GRASS program to sample a raster file at site locations.
+ * from s.qcount - GRASS program to sample a raster file at site locations.
  * Copyright (C) 1993-1995. James Darrell McCauley.
  *
  * Author: James Darrell McCauley darrell@mccauley-usa.com
@@ -19,8 +19,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
- *  $Id: main.c,v 1.2 2004/12/15 17:41:15 radim Exp $ 
- *
  * Modification History:
  * <03 Mar 1993> - began coding (jdm)
  * <11 Jan 1994> - announced version 0.3B on pasture.ecn.purdue.edu (jdm)
@@ -32,13 +30,14 @@
  *
  */
 
-/* #pragma ident "s.qcount v 0.7B <25 Jun 1995>; Copyright (c) 1993-1995. James Darrell McCauley" */
 
+#include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 #include <math.h>
-#include "gis.h"
-#include "Vect.h"
+#include <grass/gis.h>
+#include <grass/Vect.h>
+#include <grass/glocale.h>
 #include "quaddefs.h"
 
 int main ( int argc, char **argv)
@@ -65,6 +64,7 @@ int main ( int argc, char **argv)
   G_gisinit (argv[0]);
 
   module = G_define_module();
+  module->keywords = _("vector, statistics");
   module->description = "indices for quadrat counts of sites lists";
                   
   parm.input = G_define_option ();
@@ -100,7 +100,7 @@ int main ( int argc, char **argv)
   flag.q->description = "Quiet";
 
   if (G_parser (argc, argv))
-    exit (1);
+    exit (EXIT_FAILURE);
 
   verbose = (flag.q->answer) ? 0 : 1;
 
@@ -179,5 +179,5 @@ int main ( int argc, char **argv)
   fprintf(stdout,"Morisita's (1959) I (variability b/n patches)    %g\n",morisita);
   fprintf(stdout,"-----------------------------------------------------------\n");
 
-  exit (0);
+  exit (EXIT_SUCCESS);
 }
