@@ -1,3 +1,6 @@
+#ifndef __USER_H__
+#define __USER_H__
+
 int translate_oct ();
 int interp_call ();
 int INPUT ();
@@ -16,3 +19,6 @@ int POINT ();
 int LINEQS ();
 void clean_fatal_error();
 int point_save ();
+
+#endif
+
