@@ -10,7 +10,7 @@
 # Globals for animation
 ##################################
 global animNumFrames animStartX animEndX animFirstKeyX animLastKeyX
-global animKeyList animUniqueTag animInterpType animPathState
+global animKeyList animUniqueTag animInterpType animPathState IMG
 
 set animNumFrames 25
 Nset_numsteps 25
@@ -27,6 +27,7 @@ set animSiteState 0
 set animVolState 0
 set animRunState stop
 set animSaveRenderStyle 0
+set IMG 2
 # Update all the frames before we exit (should be easy since there aren't any)
 Nupdate_frames
 
@@ -89,7 +90,7 @@ proc mkanimationPanel { BASE } {
     button $rname.slow_back    -bitmap @$bit_map_path/slow_left \
 	-command "animStepBackward $BASE"
     button $rname.stop         -bitmap @$bit_map_path/stop \
-	-command {set animRunState stop}
+	-command {set animRunState stop; move_position}
     button $rname.slow_forward -bitmap @$bit_map_path/slow_right \
 	-command "animStepForward $BASE"
     button $rname.forward      -bitmap @$bit_map_path/right \
@@ -252,6 +253,7 @@ proc kfMoveSlider { x BASE } {
     set frame [animPosToFrame $pos]
     $oBASE.buttons.cur_frame configure -text "$frame"
     Ndo_framestep [expr $frame + 1] 0
+
 }
 
 ############################################################################
@@ -755,7 +757,7 @@ proc animClearAllKeys { BASE } {
 #
 ############################################################################
 proc animStepForward { BASE } {
-    global animNumFrames animKeyList animRunState animSaveRenderStyle
+    global animNumFrames animKeyList animRunState animSaveRenderStyle IMG
 
     if {"$animRunState" == "run_and_save"} then {
 	set style $animSaveRenderStyle
@@ -780,6 +782,9 @@ proc animStepForward { BASE } {
     } else {
 	$BASE.buttons.cur_frame configure -text "[expr $animNumFrames - 1]"
 	Ndo_framestep $animNumFrames $style
+	if {$IMG == "4" && $animRunState == "run_and_save"} {
+		Nclose_mpeg
+	}
 	set animRunState stop
     }
 
@@ -859,15 +864,16 @@ proc animRunAndSave { BASE } {
     radiobutton .ras_fname.fancy -text "Full Rendering" -variable animSaveRenderStyle -value 1
     button .ras_fname.ok -text "Ok" -command "set animWaitPress true"
     label .ras_fname.label -text "" -relief raised
-    radiobutton .ras_fname.img1 -text "Iris RGB" -variable IMG -value 1
+    # Start at value 2. 1 used to be SGI .rgb support
     radiobutton .ras_fname.img2 -text "PPM" -variable IMG -value 2
     radiobutton .ras_fname.img3 -text "TIFF" -variable IMG -value 3
+    radiobutton .ras_fname.img4 -text "MPEG-1" -variable IMG -value 4
 #Pack Menu
     pack .ras_fname.frame1 -side top -fill both -expand 1
     pack .ras_fname.frame2 -side bottom -fill both -expand 1
     pack .ras_fname.title .ras_fname.enter -side top \
     -in .ras_fname.frame1 -fill both
-    pack .ras_fname.img1 .ras_fname.img2 .ras_fname.img3 \
+    pack .ras_fname.img2 .ras_fname.img3 .ras_fname.img4 \
     -in .ras_fname.frame1 -side left -fill both
     pack .ras_fname.label .ras_fname.norm .ras_fname.fancy -side top \
 	-in .ras_fname.frame2 -fill both
@@ -876,6 +882,10 @@ proc animRunAndSave { BASE } {
     set animBaseName [.ras_fname.enter get]
     destroy .ras_fname
 
+    if {$IMG == 4} {
+	Ninit_mpeg $animBaseName
+    }
+
     # If we are already at the end then restart from the beginning
     set cur_frame [lindex [$BASE.buttons.cur_frame configure -text] 4]
     if {$cur_frame >= [expr $animNumFrames - 1]} then {
@@ -904,20 +914,16 @@ proc animSaveFrame { fnum } {
 	set num 0$num
     }
 
-if {$IMG == 1} {
-    append fname $num ".rgb"
-    Nwrite_rgb $fname
-	}
-if {$IMG == 2} {
+    # Start at 2. 1 used to be SGI .rgb support
+    if {$IMG == 2} {
 	append fname $num ".ppm"
 	Nwrite_ppm $fname
-	}
-if {$IMG == 3} {
+    }
+    if {$IMG == 3} {
 	append fname $num ".tif"
 	Nwrite_tif $fname
-	}
-
+    }
+    if {$IMG == 4} {
+	Nwrite_mpeg_frame
+    }
 }
-
-
-
